@@ -27,30 +27,30 @@
 
 // .SUMMARY General, Indexing, and Conformace errors thrown by Array classes.
 
-#include <casacore/casa/Arrays/ArrayError.h>
+#include "ArrayError.h"
 
 
 namespace casacore { //# NAMESPACE CASACORE - BEGIN
 
-ArrayError::ArrayError(Category c) : AipsError("ArrayError",c) {}
+ArrayError::ArrayError() : std::runtime_error("ArrayError") {}
 
-ArrayError::ArrayError(const Char *m,Category c) : AipsError(m,c) {}
+ArrayError::ArrayError(const char *m) : std::runtime_error(m) {}
 
-ArrayError::ArrayError(const String &m,Category c) : AipsError(m,c) {}
+ArrayError::ArrayError(const std::string &m) : std::runtime_error(m) {}
 
 ArrayError::~ArrayError() noexcept{}
 
 
 
-ArrayIndexError::ArrayIndexError(Category c) : ArrayError("ArrayIndexError",c) {}
+ArrayIndexError::ArrayIndexError() : ArrayError("ArrayIndexError") {}
 
-ArrayIndexError::ArrayIndexError(const Char *m,Category c) : ArrayError(m,c) {}
+ArrayIndexError::ArrayIndexError(const char* m) : ArrayError(m) {}
 
-ArrayIndexError::ArrayIndexError(const String &m,Category c) : ArrayError(m,c) {}
+ArrayIndexError::ArrayIndexError(const std::string &m) : ArrayError(m) {}
 
 ArrayIndexError::ArrayIndexError(const IPosition &in, 
-				 const IPosition &sh, const Char *m,Category c)
-: ArrayError(m,c),
+				 const IPosition &sh, const char* m)
+: ArrayError(m),
   i(in),
   l(sh)
 {
@@ -69,32 +69,37 @@ IPosition ArrayIndexError::shape() const
     return l;
 }
 
-
-
-ArrayConformanceError::ArrayConformanceError(Category c) 
-: ArrayError("ArrayConformanceError",c) 
+ArrayConformanceError::ArrayConformanceError() 
+: ArrayError("ArrayConformanceError") 
 {
     // Nothing
 }
 
-ArrayConformanceError::ArrayConformanceError(const Char *m,Category c) : ArrayError(m,c) {}
+ArrayConformanceError::ArrayConformanceError(const char* m) : ArrayError(m) {}
 
-ArrayConformanceError::ArrayConformanceError(const String &m,Category c) : ArrayError(m,c) {}
+ArrayConformanceError::ArrayConformanceError(const std::string &m) : ArrayError(m) {}
 
 ArrayConformanceError::~ArrayConformanceError() noexcept{}
 
 
 
-ArrayNDimError::ArrayNDimError(Int ndim1, Int ndim2, const Char *m,Category c)
-: ArrayConformanceError(m + String(" ndim ") + String::toString(ndim1)
-                        + " differs from " + String::toString(ndim2), c),
+ArrayNDimError::ArrayNDimError(int ndim1, int ndim2, const char* m)
+: ArrayConformanceError(m + std::string(" -- ndim ") + std::to_string(ndim1)
+                        + " differs from " + std::to_string(ndim2)),
+  r1(ndim1),
+  r2(ndim2)
+{}
+
+ArrayNDimError::ArrayNDimError(int ndim1, int ndim2, const std::string& m)
+: ArrayConformanceError(m + std::string(" -- ndim ") + std::to_string(ndim1)
+                        + " differs from " + std::to_string(ndim2)),
   r1(ndim1),
   r2(ndim2)
 {}
 
 ArrayNDimError::~ArrayNDimError() noexcept{}
 
-void ArrayNDimError::ndims(Int &ndim1, Int &ndim2) const
+void ArrayNDimError::ndims(int &ndim1, int &ndim2) const
 {
     ndim1 = r1; 
     ndim2 = r2;
@@ -103,9 +108,9 @@ void ArrayNDimError::ndims(Int &ndim1, Int &ndim2) const
 
 
 ArrayShapeError::ArrayShapeError(const IPosition &s1, const IPosition & s2,
-				 const Char *m,Category c)
-: ArrayConformanceError(m + String(" shape ") + s1.toString()
-                        + " differs from " + s2.toString(), c),
+				 const char* m)
+: ArrayConformanceError(m + std::string(" shape ") + s1.toString()
+                        + " differs from " + s2.toString()),
   sh1(s1), sh2(s2)
 {
     // Nothing
@@ -120,20 +125,20 @@ void ArrayShapeError::shapes(IPosition &shape1, IPosition &shape2) const
 
 
 
-ArrayIteratorError::ArrayIteratorError(Category c) : ArrayError("ArrayIteratorError",c) {}
+ArrayIteratorError::ArrayIteratorError() : ArrayError("ArrayIteratorError") {}
 
-ArrayIteratorError::ArrayIteratorError(const Char *m,Category c) : ArrayError(m,c) {}
+ArrayIteratorError::ArrayIteratorError(const char* m) : ArrayError(m) {}
 
-ArrayIteratorError::ArrayIteratorError(const String &m,Category c) : ArrayError(m,c) {}
+ArrayIteratorError::ArrayIteratorError(const std::string &m) : ArrayError(m) {}
 
 ArrayIteratorError::~ArrayIteratorError() noexcept{}
 
 
 
-ArraySlicerError::ArraySlicerError(Category c) : ArrayError("Slicer error",c) {}
+ArraySlicerError::ArraySlicerError() : ArrayError("Slicer error") {}
 
-ArraySlicerError::ArraySlicerError(const String &m,Category c)
-: ArrayError("Slicer error:" + m,c) {}
+ArraySlicerError::ArraySlicerError(const std::string &m)
+: ArrayError("Slicer error:" + m) {}
 
 ArraySlicerError::~ArraySlicerError() noexcept{}
 
