@@ -25,9 +25,12 @@
 //#
 //# $Id$
 
-#include <casacore/casa/Arrays/Slicer.h>
-#include <casacore/casa/Arrays/Slice.h>
-#include <casacore/casa/Arrays/ArrayError.h>
+#include "Slicer.h"
+#include "Slice.h"
+#include "ArrayError.h"
+
+#include <istream>
+#include <sstream>
 
 namespace casacore { //# NAMESPACE CASACORE - BEGIN
 
@@ -37,7 +40,7 @@ Slicer::Slicer()
   end_p   (1,MimicSource),
   stride_p(1,1),
   len_p   (1,MimicSource),
-  fixed_p (False)
+  fixed_p (false)
 {}
 
 Slicer::Slicer (const IPosition& bl, const IPosition& tr, const IPosition& in,
@@ -111,38 +114,7 @@ Slicer::Slicer (const Slice& x,
     fillEndLen();
 }
 
-
-Slicer::Slicer (const Slicer& that)
-: asEnd_p (that.asEnd_p),
-  start_p (that.start_p),
-  end_p   (that.end_p),
-  stride_p(that.stride_p),
-  len_p   (that.len_p),
-  fixed_p (that.fixed_p)
-{}
-
-Slicer& Slicer::operator= (const Slicer& that)
-{
-    if (this != &that) {
-	uInt nels = that.ndim();
-	if (ndim() != nels) {
-	    start_p.resize (nels);
-	    end_p.resize (nels);
-	    stride_p.resize (nels);
-	    len_p.resize (nels);
-	}
-	asEnd_p  = that.asEnd_p;
-	start_p  = that.start_p;
-	end_p    = that.end_p;
-	stride_p = that.stride_p;
-	len_p    = that.len_p;
-	fixed_p  = that.fixed_p;
-    }
-    return *this;
-}
-
-
-Bool Slicer::operator==(const Slicer& that) const
+bool Slicer::operator==(const Slicer& that) const
 {
    return this->len_p.isEqual(that.len_p) &&
           this->start_p.isEqual(that.start_p) &&
@@ -161,7 +133,7 @@ void Slicer::fillEndLen()
 	throw (ArraySlicerError ("IPosition-lengths differ"));
     }
     //# Reversed strides are not allowed yet (thus stride>0).
-    for (uInt i=0; i<start_p.nelements(); i++) {
+    for (size_t i=0; i<start_p.nelements(); i++) {
         if (stride_p(i) <= 0) {
 	    throw (ArraySlicerError ("stride<=0"));
 	}else{
@@ -195,10 +167,10 @@ void Slicer::fillEndLen()
 
 void Slicer::fillFixed()
 {
-    fixed_p = True;
-    for (uInt i=0; i<start_p.nelements(); i++) {
+    fixed_p = true;
+    for (size_t i=0; i<start_p.nelements(); i++) {
 	if (start_p(i) < 0  ||  end_p(i) < 0) {
-	    fixed_p = False;
+	    fixed_p = false;
 	    break;
 	}
     }
@@ -235,7 +207,7 @@ IPosition Slicer::inferShapeFromSource (const IPosition& shp,
     end    = shp - 1;
     stride = stride_p;
     IPosition res(start_p.nelements(), 0);
-    for (uInt i=0; i<start_p.nelements(); i++) {
+    for (size_t i=0; i<start_p.nelements(); i++) {
 	//# Fill and check start value; unspecified means 0.
 	if (start_p(i) != MimicSource) {
             start(i) = start_p(i);
@@ -278,7 +250,7 @@ IPosition Slicer::inferShapeFromSource (const IPosition& shp,
 }
 
 
-ostream  &operator << (ostream &stream, const Slicer &slicer)
+std::ostream  &operator << (std::ostream &stream, const Slicer &slicer)
 {
   
   stream << slicer.start () << " to " << slicer.end () 
@@ -288,5 +260,12 @@ ostream  &operator << (ostream &stream, const Slicer &slicer)
   return stream;
 }
 
+std::string to_string(const Slicer& slicer)
+{
+  std::ostringstream str;
+  str << slicer;
+  return str.str();
+}
+
 } //# NAMESPACE CASACORE - END
 
