@@ -31,7 +31,6 @@
 #include <casacore/casa/Containers/RecordDesc.h>
 #include <casacore/casa/Arrays/Array.h>
 #include <casacore/casa/Arrays/IPosition.h>
-#include <casacore/casa/Utilities/Register.h>
 #include <casacore/casa/Exceptions/Error.h>
 #include <casacore/casa/Utilities/Assert.h>
 
@@ -703,17 +702,10 @@ RecordNotice::RecordNotice (NoticeType changeType, uInt fieldNumber)
   fieldNumber_p (fieldNumber)
 {}
 
-uInt RecordNotice::type() const
+bool RecordNotice::operator== (const Notice& that) const
 {
-    // This function returns the "Notice" type, retrieved
-    // from the "type registry".
-    return Register(this);
-}
-
-int RecordNotice::operator== (const Notice& that) const
-{
-    if (type() != that.type()) {
-	return 0;
+    if (typeid(*this) != typeid(that)) {
+	return false;
     }
     return (changeType_p  == ((const RecordNotice&)that).changeType_p)
 	&& (fieldNumber_p == ((const RecordNotice&)that).fieldNumber_p);
