@@ -632,11 +632,8 @@ public:
     // The field number is only used for type REMOVE.
     RecordNotice (NoticeType changeType, uInt fieldNumber);
 
-    // Returns the change type.
-    virtual uInt type() const;
-
     // Always returns False.
-    virtual int operator== (const Notice& that) const;
+    virtual bool operator== (const Notice& that) const;
 
     // Return the change type.
     NoticeType changeType() const;
