@@ -34,6 +34,7 @@
 #include <casacore/casa/Arrays/ArrayLogical.h>
 #include <casacore/casa/Utilities/Assert.h>
 #include <casacore/casa/Exceptions/Error.h>
+#include <casacore/casa/vector.h>
 
 using namespace casacore;
 
@@ -291,7 +292,7 @@ int main()
     HDF5Record::writeRecord (file, "test", rec3);
     check (file);
 
-  } catch (AipsError& x) {
+  } catch (std::exception& x) {
     cout << "Unexpected exception: " << x.what() << endl;
     return 1;
   }
