@@ -54,8 +54,8 @@ int main (int argc, const char*[])
 //	d (1024);
 //	d (32768);
 //	d (327680);
-    } catch (AipsError& x) {
-	cout << "Caught an exception: " << x.getMesg() << endl;
+    } catch (std::exception& x) {
+	cout << "Caught an exception: " << x.what() << endl;
 	return 1;
     } 
     return 0;                           // exit with success status
