@@ -119,9 +119,9 @@ int main(int argc, const char* argv[])
     // Announce program and version.
     prgInput.announce();
     
-  } catch(AipsError& x) {
+  } catch(std::exception& x) {
     cout << "Caught exception" << endl;
-    cout << "Message is: " << x.getMesg() << endl;
+    cout << "Message is: " << x.what() << endl;
   } 
 }
 
