@@ -29,7 +29,6 @@
 #include <casacore/casa/Quanta/MVEarthMagnetic.h>
 #include <casacore/casa/Utilities/Assert.h>
 #include <casacore/casa/BasicMath/Math.h>
-#include <casacore/casa/Utilities/Register.h>
 #include <casacore/casa/Quanta/RotMatrix.h>
 #include <casacore/casa/Quanta/UnitVal.h>
 #include <casacore/casa/Quanta/QMath.h>
@@ -220,12 +219,8 @@ MVEarthMagnetic MVEarthMagnetic::operator-(const MVEarthMagnetic &right) const{
 
 //# Member functions
 
-uInt MVEarthMagnetic::type() const {
-  return Register(static_cast<MVEarthMagnetic *>(0));
-}
-
 void MVEarthMagnetic::assure(const MeasValue &in) {
-  if (in.type() != Register(static_cast<MVEarthMagnetic *>(0))) {
+  if (!dynamic_cast<const MVEarthMagnetic*>(&in)) {
     throw(AipsError("Illegal MeasValue type argument: MVEarthMagnetic"));
   }
 }
