@@ -164,8 +164,8 @@ int main() {
     }
     cout << "----------------------------------------------------" << endl;
 
-  } catch (AipsError& x) {
-    cout << x.getMesg() << endl;
+  } catch (std::exception& x) {
+    cout << x.what() << endl;
     return 1;
   } 
 
