@@ -96,8 +96,7 @@ void MUString::skipBlank() {
 }
 
 Bool MUString::testBlank() const {
-  static Regex ex("[ \t]");
-  return (ptr >= len || testChar(ex));
+  return (ptr >= len || str[ptr] == ' ' || str[ptr] == '\t');
 }
 
 Bool MUString::tSkipBlank() {
@@ -105,8 +104,7 @@ Bool MUString::tSkipBlank() {
 }
 
 Bool MUString::testSign() const {
-  static Regex ex("[-+]");
-  return testChar(ex);
+  return (ptr < len && (str[ptr] == '-' || str[ptr] == '+'));
 }
 
 void MUString::skipSign() {
@@ -467,30 +465,27 @@ void MUString::setLast(Int st) {
 
 uInt MUString::minimaxNC(const String &in, Int N_name, 
 			const String tname[]) {
-    String a;
-    String b;
     Int i;
-    a = upcase(in);
+    String a = upcase(in);
 // Exact fit?
     for (i=0; i<N_name; i++) {
 	if (a == upcase(tname[i])) break;
     }
 // Now look for partial
     if (i >= N_name) {
-	Int ia, ib;
-	ia = a.length();
+	size_t ia = a.length();
 	for (i=0; i<N_name; i++) {
-	    ib = tname[i].length();
+	    String b = upcase(tname[i]);
+	    size_t ib = b.length();
 	    ib = ia < ib ? ia : ib;
-	    b = upcase(tname[i]);
 	    if (a.at(0,ib) == b.at(0,ib)) {
 		Int j;
 // Look for more partials
 		for (j=i+1; j<N_name; j++) {
-		    ib = tname[j].length();
-		    ib = ia < ib ? ia : ib;
 		    b = upcase(tname[j]);
-		    if (a.at(0,ib) == b.at(0,ib)) break;
+		    ib = b.length();
+		    ib = ia < ib ? ia : ib;
+		    if (a(0,ib) == b.at(0,ib)) break;
 		}
 // Found duplicate
 		if (j<N_name) i=N_name;
