@@ -1244,8 +1244,8 @@ void Coordinate::set_wcs (::wcsprm& wcs)
     // wcsset calls wcsunitse, which in turn calls wcsulexe, which is thread-unsafe.
     // (in wcslib 5.17, the latest version at the time of writing, but probably
     // in all previous versions as well). Thus, this call needs to be protected
-    static Mutex wcsset_mutex;
-    ScopedMutexLock lock(wcsset_mutex);
+    static std::mutex wcsset_mutex;
+    std::lock_guard<std::mutex> lock(wcsset_mutex);
     if (int iret = wcsset(&wcs)) {
         String errmsg = "wcs wcsset_error: ";
         errmsg += wcsset_errmsg[iret];
@@ -1260,13 +1260,13 @@ void Coordinate::set_wcs (::wcsprm& wcs)
 // their previous values. This situation creates a race condition between
 // concurrent, independent calls to wcssub and wcsini. Thus, we serialize them
 // with this lock
-static Mutex wcs_initsubcopy_mutex;
+static std::mutex wcs_initsubcopy_mutex;
 //#endif // WCSLIB_VERSION >= 5.7
 
 void Coordinate::init_wcs(::wcsprm& wcs, int naxis)
 {
 //#if (WCSLIB_VERSION_MAJOR == 5 && WCSLIB_VERSION_MINOR >= 7) || WCSLIB_VERSION_MAJOR > 5
-    ScopedMutexLock lock(wcs_initsubcopy_mutex);
+    std::lock_guard<std::mutex> lock(wcs_initsubcopy_mutex);
 //#endif // WCSLIB_VERSION >= 5.7
     if (int iret = wcsini(1, naxis, &wcs)) {
         String errmsg = "wcs wcsini_error: ";
@@ -1279,7 +1279,7 @@ void Coordinate::sub_wcs(const ::wcsprm &src, int &nsub, int axes[], ::wcsprm &d
 {
 	// see init_wcs
 //#if (WCSLIB_VERSION_MAJOR == 5 && WCSLIB_VERSION_MINOR >= 7) || WCSLIB_VERSION_MAJOR > 5
-    ScopedMutexLock lock(wcs_initsubcopy_mutex);
+    std::lock_guard<std::mutex> lock(wcs_initsubcopy_mutex);
 //#endif // WCSLIB_VERSION >= 5.7
 	if (int iret = wcssub(1, &src, &nsub, axes, &dst)) {
 		String errmsg = "wcslib wcssub error: ";
@@ -1292,7 +1292,7 @@ void Coordinate::copy_wcs(const ::wcsprm &src, ::wcsprm &dst)
 {
 	// see init_wcs
 //#if (WCSLIB_VERSION_MAJOR == 5 && WCSLIB_VERSION_MINOR >= 7) || WCSLIB_VERSION_MAJOR > 5
-	ScopedMutexLock lock(wcs_initsubcopy_mutex);
+	std::lock_guard<std::mutex> lock(wcs_initsubcopy_mutex);
 //#endif // WCSLIB_VERSION >= 5.7
 	if (int iret = wcssub(1, &src, 0, 0, &dst)) {
 		String errmsg = "wcslib wcscopy error: ";
