@@ -31,6 +31,7 @@
 #define COORDINATES_COORDINATE_H
 
 #include <casacore/casa/aips.h>
+#include <casacore/casa/Arrays/ArrayFwd.h>
 #include <casacore/casa/BasicSL/String.h>
 #include <casacore/casa/Arrays/Vector.h>
 #include <wcslib/wcs.h>
@@ -39,7 +40,6 @@ namespace casacore { //# NAMESPACE CASACORE - BEGIN
 
 
 template<class T> class Quantum;
-template<class T> class Matrix;
 class IPosition;
 class RecordInterface;
 class Projection;
