@@ -32,7 +32,7 @@
 #include <casacore/coordinates/Coordinates/CoordinateSystem.h>
 
 #include <casacore/casa/Arrays/Matrix.h>
-#include <casacore/casa/Arrays/ArrayIO.h>
+#include <casacore/casa/IO/ArrayIO.h>
 #include <casacore/casa/BasicSL/Constants.h>
 #include <casacore/tables/Tables/TableRecord.h>
 #include <casacore/casa/Exceptions/Error.h>
@@ -202,8 +202,8 @@ int main()
        delete pCoordSys;
     }
 
-  } catch (AipsError& x) {
-     cerr << "aipserror: error " << x.getMesg() << endl;
+  } catch (std::exception& x) {
+     cerr << "aipserror: error " << x.what() << endl;
      return 1;
   }
 
