@@ -257,8 +257,8 @@ try {
 
 
 }
-   catch (AipsError& x) {
-      cerr << "aipserror: error " << x.getMesg() << endl;
+   catch (std::exception& x) {
+      cerr << "aipserror: error " << x.what() << endl;
       return 1;
   }
  
