@@ -265,8 +265,8 @@ int main()
                                 useCachedX, method, extrapolate),AipsError); // Recompute
          AlwaysAssert (allNear(yOut3, yOut, 1e-6), AipsError);
       }
-   } catch (AipsError& x) {
-      cerr << "aipserror: error " << x.getMesg() << endl;
+   } catch (std::exception& x) {
+      cerr << "aipserror: error " << x.what() << endl;
       return (1);
    }
 
