@@ -477,8 +477,8 @@ int main()
       }
 
        
-   } catch (AipsError& x) {
-      cerr << "aipserror: error " << x.getMesg() << endl;
+   } catch (std::exception& x) {
+      cerr << "aipserror: error " << x.what() << endl;
       return (1);
    }
 
