@@ -288,8 +288,8 @@ int main()
             throw(AipsError("Conversion reflection failed"));
          }
       }
-   } catch (AipsError& x) {
-      cerr << "aipserror: error " << x.getMesg() << endl;
+   } catch (std::exception& x) {
+      cerr << "aipserror: error " << x.what() << endl;
       return (1);
    }
 
