@@ -119,8 +119,8 @@ int main()
     	  AlwaysAssert(allTrue(stokesStrings == expec), AipsError);
       }
 
-   } catch (const AipsError& x) {
-      cerr << "aipserror: error " << x.getMesg() << endl;
+   } catch (const std::exception& x) {
+      cerr << "aipserror: error " << x.what() << endl;
       return (1);
    }
 
@@ -383,7 +383,7 @@ void doit4(StokesCoordinate& lc)
    Coordinate* pC = 0;
    try {
       pC = lc.makeFourierCoordinate (axes, shape);
-   } catch (AipsError& x) {
+   } catch (std::exception& x) {
      failed = True;
    } 
    if (!failed) {
