@@ -163,8 +163,8 @@ int main()
          doitNonLinear(pixelValues, worldValues, lc);
       }
 
-  } catch (AipsError& x) {
-      cerr << "aipserror: error " << x.getMesg() << endl;
+  } catch (std::exception& x) {
+      cerr << "aipserror: error " << x.what() << endl;
       return (1);
    }
 
