@@ -32,81 +32,81 @@ namespace casacore {
 
   HourangleColumn::~HourangleColumn()
   {}
-  void HourangleColumn::get (uInt rowNr, Double& data)
+  void HourangleColumn::get (rownr_t rowNr, Double& data)
   {
     data = itsEngine->getHA (itsAntNr, rowNr);
   }
 
   ParAngleColumn::~ParAngleColumn()
   {}
-  void ParAngleColumn::get (uInt rowNr, Double& data)
+  void ParAngleColumn::get (rownr_t rowNr, Double& data)
   {
     data = itsEngine->getPA (itsAntNr, rowNr);
   }
 
   LASTColumn::~LASTColumn()
   {}
-  void LASTColumn::get (uInt rowNr, Double& data)
+  void LASTColumn::get (rownr_t rowNr, Double& data)
   {
     data = itsEngine->getLAST (itsAntNr, rowNr);
   }
 
   HaDecColumn::~HaDecColumn()
   {}
-  IPosition HaDecColumn::shape (uInt)
+  IPosition HaDecColumn::shape (rownr_t)
   {
     return IPosition(1,2);
   }
-  Bool HaDecColumn::isShapeDefined (uInt)
+  Bool HaDecColumn::isShapeDefined (rownr_t)
   {
     return True;
   }
-  void HaDecColumn::getArray (uInt rowNr, Array<Double>& data)
+  void HaDecColumn::getArray (rownr_t rowNr, Array<Double>& data)
   {
     itsEngine->getHaDec (itsAntNr, rowNr, data);
   }
 
   AzElColumn::~AzElColumn()
   {}
-  IPosition AzElColumn::shape (uInt)
+  IPosition AzElColumn::shape (rownr_t)
   {
     return IPosition(1,2);
   }
-  Bool AzElColumn::isShapeDefined (uInt)
+  Bool AzElColumn::isShapeDefined (rownr_t)
   {
     return True;
   }
-  void AzElColumn::getArray (uInt rowNr, Array<Double>& data)
+  void AzElColumn::getArray (rownr_t rowNr, Array<Double>& data)
   {
     itsEngine->getAzEl (itsAntNr, rowNr, data);
   }
 
   ItrfColumn::~ItrfColumn()
   {}
-  IPosition ItrfColumn::shape (uInt)
+  IPosition ItrfColumn::shape (rownr_t)
   {
     return IPosition(1,2);
   }
-  Bool ItrfColumn::isShapeDefined (uInt)
+  Bool ItrfColumn::isShapeDefined (rownr_t)
   {
     return True;
   }
-  void ItrfColumn::getArray (uInt rowNr, Array<Double>& data)
+  void ItrfColumn::getArray (rownr_t rowNr, Array<Double>& data)
   {
     itsEngine->getItrf (itsAntNr, rowNr, data);
   }
 
   UVWJ2000Column::~UVWJ2000Column()
   {}
-  IPosition UVWJ2000Column::shape (uInt)
+  IPosition UVWJ2000Column::shape (rownr_t)
   {
     return IPosition(1,3);
   }
-  Bool UVWJ2000Column::isShapeDefined (uInt)
+  Bool UVWJ2000Column::isShapeDefined (rownr_t)
   {
     return True;
   }
-  void UVWJ2000Column::getArray (uInt rowNr, Array<Double>& data)
+  void UVWJ2000Column::getArray (rownr_t rowNr, Array<Double>& data)
   {
     itsEngine->getNewUVW (False, rowNr, data);
   }
