@@ -862,13 +862,6 @@ int *FitsBase::vdim() {
 	return &no_elements; 
 }
 //====================================================================================
-FitsBase & FitsBase::operator = (FitsBase &x) {
-	if (fieldtype() == x.fieldtype() &&
-	    nelements() == x.nelements())
-	    memcpy(data(),x.data(),localfieldsize());
-	return *this;
-}
-//====================================================================================
 FitsBase * FitsBase::make(const FITS::ValueType &type,int n) {
 	switch (type) {
 	    case FITS::LOGICAL: return (new FitsField<FitsLogical> (n));
