@@ -31,7 +31,7 @@
 #include <casacore/casa/Arrays/Matrix.h>
 #include <casacore/scimath/Mathematics/GaussianBeam.h>
 //#include <casacore/measures/Measures/Stokes.h>
-//#include <map>
+#include <map>
 
 namespace casacore {
 
@@ -271,6 +271,15 @@ public:
     // it falls in the range -90 to 90 degrees before setting it.
     void rotate(const Quantity& angle, Bool unwrap=False);
 
+    // get all the beam areas in a single quantum matrix.
+    const Quantum<Matrix<double>> getAreas() const;
+
+    // get all the major axes, minor axes, and pas in quantum matrices.
+    // The returned map has keys "major", "minor", and "pa". 
+    const std::map<String, Quantum<Matrix<double>>> paramMatrices(
+        const Unit& majminUnit=Unit("arcsec"), const Unit& paUnit="deg"
+    ) const;
+
 private:
 
     static const String _DEFAULT_AREA_UNIT;
