@@ -250,7 +250,7 @@ namespace casacore { //# NAMESPACE CASACORE - BEGIN
           success = False;
         }
       }
-      catch(const AipsError& x){
+      catch(const std::exception& x){
         if(whichHDU>=0){
           throw(x);
         }
@@ -758,8 +758,8 @@ namespace casacore { //# NAMESPACE CASACORE - BEGIN
           } else {
             msg = "Cannot remove file - unknown file type";
           }
-        } catch (AipsError& x) {
-          msg = x.getMesg();
+        } catch (std::exception& x) {
+          msg = x.what();
         }
         //
         if (outFile.exists()) {
@@ -1493,7 +1493,7 @@ namespace casacore { //# NAMESPACE CASACORE - BEGIN
       //
       if (pMeter) delete pMeter;
     }
-    catch (const AipsError& x) {
+    catch (const std::exception& x) {
       error = "Unknown error copying image to FITS file";
       if (outfile) {
         delete outfile;
