@@ -32,6 +32,7 @@
 
 #include <casacore/casa/aips.h>
 #include <casacore/fits/FITS/fits.h>
+#include <casacore/casa/Arrays/ArrayFwd.h>
 #include <casacore/casa/Arrays/IPosition.h>
 #include <casacore/casa/BasicSL/String.h>
 #include <casacore/casa/Utilities/DataType.h>
@@ -46,7 +47,6 @@ namespace casacore { //# NAMESPACE CASACORE - BEGIN
 
   template<class T> class PagedImage;
   template<class T> class ImageInterface;
-  template<class T> class Vector;
   class FitsOutput;
   class File;
   class ImageInfo;
