@@ -315,8 +315,8 @@ try {
 //
     delete pIm;
     cout << "OK" << endl;
-} catch (AipsError& x) {
-     cerr << "aipserror: error " << x.getMesg() << endl;
+} catch (std::exception& x) {
+     cerr << "aipserror: error " << x.what() << endl;
      return 1;
 } 
 
