@@ -41,7 +41,7 @@
 #include <casacore/casa/Arrays/Vector.h>
 #include <casacore/casa/Arrays/ArrayMath.h>
 #include <casacore/casa/Arrays/ArrayLogical.h>
-#include <casacore/casa/Arrays/ArrayIO.h>
+#include <casacore/casa/IO/ArrayIO.h>
 #include <casacore/casa/Arrays/IPosition.h>
 #include <casacore/casa/Utilities/PtrHolder.h>
 #include <casacore/casa/Utilities/Assert.h>
@@ -373,8 +373,8 @@ int main ()
     // test per plane beams
     testBeams();
   }
-  catch (AipsError& x) {
-    cerr << "Caught exception: " << x.getMesg() << endl;
+  catch (std::exception& x) {
+    cerr << "Caught exception: " << x.what() << endl;
     cout << "FAIL" << endl;
     return 1;
   } 
