@@ -249,8 +249,8 @@ try {
       try {
          LCRegion* pLCRegion = box3.toLCRegion(cSys2, shape2);
          if (pLCRegion != 0) delete pLCRegion;
-      } catch (AipsError& x) {
-//         cout << "aipserror: caught error " << x.getMesg() << endl;
+      } catch (std::exception& x) {
+//         cout << "aipserror: caught error " << x.what() << endl;
          ok = True;
       } 
       if (!ok) {
@@ -279,8 +279,8 @@ try {
       try {
          pLCRegion =  box.toLCRegion(cSys2, shape);
          if (pLCRegion != 0) delete pLCRegion;
-      } catch (AipsError& x) {
-//         cout << "aipserror: caught error " << x.getMesg() << endl;
+      } catch (std::exception& x) {
+//         cout << "aipserror: caught error " << x.what() << endl;
          ok = True;
       } 
       if (!ok) {
@@ -346,7 +346,7 @@ try {
       cSys2.removeWorldAxis(wSpec, cSys.referenceValue()(wSpec));
 //
       IPosition shape2(cSys2.nPixelAxes(),10);
-      for (uInt i=0; i<min(shape.nelements(),shape2.nelements()); i++) {
+      for (uInt i=0; i<std::min(shape.nelements(),shape2.nelements()); i++) {
          shape2(i) = shape(i);
       }
       LCRegion* pLCRegion = 0;
@@ -374,8 +374,8 @@ try {
       try {
          pLCRegion = box1.toLCRegion(cSys2, shape2);
          if (pLCRegion != 0) delete pLCRegion;
-       } catch (AipsError& x) {
-//          cout << "aipserror: caught error " << x.getMesg() << endl;
+       } catch (std::exception& x) {
+//          cout << "aipserror: caught error " << x.what() << endl;
           ok = True;
        } 
       if (!ok) {
@@ -401,8 +401,8 @@ try {
 //         cout << "toLCRegion called with shape = " << shape2 << endl;
          pLCRegion = box1.toLCRegion(cSys2, shape2);
          if (pLCRegion != 0) delete pLCRegion;
-      } catch (AipsError& x) {
-//         cout << "aipserror: caught expected error " << x.getMesg() << endl;
+      } catch (std::exception& x) {
+//         cout << "aipserror: caught expected error " << x.what() << endl;
          ok = True;
       } 
       if (!ok) { 
@@ -450,8 +450,8 @@ try {
 //   cout << endl;
 
 
-} catch (AipsError& x) {
-      cerr << "aipserror: error " << x.getMesg() << endl;
+} catch (std::exception& x) {
+      cerr << "aipserror: error " << x.what() << endl;
       cout << "not ok" << endl; 
       return 1;
 }
