@@ -28,7 +28,7 @@
 #include <casacore/lattices/LRegions/LCEllipsoid.h>
 #include <casacore/tables/Tables/TableRecord.h>
 #include <casacore/casa/Arrays/ArrayMath.h>
-#include <casacore/casa/Arrays/ArrayIO.h>
+#include <casacore/casa/IO/ArrayIO.h>
 #include <casacore/casa/BasicSL/Constants.h>
 #include <casacore/casa/Exceptions/Error.h>
 #include <casacore/casa/Utilities/Assert.h>
