@@ -28,7 +28,7 @@
 #include <casacore/lattices/LRegions/LCComplement.h>
 #include <casacore/lattices/LRegions/LCBox.h>
 #include <casacore/lattices/LRegions/LCEllipsoid.h>
-#include <casacore/casa/Arrays/ArrayIO.h>
+#include <casacore/casa/IO/ArrayIO.h>
 #include <casacore/casa/Arrays/ArrayLogical.h>
 #include <casacore/casa/Arrays/IPosition.h>
 #include <casacore/tables/Tables/TableRecord.h>
@@ -124,8 +124,8 @@ int main()
 	doIt (IPosition (2,10,20),
 	      IPosition (2,3,4), IPosition (2,7,8),
 	      IPosition (2,4,16), 5.);
-    } catch (AipsError& x) {
-	cout << "Caught exception: " << x.getMesg() << endl;
+    } catch (std::exception& x) {
+	cout << "Caught exception: " << x.what() << endl;
 	return 1;
     } 
     cout << "OK" << endl;
