@@ -50,132 +50,6 @@
 
 namespace casacore { //# NAMESPACE CASACORE - BEGIN
 
-void LattStatsSpecialize::accumulate (
-		Double& nPts, Double& sum,
-		Double& mean, Double& nvariance,Double& variance,
-		Double& sumSq, Float& dataMin,
-		Float& dataMax, Int& minPos,
-		Int& maxPos, Bool& minMaxInit,
-		const Bool fixedMinMax, const Float datum,
-		const uInt& pos, const Float useIt
-) {
-	if (useIt < 0) {
-		return;
-	}
-
-	nPts += 1.0;
-	sum += datum;
-	sumSq += datum*datum;
-
-	Double prevMean = mean;
-	mean += (datum - prevMean)/nPts;
-	nvariance += (datum - prevMean)*(datum - mean);
-	variance = (nPts == 1) ? 0 : nvariance/(nPts-1);
-
-	// If fixedMinMax, then the min and max will always
-	// be given by the inclusion range that the user specified.
-	// This will be set outside of here.  We have no
-	// more work to do if so.
-
-	if (fixedMinMax) {
-		return;
-	}
-
-	// Set min and max
-
-	if (minMaxInit) {
-		dataMin = datum;
-		dataMax = datum;
-		minPos = pos;
-		maxPos = pos;
-		minMaxInit = False;
-	}
-	else {
-		if (datum < dataMin) {
-			dataMin = datum;
-			minPos = pos;
-		}
-		if (datum > dataMax) {
-			dataMax = datum;
-			maxPos = pos;
-		}
-	}
-}
-
-void LattStatsSpecialize::accumulate (
-	DComplex& nPts, DComplex& sum,
-	DComplex& mean, DComplex& nvariance, DComplex& variance,
-	DComplex& sumSq, Complex& dataMin,
-	Complex& dataMax, const Int&,
-	const Int&, Bool& minMaxInit,
-	const Bool fixedMinMax, const Complex datum,
-	const uInt&, const Complex useIt
-) {
-	// note the position of the maximum and minimum were not determined in the previous
-	// version of this function and so are not here. It is not clear of what value the
-	// min and max calculated in this method are, but I preserved that from the
-	// previous incarnation -- dmehring 2011mar01
-
-	const Float rd = real(datum);
-	const Float id = imag(datum);
-	const Double rm = real(mean);
-	const Double im = imag(mean);
-
-	if (real(useIt) > 0.5) {
-		nPts += Complex(1.0, 0.0);
-		sum += DComplex(rd, 0.0);
-		sumSq += DComplex(rd*rd, 0.0);
-		Double prevMean = rm;
-		Double rn = real(nPts);
-		mean += DComplex((rd - prevMean)/rn, 0);
-		nvariance += DComplex((rd - prevMean)*(rd - real(mean)), 0);
-		variance = (rn <= 1) ? 0 : DComplex(real(nvariance)/(rn-1), imag(variance));
-	}
-	if (imag(useIt) > 0.5) {
-		nPts += Complex(0.0, 1.0);
-		sum += DComplex(0.0, id);
-		sumSq += DComplex(0.0, id*id);
-		Double prevMean = im;
-		Double in = imag(nPts);
-		mean += DComplex(0, (id - prevMean)/in);
-		nvariance += DComplex(0, (id - prevMean)*(id - imag(mean)));
-		variance = (in <= 1) ? 0 : DComplex(real(variance), imag(nvariance)/(in-1));
-	}
-
-	// If fixedMinMax, then the min and max will always
-	// be given by the inclusion range that the user specified.
-	// This will be set outside of here.  We have no
-	// more work to do if so.
-
-	if (fixedMinMax) return;
-
-	// Set min and max
-
-	if (minMaxInit) {
-		dataMin = datum;
-		dataMax = datum;
-		minMaxInit = False;
-	}
-	else {
-		if (real(useIt) > 0.5) {
-			if (rd < real(dataMin)) {
-				dataMin = Complex(rd, dataMin.imag());
-			}
-			if (rd > real(dataMax)) {
-				dataMax = Complex(rd, dataMax.imag());
-			}
-		}
-		if (imag(useIt) > 0.5) {
-			if (id < imag(dataMin)) {
-				dataMin = Complex(dataMin.real(), id);
-			}
-			if (id > imag(dataMax)) {
-				dataMax = Complex(dataMax.real(), id);
-			}
-		}
-	}
-}
-
 Double LattStatsSpecialize::getMean (Double sum, Double n)
 {
    Double tmp = 0.0;
