@@ -178,8 +178,8 @@ int main() {
     }
     cout<< "OK"<< endl;
     return 0;
-  } catch (AipsError& x) {
-    cerr << x.getMesg() << endl;
+  } catch (std::exception& x) {
+    cerr << x.what() << endl;
     cout<< "FAIL"<< endl;
   } 
 }
