@@ -31,6 +31,7 @@
 
 //# Includes
 #include <casacore/casa/aips.h>
+#include <casacore/casa/Arrays/ArrayFwd.h>
 #include <casacore/lattices/Lattices/LatticeBase.h>
 #include <casacore/casa/Arrays/Slicer.h>
 
@@ -39,7 +40,6 @@ namespace casacore { //# NAMESPACE CASACORE - BEGIN
 //# Forward Declarations
 class IPosition;
 class LatticeNavigator;
-template <class T> class Array;
 template <class T> class COWPtr;
 template <class Domain, class Range> class Functional;
 template <class T> class LatticeIterInterface;
