@@ -241,8 +241,8 @@ int main(int argc, const char* argv[])
       pa.showCacheStatistics (cout);
       pa.clearCache();
     }
-  } catch (AipsError& x) {
-    cerr << x.getMesg() << endl;
+  } catch (std::exception& x) {
+    cerr << x.what() << endl;
     cout << "FAIL" << endl;
     return 1;
   } 
