@@ -64,18 +64,18 @@ void testVectorROIter (const Lattice<Int>& lattice, Bool useRef)
         Matrix<Int> temp(iter.matrixCursor());
         throw(AipsError("tLatticeIterator - "
                         "matrixCursor worked where it should not have"));
-    } catch (AipsError& x) {
-        if (!x.getMesg().contains("two non-degenerate")) {
-	    throw (AipsError (x.getMesg()));
+    } catch (std::exception& x) {
+        if (!String(x.what()).contains("two non-degenerate")) {
+	    throw (AipsError (x.what()));
         }
     } 
     try {
         Cube<Int> temp(iter.cubeCursor());
         throw(AipsError("tLatticeIterator - "
                         "cubeCursor worked where it should not have"));
-    } catch (AipsError& x) {
-        if (!x.getMesg().contains("three non-degenerate")) {
-	    throw (AipsError (x.getMesg()));
+    } catch (std::exception& x) {
+        if (!String(x.what()).contains("three non-degenerate")) {
+	    throw (AipsError (x.what()));
         }
     } 
     AlwaysAssert(latticeShape == iter.latticeShape(), AipsError);
@@ -128,18 +128,18 @@ void testMatrixROIter (const Lattice<Int>& lattice, Bool useRef)
         Vector<Int> temp(iter.vectorCursor());
         throw(AipsError("tLatticeIterator - "
                         "vectorCursor worked where it should not have"));
-    } catch (AipsError& x) {
-        if (!x.getMesg().contains("one non-degenerate")) {
-	    throw (AipsError (x.getMesg()));
+    } catch (std::exception& x) {
+        if (!String(x.what()).contains("one non-degenerate")) {
+	    throw (AipsError (x.what()));
         }
     } 
     try {
         Cube<Int> temp(iter.cubeCursor());
         throw(AipsError("tLatticeIterator - "
                         "cubeCursor worked where it should not have"));
-    } catch (AipsError& x) {
-        if (!x.getMesg().contains("three non-degenerate")) {
-	    throw (AipsError (x.getMesg()));
+    } catch (std::exception& x) {
+        if (!String(x.what()).contains("three non-degenerate")) {
+	    throw (AipsError (x.what()));
         }
     } 
     Timer clock;
@@ -193,18 +193,18 @@ void testCubeROIter (const Lattice<Int>& lattice, Bool useRef)
         Vector<Int> temp(iter.vectorCursor());
         throw(AipsError("tLatticeIterator - "
                         "vectorCursor worked where it should not have"));
-    } catch (AipsError& x) {
-        if (!x.getMesg().contains("one non-degenerate")) {
-	    throw (AipsError (x.getMesg()));
+    } catch (std::exception& x) {
+        if (!String(x.what()).contains("one non-degenerate")) {
+	    throw (AipsError (x.what()));
         }
     } 
     try {
         Matrix<Int> temp(iter.matrixCursor());
         throw(AipsError("tLatticeIterator - "
                         "matrixCursor worked where it should not have"));
-    } catch (AipsError& x) {
-        if (!x.getMesg().contains("two non-degenerate")) {
-	    throw (AipsError (x.getMesg()));
+    } catch (std::exception& x) {
+        if (!String(x.what()).contains("two non-degenerate")) {
+	    throw (AipsError (x.what()));
         }
     } 
     Timer clock;
@@ -252,27 +252,27 @@ void testArrayROIter (const Lattice<Int>& lattice, Bool useRef)
         Vector<Int> temp(iter.vectorCursor());
         throw(AipsError("tLatticeIterator - "
                         "vectorCursor worked where it should not have"));
-    } catch (AipsError& x) {
-        if (!x.getMesg().contains("one non-degenerate")) {
-	    throw (AipsError (x.getMesg()));
+    } catch (std::exception& x) {
+        if (!String(x.what()).contains("one non-degenerate")) {
+	    throw (AipsError (x.what()));
         }
     } 
     try {
         Matrix<Int> temp(iter.matrixCursor());
         throw(AipsError("tLatticeIterator - "
                         "matrixCursor worked where it should not have"));
-    } catch (AipsError& x) {
-        if (!x.getMesg().contains("two non-degenerate")) {
-	    throw (AipsError (x.getMesg()));
+    } catch (std::exception& x) {
+        if (!String(x.what()).contains("two non-degenerate")) {
+	    throw (AipsError (x.what()));
         }
     } 
     try {
         Cube<Int> temp(iter.cubeCursor());
         throw(AipsError("tLatticeIterator - "
                         "cubeCursor worked where it should not have"));
-    } catch (AipsError& x) {
-        if (!x.getMesg().contains("three non-degenerate")) {
-	    throw (AipsError (x.getMesg()));
+    } catch (std::exception& x) {
+        if (!String(x.what()).contains("three non-degenerate")) {
+	    throw (AipsError (x.what()));
         }
     } 
     Timer clock;
@@ -320,18 +320,18 @@ void test8ElemROIter (const Lattice<Int>& lattice, Bool useRef)
         Matrix<Int> temp(iter.matrixCursor());
         throw(AipsError("tLatticeIterator - "
                         "matrixCursor worked where it should not have"));
-    } catch (AipsError& x) {
-        if (!x.getMesg().contains("two non-degenerate")) {
-	    throw (AipsError (x.getMesg()));
+    } catch (std::exception& x) {
+        if (!String(x.what()).contains("two non-degenerate")) {
+	    throw (AipsError (x.what()));
         }
     } 
     try {
         Cube<Int> temp(iter.cubeCursor());
         throw(AipsError("tLatticeIterator - "
                         "cubeCursor worked where it should not have"));
-    } catch (AipsError& x) {
-        if (!x.getMesg().contains("three non-degenerate")) {
-	    throw (AipsError (x.getMesg()));
+    } catch (std::exception& x) {
+        if (!String(x.what()).contains("three non-degenerate")) {
+	    throw (AipsError (x.what()));
         }
     } 
     Timer clock;
@@ -624,18 +624,18 @@ void testVectorRWIter (Lattice<Int>& lattice, Bool useRef)
         Matrix<Int> temp(iter.matrixCursor());
         throw(AipsError("tLatticeIterator - "
                         "matrixCursor worked where it should not have"));
-    } catch (AipsError& x) {
-        if (!x.getMesg().contains("two non-degenerate")) {
-	    throw (AipsError (x.getMesg()));
+    } catch (std::exception& x) {
+        if (!String(x.what()).contains("two non-degenerate")) {
+	    throw (AipsError (x.what()));
         }
     } 
     try {
         Cube<Int> temp(iter.cubeCursor());
         throw(AipsError("tLatticeIterator - "
                         "cubeCursor worked where it should not have"));
-    } catch (AipsError& x) {
-        if (!x.getMesg().contains("three non-degenerate")) {
-	    throw (AipsError (x.getMesg()));
+    } catch (std::exception& x) {
+        if (!String(x.what()).contains("three non-degenerate")) {
+	    throw (AipsError (x.what()));
         }
     } 
     
@@ -692,18 +692,18 @@ void testMatrixRWIter (Lattice<Int>& lattice, Bool useRef)
         Vector<Int> temp(iter.vectorCursor());
         throw(AipsError("tLatticeIterator - "
                         "vectorCursor worked where it should not have"));
-    } catch (AipsError& x) {
-        if (!x.getMesg().contains("one non-degenerate")) {
-	    throw (AipsError (x.getMesg()));
+    } catch (std::exception& x) {
+        if (!String(x.what()).contains("one non-degenerate")) {
+	    throw (AipsError (x.what()));
         }
     } 
     try {
         Cube<Int> temp(iter.cubeCursor());
         throw(AipsError("tLatticeIterator - "
                         "cubeCursor worked where it should not have"));
-    } catch (AipsError& x) {
-        if (!x.getMesg().contains("three non-degenerate")) {
-	    throw (AipsError (x.getMesg()));
+    } catch (std::exception& x) {
+        if (!String(x.what()).contains("three non-degenerate")) {
+	    throw (AipsError (x.what()));
         }
     } 
     Timer clock;
@@ -757,18 +757,18 @@ void testCubeRWIter (Lattice<Int>& lattice, Bool useRef)
         Vector<Int> temp(iter.vectorCursor());
         throw(AipsError("tLatticeIterator - "
                         "vectorCursor worked where it should not have"));
-    } catch (AipsError& x) {
-        if (!x.getMesg().contains("one non-degenerate")) {
-	    throw (AipsError (x.getMesg()));
+    } catch (std::exception& x) {
+        if (!String(x.what()).contains("one non-degenerate")) {
+	    throw (AipsError (x.what()));
         }
     } 
     try {
         Matrix<Int> temp(iter.matrixCursor());
         throw(AipsError("tLatticeIterator - "
                         "matrixCursor worked where it should not have"));
-    } catch (AipsError& x) {
-        if (!x.getMesg().contains("two non-degenerate")) {
-	    throw (AipsError (x.getMesg()));
+    } catch (std::exception& x) {
+        if (!String(x.what()).contains("two non-degenerate")) {
+	    throw (AipsError (x.what()));
         }
     } 
     Timer clock;
@@ -816,27 +816,27 @@ void testArrayRWIter (Lattice<Int>& lattice, Bool useRef)
         Vector<Int> temp(iter.vectorCursor());
         throw(AipsError("tLatticeIterator - "
                         "vectorCursor worked where it should not have"));
-    } catch (AipsError& x) {
-        if (!x.getMesg().contains("one non-degenerate")) {
-	    throw (AipsError (x.getMesg()));
+    } catch (std::exception& x) {
+        if (!String(x.what()).contains("one non-degenerate")) {
+	    throw (AipsError (x.what()));
         }
     } 
     try {
         Matrix<Int> temp(iter.matrixCursor());
         throw(AipsError("tLatticeIterator - "
                         "matrixCursor worked where it should not have"));
-    } catch (AipsError& x) {
-        if (!x.getMesg().contains("two non-degenerate")) {
-	    throw (AipsError (x.getMesg()));
+    } catch (std::exception& x) {
+        if (!String(x.what()).contains("two non-degenerate")) {
+	    throw (AipsError (x.what()));
         }
     } 
     try {
         Cube<Int> temp(iter.cubeCursor());
         throw(AipsError("tLatticeIterator - "
                         "cubeCursor worked where it should not have"));
-    } catch (AipsError& x) {
-        if (!x.getMesg().contains("three non-degenerate")) {
-	    throw (AipsError (x.getMesg()));
+    } catch (std::exception& x) {
+        if (!String(x.what()).contains("three non-degenerate")) {
+	    throw (AipsError (x.what()));
         }
     } 
     Timer clock;
@@ -1271,8 +1271,8 @@ int main (int argc, const char* argv[])
       pagedArr.put (savarr);
       testNonCongruentRWIter (pagedArr, True);
     }
-  } catch (AipsError& x) {
-    cerr << "Caught exception: " << x.getMesg() << endl;
+  } catch (std::exception& x) {
+    cerr << "Caught exception: " << x.what() << endl;
     cout << "FAIL" << endl;
     return 1;
   } 
@@ -1441,8 +1441,8 @@ int main (int argc, const char* argv[])
       testAdd (latArr1, pagedArr2, True);
       AlwaysAssert (allEQ(latArr1.get(), 13*arr), AipsError);
     }      
-  } catch (AipsError& x) {
-    cerr << "Caught exception: " << x.getMesg() << endl;
+  } catch (std::exception& x) {
+    cerr << "Caught exception: " << x.what() << endl;
     cout << "FAIL" << endl;
     return 1;
   } 
