@@ -256,7 +256,7 @@ void testAxes()
       Bool exc = False;
       try {
 	ml2.setPixelMask (ArrayLattice<Bool>(pm2), False);
-      } catch (AipsError& x) {
+      } catch (std::exception& x) {
 	exc = True;
       }
       AlwaysAssertExit (exc);
@@ -454,8 +454,8 @@ int main (int argc, const char* argv[])
                    IPosition(3, 1, 5, 11),
                    AipsError);
     }
-  } catch (const AipsError& x) {
-    cerr << "Caught exception: " << x.getMesg() << endl;
+  } catch (const std::exception& x) {
+    cerr << "Caught exception: " << x.what() << endl;
     cout << "FAIL" << endl;
     return 1;
   } 
