@@ -36,7 +36,7 @@
 #include <casacore/measures/Measures/MeasConvert.h>
 #include <casacore/tables/TaQL/TableParse.h>
 #include <casacore/casa/Arrays/ArrayLogical.h>
-#include <casacore/casa/Arrays/ArrayIO.h>
+#include <casacore/casa/IO/ArrayIO.h>
 #include <casacore/casa/Quanta/MVTime.h>
 #include <iostream>
 
