@@ -170,7 +170,6 @@ class MBaseline : public MeasBase<MVBaseline, MeasRef<MBaseline> > {
 // <group>
     virtual const String &tellMe() const;
     static const String &showMe();
-    virtual uInt type() const;
     static void assure(const Measure &in);
 // </group>
   // Translate reference code. The uInt version has a check for valid codes
@@ -221,8 +220,6 @@ class MBaseline : public MeasBase<MVBaseline, MeasRef<MBaseline> > {
   // </group>
   // Get the reference type (for records, including codes like R_)
   virtual String getRefString() const;
-  // Get my type (as Register)
-  static uInt myType();
 
 // Get Measure data
 // <group>
