@@ -36,7 +36,8 @@
 #include <casacore/measures/Measures/MCBase.h>
 #include <casacore/measures/Measures/MConvertBase.h>
 #include <casacore/measures/Measures/MDoppler.h>
-#include <casacore/casa/OS/Mutex.h>
+
+#include <mutex>
 
 namespace casacore { //# NAMESPACE CASACORE - BEGIN
 
@@ -146,7 +147,7 @@ private:
   // Transition matrix
   static uInt FromTo_p[MDoppler::N_Types][MDoppler::N_Types];
   // Object to ensure safe multi-threaded lazy single initialization
-  static CallOnce0 theirInitOnce;
+  static std::once_flag theirInitOnceFlag;
 
   //# Member functions
   
