@@ -54,13 +54,13 @@ uInt MCFrequency::ToRef_p[N_Routes][3] = {
   {MFrequency::REST,	MFrequency::LSRK,	3},
   {MFrequency::LSRK,	MFrequency::REST,	3} };
 uInt MCFrequency::FromTo_p[MFrequency::N_Types][MFrequency::N_Types];
-CallOnce0 MCFrequency::theirInitOnce;
+std::once_flag MCFrequency::theirInitOnceFlag;
 
 
 //# Constructors
 MCFrequency::MCFrequency() :
   MVPOS1(0), MVDIR1(0), ABERFROM(0), ABERTO(0) {
-    theirInitOnce(doFillState);
+    std::call_once(theirInitOnceFlag, doFillState);
 }
 
 //# Destructor
@@ -353,7 +353,7 @@ void MCFrequency::doConvert(MVFrequency &in,
 }
 
 String MCFrequency::showState() {
-  theirInitOnce(doFillState);
+  std::call_once(theirInitOnceFlag, doFillState);
   return MCBase::showState(MCFrequency::FromTo_p[0],
 			   MFrequency::N_Types, MCFrequency::N_Routes,
 			   MCFrequency::ToRef_p);
