@@ -36,7 +36,6 @@
 #include <casacore/measures/Measures/MCBase.h>
 #include <casacore/measures/Measures/MConvertBase.h>
 #include <casacore/measures/Measures/MFrequency.h>
-#include <casacore/casa/OS/Mutex.h>
 
 namespace casacore { //# NAMESPACE CASACORE - BEGIN
 
@@ -154,7 +153,7 @@ private:
   // Transition matrix
   static uInt FromTo_p[MFrequency::N_Types][MFrequency::N_Types];
   // Object to ensure safe multi-threaded lazy single initialization
-  static CallOnce0 theirInitOnce;
+  static std::once_flag theirInitOnceFlag;
 
   //# Constructors
   // Copy constructor (not implemented)
