@@ -32,7 +32,6 @@
 #include <casacore/casa/Quanta/MVFrequency.h>
 #include <casacore/casa/Quanta/Quantum.h>
 #include <casacore/casa/Utilities/Assert.h>
-#include <casacore/casa/Utilities/Register.h>
 
 namespace casacore { //# NAMESPACE CASACORE - BEGIN
 
@@ -79,12 +78,8 @@ const String &MDoppler::showMe() {
     return name;
 }
 
-uInt MDoppler::type() const {
-  return Register(static_cast<MDoppler *>(0));
-}
-
 void MDoppler::assure(const Measure &in) {
-  if (in.type() != Register(static_cast<MDoppler *>(0))) {
+  if (!dynamic_cast<const MDoppler*>(&in)) {
     throw(AipsError("Illegal Measure type argument: " +
 		    MDoppler::showMe()));
   }
@@ -197,7 +192,7 @@ Bool MDoppler::giveMe(MDoppler::Ref &mr, const String &in) {
 }
 
 Bool MDoppler::setOffset(const Measure &in) {
-  if (in.type() != Register(static_cast<MDoppler *>(0))) return False;
+  if (!dynamic_cast<const MDoppler*>(&in)) return False;
   ref.set(in);
   return True;
 }
@@ -219,9 +214,6 @@ const String &MDoppler::getDefaultType() const {
 String MDoppler::getRefString() const {
   return MDoppler::showType(ref.getType());
 }
-uInt MDoppler::myType() {
-  return Register(static_cast<MDoppler *>(0));
-}
 
 Quantity MDoppler::get(const Unit &un) const {
     return data.get(un);
