@@ -209,7 +209,6 @@ class MEarthMagnetic : public MeasBase<MVEarthMagnetic, MeasRef<MEarthMagnetic>
   // <group>
   virtual const String &tellMe() const;
   static const String &showMe();
-  virtual uInt type() const;
   static void assure(const Measure &in);
   // </group>
   // Translate reference code. The uInt version has a check for valid codes
@@ -255,8 +254,6 @@ class MEarthMagnetic : public MeasBase<MVEarthMagnetic, MeasRef<MEarthMagnetic>
   // </group>
   // Get the reference type (for records, including codes like R_)
   virtual String getRefString() const;
-  // Get my type (as Register)
-  static uInt myType();
   // Tell me if you are a pure model (e.g. a planet)
   virtual Bool isModel() const;
   
