@@ -29,7 +29,7 @@
 #include <casacore/casa/aips.h>
 #include <casacore/casa/Exceptions/Error.h>
 #include <casacore/casa/Arrays/ArrayMath.h>
-#include <casacore/casa/Arrays/ArrayIO.h>
+#include <casacore/casa/IO/ArrayIO.h>
 #include <casacore/casa/Arrays/Vector.h>
 #include <casacore/casa/BasicSL/Constants.h>
 #include <casacore/casa/Quanta/MVAngle.h>
@@ -257,8 +257,8 @@ int main()
     conB1950(b1950, j2000, 1979.9, &frame);
     conB1950(b1950, j2000, 2000.0, &frame);
 
-  } catch (AipsError& x) {
-    cout << x.getMesg() << endl;
+  } catch (std::exception& x) {
+    cout << x.what() << endl;
   } 
     
   return(0);
