@@ -210,6 +210,12 @@ int main()
 	    " to " << tgsref << endl <<
 		" as " << tconv6() << endl;
 
+    {
+        MDirection j2000;
+        bool success = j2000.setRefString("J2000 ");
+        cout << boolalpha << success << endl;
+    }
+
     {	
 	MeasFrame b1900((MEpoch(Quantity(MeasData::MJDB1900,"d"))));
 	MDirection lsr1900(Quantity(270,"deg"),
@@ -398,8 +404,8 @@ int main()
 	
     };	
 
-    } catch (AipsError& x) {
-	cout << x.getMesg() << endl;
+    } catch (std::exception& x) {
+	cout << x.what() << endl;
     } 
 
     try {
@@ -412,8 +418,8 @@ int main()
         MeasFrame mftbm(tbm);
 	cout << mftbm << endl;
 
-    } catch (AipsError& x) {
-	cout << x.getMesg() << endl;
+    } catch (std::exception& x) {
+	cout << x.what() << endl;
     } 
 
     try {
@@ -724,9 +730,9 @@ int main()
 	    MFrequency::showType(MFrequency::Undefined) << " should not be possible." << endl;
 	  isok = False;
 	}
-	catch(const AipsError& x){
+	catch(const std::exception& x){
 	  // expected error
-	  cout << x.getMesg() << endl;
+	  cout << x.what() << endl;
 	}
         try {
 	  MFrequency::Convert backw;
@@ -736,9 +742,9 @@ int main()
 	  cout << MFrequency::showType(MFrequency::Undefined) << " to " <<
 	    MFrequency::showType(i) << " should not be possible." << endl;
 	}
-	catch(const AipsError& x){
+	catch(const std::exception& x){
 	  // expected error
-	  cout << x.getMesg() << endl;
+	  cout << x.what() << endl;
 	}
 	  
       };
@@ -819,8 +825,8 @@ int main()
       };
     }
 
-    } catch (AipsError& x) {
-      cout << x.getMesg() << endl;
+    } catch (std::exception& x) {
+      cout << x.what() << endl;
     } 
 
     return 0;
