@@ -103,8 +103,8 @@ int main() {
         }
         cout << "OK" << endl;
     } 
-    catch (const AipsError& x) {
-    	cerr << "Exception : " << x.getMesg() << endl;
+    catch (const std::exception& x) {
+    	cerr << "Exception : " << x.what() << endl;
     	return 1;
     }
     return 0;
