@@ -53,7 +53,7 @@ namespace casacore { //# NAMESPACE CASACORE - BEGIN
     virtual void init(const Table& msLikeTable) {table_p=&msLikeTable;}
     const Table* table()                      {return table_p;}
     virtual const ArrayColumn<Bool>& flag() = 0;
-    virtual Bool flagRow(const Int& i) = 0;
+    virtual Bool flagRow(rownr_t i) = 0;
     virtual const ScalarQuantColumn<Double>& exposureQuant() = 0;
     virtual const ScalarQuantColumn<Double>& timeQuant() = 0;
     virtual const MeasurementSet *asMS() = 0;
@@ -76,7 +76,7 @@ namespace casacore { //# NAMESPACE CASACORE - BEGIN
     virtual const ArrayColumn<Bool>& flag() {return msCols_p->flag();}
 
     //    virtual Bool flagRow(const Int& i) {return allTrue(msCols_p->flag()(i));}
-    virtual Bool flagRow(const Int& i) {return msCols_p->flagRow()(i);}
+    virtual Bool flagRow(rownr_t i) {return msCols_p->flagRow()(i);}
     virtual const ScalarQuantColumn<Double>& exposureQuant() {return msCols_p->exposureQuant();}
     virtual const ScalarQuantColumn<Double>& timeQuant()     {return msCols_p->timeQuant();}
 
