@@ -94,7 +94,7 @@ public:
     MSHistory (const String &tableName, TableOption = Table::Old);
     MSHistory (const String &tableName, const String &tableDescName,
 		    TableOption = Table::Old);
-    MSHistory (SetupNewTable &newTab, uInt nrrow = 0, Bool initialize = False);
+    MSHistory (SetupNewTable &newTab, rownr_t nrrow = 0, Bool initialize = False);
     MSHistory (const Table &table);
     MSHistory (const MSHistory &other);
     // </group>
