@@ -203,6 +203,15 @@ public:
   // functions used to group the iterations are given explicitly, making
   // the constructor more generic. Also, the column is specified as a string,
   // to support sorting by columns not part of the standard MS definition.
+  // Note that with this constructor TIME is not treated in any special way and
+  // there are no default sorting columns, i.e., the sorting needs have to be
+  // set explicitly.
+  // The last element in vector sortColumns will be the column that will change
+  // faster in the iteration loop, whereas the first element will be the slower.
+  // For instance, if sortColumns[0].first = "DATA_DESC_ID" nad
+  // sortColumns[1].first = "ANTENNA1" then the first iterations will go through
+  // all possible values of ANTENNA1 for the first DDId, then it will start
+  // the iterations for the second DDId and so on.
   MSIter(const MeasurementSet& ms,
          const std::vector<std::pair<String, CountedPtr<BaseCompare>>>& sortColumns);
 
@@ -382,7 +391,7 @@ public:
   //phasecenters, i.e time varying for a given field_id..
   //If the iterator is set so as one iteration has more that 1 time stamp
   //then this version is correct only for fixed phasecenters
-  const MDirection& phaseCenter() const ;
+  const MDirection& phaseCenter() const;
 
   //If the iterator is set so as one iteration has more that 1 value of time stamp
   // or fieldid
@@ -404,9 +413,16 @@ protected:
   virtual void setState();
   void setMSInfo();
   void setArrayInfo();
-  void setFeedInfo();
-  void setDataDescInfo();
-  void setFieldInfo();
+  void setFeedInfo() const;
+  // Store the current DD, SPW, Pol ID.
+  // It can be called in logically const objects although it modifies
+  // caching (mutable) variables for performance reasons.
+  void cacheCurrentDDInfo() const;
+  // Store extra info related to the DD.
+  // It can be called in logically const objects although it modifies
+  // caching (mutable) variables for performance reasons.
+  void cacheExtraDDInfo() const;
+  void setFieldInfo() const;
 
 // Determine if the numbers in r1 are a sorted subset of those in r2
   Bool isSubSet(const Vector<rownr_t>& r1, const Vector<rownr_t>& r2);
@@ -424,14 +440,27 @@ protected:
   CountedPtr<MSColumns> msc_p;
   Table curTable_p;
   Int curArrayIdFirst_p, lastArrayId_p, curSourceIdFirst_p;
-  String curFieldNameFirst_p, curSourceNameFirst_p;
-  Int curFieldIdFirst_p, lastFieldId_p;
-  Int curSpectralWindowIdFirst_p, lastSpectralWindowId_p;
-  Int curPolarizationId_p, lastPolarizationId_p;
-  Int curDataDescIdFirst_p, lastDataDescId_p;
+  mutable String curFieldNameFirst_p;
+  String curSourceNameFirst_p;
+  mutable Int curFieldIdFirst_p;
+  Int lastFieldId_p;
+  // These variables point to the current (as in this iteration)
+  // DD, SPW and polarization IDs. They are mutable since they are
+  // evaluated in a lazy way, i.e., only when needed. If the DDId is
+  // part of the sorting columns then it is always computed when calling
+  // next(), otherwise it is only computed when some accesor of
+  // metadata that depends on them is called by the application.
+  mutable Int curDataDescIdFirst_p, curSpectralWindowIdFirst_p,
+    curPolarizationIdFirst_p;
+  // These variables point to the IDs of the previous iteration.
+  Int lastDataDescId_p, lastSpectralWindowId_p, lastPolarizationId_p;
   Bool more_p, newMS_p, newArrayId_p, newFieldId_p, newSpectralWindowId_p,
-    newPolarizationId_p, newDataDescId_p,
-    timeDepFeed_p, spwDepFeed_p, checkFeed_p;
+    newPolarizationId_p, newDataDescId_p;
+  mutable bool spwDepFeed_p, checkFeed_p;
+
+  // Variable to know whether the feed info is already computed
+  mutable bool feedInfoCached_p;
+
 
   // Globally control disk storage of SORTED_TABLE
   Bool storeSorted_p;
@@ -439,32 +468,36 @@ protected:
   // time selection
   Double interval_p;
 
-  // columns
-  ScalarColumn<Int> colArray_p, colDataDesc_p, colField_p;
+  // This column is mutable since it is only attached when it is
+  // neccesary to read the DD Ids. That might happen when calling
+  // a const accesor like dataDescriptionId().
+  mutable ScalarColumn<Int> colDataDesc_p, colField_p;
+  ScalarColumn<Int> colArray_p;
 
-  MDirection phaseCenter_p;
-  Double prevFirstTimeStamp_p;
+  mutable MDirection phaseCenter_p;
+  mutable Double prevFirstTimeStamp_p;
   //cache for access functions
-  Matrix<Double> receptorAnglesFeed0_p; // former receptorAngle_p,
+  mutable Matrix<Double> receptorAnglesFeed0_p; // former receptorAngle_p,
                                    // temporary retained for compatibility
                                    // contain actually a reference to the
 				   // first plane of receptorAngles_p
-  Cube<Double> receptorAngles_p;
-  Vector<SquareMatrix<Complex,2> > CJonesFeed0_p; // a temporary reference
+  mutable Cube<Double> receptorAngles_p;
+  mutable Vector<SquareMatrix<Complex,2> > CJonesFeed0_p; // a temporary reference
                                    // similar to receptorAngle_p
-  Matrix<SquareMatrix<Complex,2> > CJones_p;
+  mutable Matrix<SquareMatrix<Complex,2> > CJones_p;
   Vector<String>  antennaMounts_p; // a string mount identifier for each
                                    // antenna (e.g. EQUATORIAL, ALT-AZ,...)
-  Cube<RigidVector<Double, 2> > beamOffsets_p;// angular offsets (two values for
+  mutable Cube<RigidVector<Double, 2> > beamOffsets_p;// angular offsets (two values for
                                    // each element of the cube in radians)
 				   // in the antenna coordinate system.
 				   // Cube axes are: receptor, antenna, feed.
-  Bool allBeamOffsetsZero_p;       // True if all elements of beamOffsets_p
-                                   // are zero (to speed things up in a
-				   // single beam case)
-  PolFrame polFrame_p;
-  Bool freqCacheOK_p;
-  Vector<Double> frequency_p;
+  mutable Bool allBeamOffsetsZero_p; // True if all elements of beamOffsets_p
+                                     // are zero (to speed things up in a
+				     // single beam case)
+  mutable PolFrame polFrame_p;     // polarization Frame. It is lazily cached,
+                                   // hence mutable. See cacheExtraDDInfo()
+  mutable Bool freqCacheOK_p;      // signal that the frequency cache is fine
+  mutable Vector<Double> frequency_p;
   MFrequency frequency0_p;
   MFrequency restFrequency_p;
   MPosition telescopePosition_p;
@@ -489,31 +522,40 @@ inline const ScalarColumn<Int>& MSIter::colArrayIds() const
 inline const ScalarColumn<Int>& MSIter::colFieldIds() const
 { return colField_p;}
 inline const ScalarColumn<Int>& MSIter::colDataDescriptionIds() const
-{ return colDataDesc_p;}
+{if(curDataDescIdFirst_p==-1) {cacheCurrentDDInfo(); cacheExtraDDInfo();}
+  return colDataDesc_p;}
 inline Int MSIter::arrayId() const {return curArrayIdFirst_p;}
-inline Int MSIter::fieldId() const { return curFieldIdFirst_p;}
+inline Int MSIter::fieldId() const {if(curFieldIdFirst_p==-1) setFieldInfo(); return curFieldIdFirst_p;}
 inline Int MSIter::spectralWindowId() const
-{ return curSpectralWindowIdFirst_p;}
-inline Int MSIter::polarizationId() const {return curPolarizationId_p;}
-inline Int MSIter::dataDescriptionId() const {return curDataDescIdFirst_p;}
+{if(curSpectralWindowIdFirst_p==-1) {cacheCurrentDDInfo(); cacheExtraDDInfo();}
+  return curSpectralWindowIdFirst_p;}
+inline Int MSIter::polarizationId() const
+{if(curPolarizationIdFirst_p==-1) {cacheCurrentDDInfo(); cacheExtraDDInfo();}
+  return curPolarizationIdFirst_p;}
+inline Int MSIter::dataDescriptionId() const
+{if(curDataDescIdFirst_p==-1) {cacheCurrentDDInfo(); cacheExtraDDInfo();}
+  return curDataDescIdFirst_p;}
 inline Bool MSIter::newPolarizationId() const { return newPolarizationId_p;}
 inline Bool MSIter::newDataDescriptionId() const { return newDataDescId_p;}
-inline Int MSIter::polFrame() const { return polFrame_p;}
+inline Int MSIter::polFrame() const
+{if(curPolarizationIdFirst_p==-1) {cacheCurrentDDInfo(); cacheExtraDDInfo();}
+  return polFrame_p;}
 inline const MPosition& MSIter::telescopePosition() const
 { return telescopePosition_p;}
 inline const Vector<SquareMatrix<Complex,2> >& MSIter::CJones() const
-{ return CJonesFeed0_p;}
+{if(!feedInfoCached_p)  setFeedInfo();  return CJonesFeed0_p;}
 inline const Matrix<SquareMatrix<Complex,2> >& MSIter::CJonesAll() const
-{ return CJones_p;}
+{if(!feedInfoCached_p)  setFeedInfo();  return CJones_p;}
 inline const Matrix<Double>& MSIter::receptorAngle() const
-{return receptorAnglesFeed0_p;}
+{if(!feedInfoCached_p)  setFeedInfo();  return receptorAnglesFeed0_p;}
 inline const Cube<Double>& MSIter::receptorAngles() const
-{return receptorAngles_p;}
+{if(!feedInfoCached_p)  setFeedInfo();  return receptorAngles_p;}
 inline const Vector<String>& MSIter::antennaMounts() const
 {return antennaMounts_p;}
 inline const Cube<RigidVector<Double, 2> >& MSIter::getBeamOffsets() const
-{return beamOffsets_p;}
-inline Bool MSIter::allBeamOffsetsZero() const {return allBeamOffsetsZero_p;}
+{if(!feedInfoCached_p)  setFeedInfo();  return beamOffsets_p;}
+inline Bool MSIter::allBeamOffsetsZero() const 
+{if(!feedInfoCached_p)  setFeedInfo();  return allBeamOffsetsZero_p;}
 
 } //# NAMESPACE CASACORE - END
 
