@@ -106,7 +106,7 @@ public:
   // </group>
 
   // Convenience function that returns the number of rows in any of the columns
-  uInt nrow() const {return flagRow_p.nrow();}
+  rownr_t nrow() const {return flagRow_p.nrow();}
 
 protected:
   //# default constructor creates a object that is not usable. Use the attach
