@@ -63,14 +63,14 @@ MSSource::MSSource(const String& tableName, const String &tableDescName,
 			 "table is not a valid MSSource"));
 }
 
-MSSource::MSSource(SetupNewTable &newTab, uInt nrrow,
+MSSource::MSSource(SetupNewTable &newTab, rownr_t nrrow,
 			       Bool initialize)
     : MSTable<MSSourceEnums>(newTab, nrrow, initialize), 
       hasBeenDestroyed_p(False)
 {
     // verify that the now opened table is valid
     if (! validate(this->tableDesc()))
-	throw (AipsError("MSSource(SetupNewTable &, uInt, Bool) - "
+	throw (AipsError("MSSource(SetupNewTable &, rownr_t, Bool) - "
 			 "table is not a valid MSSource"));
 }
 
