@@ -184,7 +184,7 @@ public:
 
   // Convenience function that returns the number of rows in any of the
   // columns. Returns zero if the object is null.
-  uInt nrow() const {return isNull() ? 0 : calibrationGroup_p.nrow();}
+  rownr_t nrow() const {return isNull() ? 0 : calibrationGroup_p.nrow();}
 
   // set the epoch type for the TIME column.
   // <note role=tip>
