@@ -75,8 +75,8 @@ int main() {
         // clean up
         RegularFile(fitsFile).remove();
     }
-    catch (const AipsError& x) {
-        cerr << x.getMesg() << endl;
+    catch (const std::exception& x) {
+        cerr << x.what() << endl;
         cout << "FAIL" << endl;
         return 1;
     }
