@@ -1483,8 +1483,8 @@ int main() {
     }
 
     cout << "---------------------------------------------------" << endl;
-  } catch (AipsError& x) {
-    cout << x.getMesg() << endl;
+  } catch (std::exception& x) {
+    cout << x.what() << endl;
   }
   return 0;
 }
