@@ -127,8 +127,8 @@ int main() {
 		     near(y61(0), y51[0]) &&
 		     near(y61(1), y51[1]) &&
 		     near(y61(2), y51[2]));
-  } catch (AipsError& x) {
-    cout << "Exception : " << x.getMesg() << endl;
+  } catch (std::exception& x) {
+    cout << "Exception : " << x.what() << endl;
   } 
 
   cout << "OK" << endl;
