@@ -35,7 +35,7 @@
 #include <casacore/casa/Arrays/Array.h>
 #include <casacore/casa/Arrays/ArrayMath.h>
 #include <casacore/casa/Arrays/ArrayIter.h> 
-#include <casacore/casa/Arrays/ArrayIO.h> 
+#include <casacore/casa/IO/ArrayIO.h> 
 #include <casacore/casa/BasicSL/Constants.h> 
 #include <casacore/casa/math.h> 
 
