@@ -109,8 +109,8 @@ int main()
 
       cout << " *** end of tHistAcc *** " << endl;  
 
-    } catch (AipsError& x) {
-        cout << x.getMesg() << endl;
+    } catch (std::exception& x) {
+        cout << x.what() << endl;
         return 1;                       // unexpected error
     } 
     return 0;                           // exit with success status
