@@ -455,7 +455,7 @@ int main() {
             try {
                 fh.setCalculateAsAdded(True);
             }
-            catch (AipsError& x) {
+            catch (std::exception& x) {
                 exceptionRaised = True;
             }
             AlwaysAssert(exceptionRaised, AipsError);
@@ -524,7 +524,7 @@ int main() {
             try {
                 fh.setData(v0.begin(), 3, r0);
             }
-            catch (const AipsError& x) {
+            catch (const std::exception& x) {
                 expectedFail = True;
             }
             AlwaysAssert(expectedFail, AipsError);
@@ -1618,7 +1618,7 @@ int main() {
             try {
                 fh.getQuantile(0);
             }
-            catch (const AipsError& x) {
+            catch (const std::exception& x) {
                 thrown = True;
             }
             AlwaysAssert(thrown, AipsError);
@@ -1626,7 +1626,7 @@ int main() {
             try {
                 fh.getQuantile(1);
             }
-            catch (const AipsError& x) {
+            catch (const std::exception& x) {
                 thrown = True;
             }
             AlwaysAssert(thrown, AipsError);
@@ -1961,8 +1961,8 @@ int main() {
             AlwaysAssert(! sd.min, AipsError);
         }
     }
-    catch (const AipsError& x) {
-        cout << x.getMesg() << endl;
+    catch (const std::exception& x) {
+        cout << x.what() << endl;
         return 1;
     } 
     return 0;
