@@ -116,7 +116,7 @@ ISMBase::ISMBase (const String& dataManagerName, const Record& spec)
         checkBucketSize_p = spec.asBool ("CHECKBUCKETSIZE");
     }
     if (spec.isDefined ("PERSCACHESIZE")) {
-        persCacheSize_p = spec.asInt ("PERSCACHESIZE");
+        persCacheSize_p = spec.asuInt ("PERSCACHESIZE");
     }
 }
 
@@ -170,7 +170,7 @@ Record ISMBase::dataManagerSpec() const
 {
   Record rec = getProperties();
   rec.define ("BUCKETSIZE", Int(bucketSize_p));
-  rec.define ("PERSCACHESIZE", Int(persCacheSize_p));
+  rec.define ("PERSCACHESIZE", persCacheSize_p);
   return rec;
 }
 
@@ -216,8 +216,9 @@ void ISMBase::showIndexStatistics (ostream& os)
 void ISMBase::showBucketLayout (ostream& os)
 {
   uInt cursor=0;
-  uInt bstrow=0;
-  uInt bnrow, bucketNr;
+  rownr_t bstrow=0;
+  rownr_t bnrow;
+  uInt bucketNr;
   while (getIndex().nextBucketNr (cursor, bstrow, bnrow, bucketNr)) {
     os << " bucket strow=" << bstrow << " bucketnr=" << bucketNr << endl;
     ((ISMBucket*) (getCache().getBucket (bucketNr)))->show (os);
@@ -403,16 +404,16 @@ void ISMBase::writeIndex()
 }
     
 
-ISMBucket* ISMBase::getBucket (uInt rownr, uInt& bucketStartRow,
-			       uInt& bucketNrrow)
+ISMBucket* ISMBase::getBucket (rownr_t rownr, rownr_t& bucketStartRow,
+			       rownr_t& bucketNrrow)
 {
     uInt bucketNr = getIndex().getBucketNr (rownr, bucketStartRow,
-					     bucketNrrow);
+                                            bucketNrrow);
     return (ISMBucket*) (getCache().getBucket (bucketNr));
 }
 
-ISMBucket* ISMBase::nextBucket (uInt& cursor, uInt& bucketStartRow,
-				uInt& bucketNrrow)
+ISMBucket* ISMBase::nextBucket (uInt& cursor, rownr_t& bucketStartRow,
+				rownr_t& bucketNrrow)
 {
     uInt bucketNr;
     if (getIndex().nextBucketNr (cursor, bucketStartRow,
@@ -428,7 +429,7 @@ void ISMBase::setBucketDirty()
     dataChanged_p = True;
 }
 
-void ISMBase::addBucket (uInt rownr, ISMBucket* bucket)
+void ISMBase::addBucket (rownr_t rownr, ISMBucket* bucket)
 {
     // Add the bucket to the cache and the index.
     // It's the last bucket in the cache.
@@ -458,7 +459,7 @@ Bool ISMBase::canRemoveColumn() const
 }
 
 
-void ISMBase::addRow (uInt nrrow)
+void ISMBase::addRow64 (rownr_t nrrow)
 {
     getIndex().addRow (nrrow);
     uInt nrcol = ncolumn();
@@ -469,11 +470,12 @@ void ISMBase::addRow (uInt nrrow)
     dataChanged_p = True;
 }
 
-void ISMBase::removeRow (uInt rownr)
+void ISMBase::removeRow64 (rownr_t rownr)
 {
     // Get the bucket and interval to which the row belongs.
     uInt i;
-    uInt bucketStartRow, bucketNrrow;
+    rownr_t bucketStartRow;
+    rownr_t bucketNrrow;
     ISMBucket* bucket = getBucket (rownr, bucketStartRow, bucketNrrow);
     uInt bucketRownr = rownr - bucketStartRow;
     // Remove that row from the bucket for all columns.
@@ -589,7 +591,7 @@ Bool ISMBase::flush (AipsIO& ios, Bool fsync)
     return changed;
 }
 
-void ISMBase::resync (uInt nrrow)
+rownr_t ISMBase::resync64 (rownr_t nrrow)
 {
     nrrow_p = nrrow;
     if (index_p != 0) {
@@ -605,17 +607,18 @@ void ISMBase::resync (uInt nrrow)
     if (iosfile_p != 0) {
         iosfile_p->resync();
     }
+    return nrrow_p;
 }
 
-void ISMBase::create (uInt nrrow)
+void ISMBase::create64 (rownr_t nrrow)
 {
     init();
     recreate();
     nrrow_p = 0;
-    addRow (nrrow);
+    addRow64 (nrrow);
 }
 
-void ISMBase::open (uInt tabNrrow, AipsIO& ios)
+rownr_t ISMBase::open64 (rownr_t tabNrrow, AipsIO& ios)
 {
     nrrow_p = tabNrrow;
     // Do not check the bucketsize for an existing table.
@@ -639,6 +642,7 @@ void ISMBase::open (uInt tabNrrow, AipsIO& ios)
     for (uInt i=0; i<nrcol; i++) {
 	colSet_p[i]->getFile (nrrow_p);
     }
+    return nrrow_p;
 }
 
 StManArrayFile* ISMBase::openArrayFile (ByteIO::OpenOption opt)
@@ -678,7 +682,8 @@ void ISMBase::deleteManager()
 void ISMBase::init()
 {
     // Determine the size of a uInt in external format.
-    uIntSize_p = ValType::getCanonicalSize (TpUInt, asBigEndian());
+    uIntSize_p  = ValType::getCanonicalSize (TpUInt, asBigEndian());
+    rownrSize_p = sizeof(rownr_t);
     // Get the total length for all columns.
     // Use 32 for each variable length element.
     // On top of that each variable length element requires uIntSize_p bytes
@@ -734,21 +739,27 @@ void ISMBase::init()
 	    }
 	}
     }
+    // Only 28 bits can be used for the offset, so the bucketsize should
+    // not be larger.
+    if (bucketSize_p >= 1<<28) {
+        throw DataManError("IncrementalStMan: bucketSize exceeds 28 bits"
+                           " (>= 268435456)");
+    }
 }
 
-Bool ISMBase::checkBucketLayout (uInt &offendingCursor,
-                                 uInt &offendingBucketStartRow,
-                                 uInt &offendingBucketNrow,
-                                 uInt &offendingBucketNr,
-                                 uInt &offendingCol,
-                                 uInt &offendingIndex,
-                                 uInt &offendingRow,
-                                 uInt &offendingPrevRow)
+Bool ISMBase::checkBucketLayout (uInt& offendingCursor,
+                                 rownr_t& offendingBucketStartRow,
+                                 uInt& offendingBucketNrow,
+                                 uInt& offendingBucketNr,
+                                 uInt& offendingCol,
+                                 uInt& offendingIndex,
+                                 rownr_t& offendingRow,
+                                 rownr_t& offendingPrevRow)
 {
   Bool ok = False;
   uInt cursor = 0;
-  uInt bucketStartRow = 0;
-  uInt bucketNrow = 0;
+  rownr_t bucketStartRow = 0;
+  rownr_t bucketNrow = 0;
   uInt bucketNr = 0;
   while (getIndex().nextBucketNr(cursor, bucketStartRow, bucketNrow, bucketNr)) {
     ok = ((ISMBucket*) (getCache().getBucket(bucketNr)))->check(offendingCol,
