@@ -31,7 +31,7 @@
 
 //# Includes
 #include <casacore/casa/aips.h>
-#include <casacore/tables/DataMan/StManColumn.h>
+#include <casacore/tables/DataMan/StManColumnBase.h>
 #include <casacore/tables/DataMan/ISMBase.h>
 #include <casacore/casa/Arrays/IPosition.h>
 #include <casacore/casa/Containers/Block.h>
@@ -112,7 +112,7 @@ class ISMBucket;
 //# </todo>
 
 
-class ISMColumn : public StManColumn
+class ISMColumn : public StManColumnBase
 {
 public:
     // Create a ISMColumn object with the given parent.
@@ -127,184 +127,109 @@ public:
 
     // Get the dimensionality of the item in the given row.
     // This is the same for all rows.
-    virtual uInt ndim (uInt rownr);
+    virtual uInt ndim (rownr_t rownr);
 
     // Get the shape of the array in the given row.
     // This is the same for all rows.
-    virtual IPosition shape (uInt rownr);
+    virtual IPosition shape (rownr_t rownr);
 
     // Let the column object initialize itself for a newly created table.
     // This is meant for a derived class.
     virtual void doCreate (ISMBucket*);
 
     // Let the column object initialize itself for an existing table.
-    virtual void getFile (uInt nrrow);
+    virtual void getFile (rownr_t nrrow);
 
     // Flush and optionally fsync the data.
     // This is meant for a derived class.
-    virtual Bool flush (uInt nrrow, Bool fsync);
+    virtual Bool flush (rownr_t nrrow, Bool fsync);
 
     // Resync the storage manager with the new file contents.
     // It resets the last rownr put.
-    void resync (uInt nrrow);
+    void resync (rownr_t nrrow);
 
     // Let the column reopen its data files for read/write access.
     virtual void reopenRW();
 
     // Get a scalar value in the given row.
     // <group>
-    virtual void getBoolV     (uInt rownr, Bool* dataPtr);
-    virtual void getuCharV    (uInt rownr, uChar* dataPtr);
-    virtual void getShortV    (uInt rownr, Short* dataPtr);
-    virtual void getuShortV   (uInt rownr, uShort* dataPtr);
-    virtual void getIntV      (uInt rownr, Int* dataPtr);
-    virtual void getuIntV     (uInt rownr, uInt* dataPtr);
-    virtual void getInt64V    (uInt rownr, Int64* dataPtr);
-    virtual void getfloatV    (uInt rownr, float* dataPtr);
-    virtual void getdoubleV   (uInt rownr, double* dataPtr);
-    virtual void getComplexV  (uInt rownr, Complex* dataPtr);
-    virtual void getDComplexV (uInt rownr, DComplex* dataPtr);
-    virtual void getStringV   (uInt rownr, String* dataPtr);
+    virtual void getBool     (rownr_t rownr, Bool* dataPtr);
+    virtual void getuChar    (rownr_t rownr, uChar* dataPtr);
+    virtual void getShort    (rownr_t rownr, Short* dataPtr);
+    virtual void getuShort   (rownr_t rownr, uShort* dataPtr);
+    virtual void getInt      (rownr_t rownr, Int* dataPtr);
+    virtual void getuInt     (rownr_t rownr, uInt* dataPtr);
+    virtual void getInt64    (rownr_t rownr, Int64* dataPtr);
+    virtual void getfloat    (rownr_t rownr, float* dataPtr);
+    virtual void getdouble   (rownr_t rownr, double* dataPtr);
+    virtual void getComplex  (rownr_t rownr, Complex* dataPtr);
+    virtual void getDComplex (rownr_t rownr, DComplex* dataPtr);
+    virtual void getString   (rownr_t rownr, String* dataPtr);
     // </group>
 
     // Put a scalar value in the given row.
     // <group>
-    virtual void putBoolV     (uInt rownr, const Bool* dataPtr);
-    virtual void putuCharV    (uInt rownr, const uChar* dataPtr);
-    virtual void putShortV    (uInt rownr, const Short* dataPtr);
-    virtual void putuShortV   (uInt rownr, const uShort* dataPtr);
-    virtual void putIntV      (uInt rownr, const Int* dataPtr);
-    virtual void putuIntV     (uInt rownr, const uInt* dataPtr);
-    virtual void putInt64V    (uInt rownr, const Int64* dataPtr);
-    virtual void putfloatV    (uInt rownr, const float* dataPtr);
-    virtual void putdoubleV   (uInt rownr, const double* dataPtr);
-    virtual void putComplexV  (uInt rownr, const Complex* dataPtr);
-    virtual void putDComplexV (uInt rownr, const DComplex* dataPtr);
-    virtual void putStringV   (uInt rownr, const String* dataPtr);
+    virtual void putBool     (rownr_t rownr, const Bool* dataPtr);
+    virtual void putuChar    (rownr_t rownr, const uChar* dataPtr);
+    virtual void putShort    (rownr_t rownr, const Short* dataPtr);
+    virtual void putuShort   (rownr_t rownr, const uShort* dataPtr);
+    virtual void putInt      (rownr_t rownr, const Int* dataPtr);
+    virtual void putuInt     (rownr_t rownr, const uInt* dataPtr);
+    virtual void putInt64    (rownr_t rownr, const Int64* dataPtr);
+    virtual void putfloat    (rownr_t rownr, const float* dataPtr);
+    virtual void putdouble   (rownr_t rownr, const double* dataPtr);
+    virtual void putComplex  (rownr_t rownr, const Complex* dataPtr);
+    virtual void putDComplex (rownr_t rownr, const DComplex* dataPtr);
+    virtual void putString   (rownr_t rownr, const String* dataPtr);
     // </group>
 
     // Get the scalar values in the entire column.
     // The buffer pointed to by dataPtr has to have the correct length.
     // (which is guaranteed by the ScalarColumn getColumn function).
-    // <group>
-    virtual void getScalarColumnBoolV     (Vector<Bool>* dataPtr);
-    virtual void getScalarColumnuCharV    (Vector<uChar>* dataPtr);
-    virtual void getScalarColumnShortV    (Vector<Short>* dataPtr);
-    virtual void getScalarColumnuShortV   (Vector<uShort>* dataPtr);
-    virtual void getScalarColumnIntV      (Vector<Int>* dataPtr);
-    virtual void getScalarColumnuIntV     (Vector<uInt>* dataPtr);
-    virtual void getScalarColumnInt64V    (Vector<Int64>* dataPtr);
-    virtual void getScalarColumnfloatV    (Vector<float>* dataPtr);
-    virtual void getScalarColumndoubleV   (Vector<double>* dataPtr);
-    virtual void getScalarColumnComplexV  (Vector<Complex>* dataPtr);
-    virtual void getScalarColumnDComplexV (Vector<DComplex>* dataPtr);
-    virtual void getScalarColumnStringV   (Vector<String>* dataPtr);
-    // </group>
+    virtual void getScalarColumnV (ArrayBase& dataPtr);
 
     // Put the scalar values into the entire column.
     // The buffer pointed to by dataPtr has to have the correct length.
     // (which is guaranteed by the ScalarColumn putColumn function).
-    // <group>
-    virtual void putScalarColumnBoolV     (const Vector<Bool>* dataPtr);
-    virtual void putScalarColumnuCharV    (const Vector<uChar>* dataPtr);
-    virtual void putScalarColumnShortV    (const Vector<Short>* dataPtr);
-    virtual void putScalarColumnuShortV   (const Vector<uShort>* dataPtr);
-    virtual void putScalarColumnIntV      (const Vector<Int>* dataPtr);
-    virtual void putScalarColumnuIntV     (const Vector<uInt>* dataPtr);
-    virtual void putScalarColumnInt64V    (const Vector<Int64>* dataPtr);
-    virtual void putScalarColumnfloatV    (const Vector<float>* dataPtr);
-    virtual void putScalarColumndoubleV   (const Vector<double>* dataPtr);
-    virtual void putScalarColumnComplexV  (const Vector<Complex>* dataPtr);
-    virtual void putScalarColumnDComplexV (const Vector<DComplex>* dataPtr);
-    virtual void putScalarColumnStringV   (const Vector<String>* dataPtr);
-    // </group>
+    virtual void putScalarColumnV (const ArrayBase& dataPtr);
 
     // Get the scalar values in some cells of the column.
     // The buffer pointed to by dataPtr has to have the correct length.
     // (which is guaranteed by the ScalarColumn getColumnCells function).
-    // The default implementation loops through all rows.
-    // <group>
-    virtual void getScalarColumnCellsBoolV     (const RefRows& rownrs,
-						Vector<Bool>* dataPtr);
-    virtual void getScalarColumnCellsuCharV    (const RefRows& rownrs,
-						Vector<uChar>* dataPtr);
-    virtual void getScalarColumnCellsShortV    (const RefRows& rownrs,
-						Vector<Short>* dataPtr);
-    virtual void getScalarColumnCellsuShortV   (const RefRows& rownrs,
-						Vector<uShort>* dataPtr);
-    virtual void getScalarColumnCellsIntV      (const RefRows& rownrs,
-						Vector<Int>* dataPtr);
-    virtual void getScalarColumnCellsuIntV     (const RefRows& rownrs,
-						Vector<uInt>* dataPtr);
-    virtual void getScalarColumnCellsInt64V    (const RefRows& rownrs,
-						Vector<Int64>* dataPtr);
-    virtual void getScalarColumnCellsfloatV    (const RefRows& rownrs,
-						Vector<float>* dataPtr);
-    virtual void getScalarColumnCellsdoubleV   (const RefRows& rownrs,
-						Vector<double>* dataPtr);
-    virtual void getScalarColumnCellsComplexV  (const RefRows& rownrs,
-						Vector<Complex>* dataPtr);
-    virtual void getScalarColumnCellsDComplexV (const RefRows& rownrs,
-						Vector<DComplex>* dataPtr);
-    virtual void getScalarColumnCellsStringV   (const RefRows& rownrs,
-						Vector<String>* dataPtr);
-    // </group>
+    virtual void getScalarColumnCellsV (const RefRows& rownrs,
+                                        ArrayBase& dataPtr);
 
     // Get an array value in the given row.
-    // <group>
-    virtual void getArrayBoolV     (uInt rownr, Array<Bool>* dataPtr);
-    virtual void getArrayuCharV    (uInt rownr, Array<uChar>* dataPtr);
-    virtual void getArrayShortV    (uInt rownr, Array<Short>* dataPtr);
-    virtual void getArrayuShortV   (uInt rownr, Array<uShort>* dataPtr);
-    virtual void getArrayIntV      (uInt rownr, Array<Int>* dataPtr);
-    virtual void getArrayuIntV     (uInt rownr, Array<uInt>* dataPtr);
-    virtual void getArrayInt64V    (uInt rownr, Array<Int64>* dataPtr);
-    virtual void getArrayfloatV    (uInt rownr, Array<float>* dataPtr);
-    virtual void getArraydoubleV   (uInt rownr, Array<double>* dataPtr);
-    virtual void getArrayComplexV  (uInt rownr, Array<Complex>* dataPtr);
-    virtual void getArrayDComplexV (uInt rownr, Array<DComplex>* dataPtr);
-    virtual void getArrayStringV   (uInt rownr, Array<String>* dataPtr);
-    // </group>
+    virtual void getArrayV (rownr_t rownr, ArrayBase& dataPtr);
 
     // Put an array value in the given row.
-    // <group>
-    virtual void putArrayBoolV     (uInt rownr, const Array<Bool>* dataPtr);
-    virtual void putArrayuCharV    (uInt rownr, const Array<uChar>* dataPtr);
-    virtual void putArrayShortV    (uInt rownr, const Array<Short>* dataPtr);
-    virtual void putArrayuShortV   (uInt rownr, const Array<uShort>* dataPtr);
-    virtual void putArrayIntV      (uInt rownr, const Array<Int>* dataPtr);
-    virtual void putArrayuIntV     (uInt rownr, const Array<uInt>* dataPtr);
-    virtual void putArrayInt64V    (uInt rownr, const Array<Int64>* dataPtr);
-    virtual void putArrayfloatV    (uInt rownr, const Array<float>* dataPtr);
-    virtual void putArraydoubleV   (uInt rownr, const Array<double>* dataPtr);
-    virtual void putArrayComplexV  (uInt rownr, const Array<Complex>* dataPtr);
-    virtual void putArrayDComplexV (uInt rownr, const Array<DComplex>* dataPtr);
-    virtual void putArrayStringV   (uInt rownr, const Array<String>* dataPtr);
-    // </group>
+    virtual void putArrayV (rownr_t rownr, const ArrayBase& dataPtr);
 
     // Add (newNrrow-oldNrrow) rows to the column and initialize
     // the new rows when needed.
-    virtual void addRow (uInt newNrrow, uInt oldNrrow);
+    virtual void addRow (rownr_t newNrrow, rownr_t oldNrrow);
 
     // Remove the given row in the bucket from the column.
-    void remove (uInt bucketRownr, ISMBucket* bucket, uInt bucketNrrow,
-		 uInt newNrrow);
+    void remove (rownr_t bucketRownr, ISMBucket* bucket, rownr_t bucketNrrow,
+		 rownr_t newNrrow);
 
-    // Get the function needed to read/write a uInt from/to external format.
-    // This is used by other classes to read the length of a variable
-    // data value.
+    // Get the function needed to read/write a uInt and rownr from/to
+    // external format. This is used by other classes to read the length
+    // of a variable data value.
     // <group>
-    static Conversion::ValueFunction* getReaduInt  (Bool asCanonical);
-    static Conversion::ValueFunction* getWriteuInt (Bool asCanonical);
+    static Conversion::ValueFunction* getReaduInt   (Bool asCanonical);
+    static Conversion::ValueFunction* getReadRownr  (Bool asCanonical);
+    static Conversion::ValueFunction* getWriteuInt  (Bool asCanonical);
+    static Conversion::ValueFunction* getWriteRownr (Bool asCanonical);
     // </group>
 
     // Give a derived class the opportunity to react on the duplication
     // of a value. It is used by ISMIndColumn.
-    virtual void handleCopy (uInt rownr, const char* value);
+    virtual void handleCopy (rownr_t rownr, const char* value);
 
     // Give a derived class the opportunity to react on the removal
     // of a value. It is used by ISMIndColumn.
-    virtual void handleRemove (uInt rownr, const char* value);
+    virtual void handleRemove (rownr_t rownr, const char* value);
 
     // Get the fixed length of the data value in a cell of this column
     // (0 = variable length).
@@ -316,14 +241,14 @@ public:
 
 protected:
     // Test if the last value is invalid for this row.
-    Bool isLastValueInvalid (uInt rownr);
+    Bool isLastValueInvalid (rownr_t rownr);
 
     // Get the value for this row.
     // Set the cache if the flag is set.
-    void getValue (uInt rownr, void* value, Bool setCache);
+    void getValue (rownr_t rownr, void* value, Bool setCache);
 
     // Put the value for this row.
-    void putValue (uInt rownr, const void* value);
+    void putValue (rownr_t rownr, const void* value);
 
     //# Declare member variables.
     // Pointer to the parent storage manager.
@@ -343,11 +268,11 @@ protected:
     uInt              nrcopy_p;
     // Cache for interval for which last value read is valid.
     // The last value is valid for startRow_p till endRow_p (inclusive).
-    uInt              startRow_p;
-    uInt              endRow_p;
+    rownr_t           startRow_p;
+    rownr_t           endRow_p;
     void*             lastValue_p;
     // The last row for which a value has been put.
-    uInt              lastRowPut_p;
+    rownr_t           lastRowPut_p;
     // The size of the data type in local format.
     uInt              typeSize_p;
     // Pointer to a convert function for writing.
@@ -373,26 +298,26 @@ private:
     void clear();
 
     // Put the value in all buckets from the given row on.
-    void putFromRow (uInt rownr, const char* data, uInt lenData);
+    void putFromRow (rownr_t rownr, const char* data, uInt lenData);
 
     // Put a data value into the bucket.
     // When it is at the first row of the bucket, it replaces the value.
     // Otherwise it is added.
-    void putData (ISMBucket* bucket, uInt bucketStartRow,
-		  uInt bucketNrrow, uInt bucketRownr,
+    void putData (ISMBucket* bucket, rownr_t bucketStartRow,
+		  rownr_t bucketNrrow, rownr_t bucketRownr,
 		  const char* data, uInt lenData,
 		  Bool afterLastRow, Bool canSplit);
 
     // Replace a value at the given offset in the bucket.
     // If the bucket is too small, it will be split (if allowed).
-    void replaceData (ISMBucket* bucket, uInt bucketStartRow,
-		      uInt bucketNrrow, uInt bucketRownr, uInt& offset,
+    void replaceData (ISMBucket* bucket, rownr_t bucketStartRow,
+		      rownr_t bucketNrrow, rownr_t bucketRownr, uInt& offset,
 		      const char* data, uInt lenData, Bool canSplit = True);
 
     // Add a value at the given index in the bucket.
     // If the bucket is too small, it will be split (if allowed).
-    Bool addData (ISMBucket* bucket, uInt bucketStartRow,
-		  uInt bucketNrrow, uInt bucketRownr, uInt inx,
+    Bool addData (ISMBucket* bucket, rownr_t bucketStartRow,
+		  rownr_t bucketNrrow, rownr_t bucketRownr, uInt inx,
 		  const char* data, uInt lenData,
 		  Bool afterLastRow = False, Bool canSplit = True);
 
@@ -413,13 +338,50 @@ private:
     static size_t writeStringLE (void* out, const void* in, size_t n);
     static size_t readStringLE (void* out, const void* in, size_t n);
     // </group>
+
+    void getScaCol (Vector<Bool>&);
+    void getScaCol (Vector<uChar>&);
+    void getScaCol (Vector<Short>&);
+    void getScaCol (Vector<uShort>&);
+    void getScaCol (Vector<Int>&);
+    void getScaCol (Vector<uInt>&);
+    void getScaCol (Vector<Int64>&);
+    void getScaCol (Vector<float>&);
+    void getScaCol (Vector<double>&);
+    void getScaCol (Vector<Complex>&);
+    void getScaCol (Vector<DComplex>&);
+    void getScaCol (Vector<String>&);
+
+    void getScaColCells (const RefRows&, Vector<Bool>&);
+    void getScaColCells (const RefRows&, Vector<uChar>&);
+    void getScaColCells (const RefRows&, Vector<Short>&);
+    void getScaColCells (const RefRows&, Vector<uShort>&);
+    void getScaColCells (const RefRows&, Vector<Int>&);
+    void getScaColCells (const RefRows&, Vector<uInt>&);
+    void getScaColCells (const RefRows&, Vector<Int64>&);
+    void getScaColCells (const RefRows&, Vector<float>&);
+    void getScaColCells (const RefRows&, Vector<double>&);
+    void getScaColCells (const RefRows&, Vector<Complex>&);
+    void getScaColCells (const RefRows&, Vector<DComplex>&);
+    void getScaColCells (const RefRows&, Vector<String>&);
+
+    void putScaCol (const Vector<Bool>&);
+    void putScaCol (const Vector<uChar>&);
+    void putScaCol (const Vector<Short>&);
+    void putScaCol (const Vector<uShort>&);
+    void putScaCol (const Vector<Int>&);
+    void putScaCol (const Vector<uInt>&);
+    void putScaCol (const Vector<Int64>&);
+    void putScaCol (const Vector<float>&);
+    void putScaCol (const Vector<double>&);
+    void putScaCol (const Vector<Complex>&);
+    void putScaCol (const Vector<DComplex>&);
+    void putScaCol (const Vector<String>&);
 };
 
 
-inline Bool ISMColumn::isLastValueInvalid (uInt rownr)
+inline Bool ISMColumn::isLastValueInvalid (rownr_t rownr)
 {
-    // Compare with cache, because that might be invalidated by Table::unlock
-    // while startRow_p and endRow_p are still fine.
     return rownr < startRow_p  ||  rownr > endRow_p;
 }
 
