@@ -23,7 +23,7 @@
 //#                        520 Edgemont Road
 //#                        Charlottesville, VA 22903-2475 USA
 //#
-//# $Id$
+//# $Id: StIndArrAIO.h 20551 2009-03-25 00:11:33Z Malte.Marquarding $
 
 #ifndef TABLES_STINDARRAIO_H
 #define TABLES_STINDARRAIO_H
@@ -103,137 +103,70 @@ public:
     StManColumnIndArrayAipsIO (StManAipsIO*, int dataType);
 
     // Frees up the storage and delete the StManArrayFile object.
-    ~StManColumnIndArrayAipsIO();
-
-    // It can handle access to a slice in a cell.
-    Bool canAccessSlice (Bool& reask) const;
+    virtual ~StManColumnIndArrayAipsIO();
 
     // Set the (fixed) shape of the arrays in the entire column.
-    void setShapeColumn (const IPosition& shape);
+    virtual void setShapeColumn (const IPosition& shape);
 
     // Add (newNrrow-oldNrrow) rows to the column.
     // Allocate the data arrays in these rows if the shape is fixed.
-    void addRow (uInt newNrrow, uInt oldNrrow);
+    virtual void addRow (rownr_t newNrrow, rownr_t oldNrrow);
 
     // Set the shape of the array in the given row and allocate the array
     // in the file.
-    void setShape (uInt rownr, const IPosition& shape);
+    virtual void setShape (rownr_t rownr, const IPosition& shape);
 
     // Is the shape defined (i.e. is there an array) in this row?
-    Bool isShapeDefined (uInt rownr);
+    virtual Bool isShapeDefined (rownr_t rownr);
 
     // Get the dimensionality of the item in the given row.
     // 0 is returned if there is no array.
-    uInt ndim (uInt rownr);
+    virtual uInt ndim (rownr_t rownr);
 
     // Get the shape of the array in the given row.
     // An zero-length IPosition is returned if there is no array.
-    IPosition shape (uInt rownr);
+    virtual IPosition shape (rownr_t rownr);
 
     // This storage manager can handle changing array shapes
     // for non-FixedShape columns.
-    Bool canChangeShape() const;
+    virtual Bool canChangeShape() const;
 
     // Get an array value in the given row.
     // The buffer pointed to by dataPtr has to have the correct length
     // (which is guaranteed by the ArrayColumn get function).
-    // <group>
-    void getArrayBoolV     (uInt rownr, Array<Bool>* dataPtr);
-    void getArrayuCharV    (uInt rownr, Array<uChar>* dataPtr);
-    void getArrayShortV    (uInt rownr, Array<Short>* dataPtr);
-    void getArrayuShortV   (uInt rownr, Array<uShort>* dataPtr);
-    void getArrayIntV      (uInt rownr, Array<Int>* dataPtr);
-    void getArrayuIntV     (uInt rownr, Array<uInt>* dataPtr);
-    void getArrayfloatV    (uInt rownr, Array<float>* dataPtr);
-    void getArrayInt64V    (uInt rownr, Array<Int64>* dataPtr);
-    void getArraydoubleV   (uInt rownr, Array<double>* dataPtr);
-    void getArrayComplexV  (uInt rownr, Array<Complex>* dataPtr);
-    void getArrayDComplexV (uInt rownr, Array<DComplex>* dataPtr);
-    void getArrayStringV   (uInt rownr, Array<String>* dataPtr);
-    // </group>
+    virtual void getArrayV (rownr_t rownr, ArrayBase& dataPtr);
 
     // Put an array value into the given row.
     // The buffer pointed to by dataPtr has to have the correct length
     // (which is guaranteed by the ArrayColumn put function).
-    // <group>
-    void putArrayBoolV     (uInt rownr, const Array<Bool>* dataPtr);
-    void putArrayuCharV    (uInt rownr, const Array<uChar>* dataPtr);
-    void putArrayShortV    (uInt rownr, const Array<Short>* dataPtr);
-    void putArrayuShortV   (uInt rownr, const Array<uShort>* dataPtr);
-    void putArrayIntV      (uInt rownr, const Array<Int>* dataPtr);
-    void putArrayuIntV     (uInt rownr, const Array<uInt>* dataPtr);
-    void putArrayInt64V    (uInt rownr, const Array<Int64>* dataPtr);
-    void putArrayfloatV    (uInt rownr, const Array<float>* dataPtr);
-    void putArraydoubleV   (uInt rownr, const Array<double>* dataPtr);
-    void putArrayComplexV  (uInt rownr, const Array<Complex>* dataPtr);
-    void putArrayDComplexV (uInt rownr, const Array<DComplex>* dataPtr);
-    void putArrayStringV   (uInt rownr, const Array<String>* dataPtr);
-    // </group>
+    virtual void putArrayV (rownr_t rownr, const ArrayBase& dataPtr);
 
     // Get a section of the array in the given row.
     // The buffer pointed to by dataPtr has to have the correct length
     // (which is guaranteed by the ArrayColumn getSlice function).
-    // <group>
-    void getSliceBoolV     (uInt rownr, const Slicer&, Array<Bool>* dataPtr);
-    void getSliceuCharV    (uInt rownr, const Slicer&, Array<uChar>* dataPtr);
-    void getSliceShortV    (uInt rownr, const Slicer&, Array<Short>* dataPtr);
-    void getSliceuShortV   (uInt rownr, const Slicer&, Array<uShort>* dataPtr);
-    void getSliceIntV      (uInt rownr, const Slicer&, Array<Int>* dataPtr);
-    void getSliceuIntV     (uInt rownr, const Slicer&, Array<uInt>* dataPtr);
-    void getSliceInt64V    (uInt rownr, const Slicer&, Array<Int64>* dataPtr);
-    void getSlicefloatV    (uInt rownr, const Slicer&, Array<float>* dataPtr);
-    void getSlicedoubleV   (uInt rownr, const Slicer&, Array<double>* dataPtr);
-    void getSliceComplexV  (uInt rownr, const Slicer&, Array<Complex>* dataPtr);
-    void getSliceDComplexV (uInt rownr, const Slicer&, Array<DComplex>* dataPtr);
-    void getSliceStringV   (uInt rownr, const Slicer&, Array<String>* dataPtr);
-    // </group>
+    virtual void getSliceV (rownr_t rownr, const Slicer&, ArrayBase& dataPtr);
 
     // Put into a section of the array in the given row.
     // The buffer pointed to by dataPtr has to have the correct length
     // (which is guaranteed by the ArrayColumn putSlice function).
-    // <group>
-    void putSliceBoolV     (uInt rownr, const Slicer&,
-		            const Array<Bool>* dataPtr);
-    void putSliceuCharV    (uInt rownr, const Slicer&,
-                            const Array<uChar>* dataPtr);
-    void putSliceShortV    (uInt rownr, const Slicer&,
-                            const Array<Short>* dataPtr);
-    void putSliceuShortV   (uInt rownr, const Slicer&,
-                            const Array<uShort>* dataPtr);
-    void putSliceIntV      (uInt rownr, const Slicer&,
-                            const Array<Int>* dataPtr);
-    void putSliceuIntV     (uInt rownr, const Slicer&,
-                            const Array<uInt>* dataPtr);
-    void putSliceInt64V    (uInt rownr, const Slicer&,
-                            const Array<Int64>* dataPtr);
-    void putSlicefloatV    (uInt rownr, const Slicer&,
-                            const Array<float>* dataPtr);
-    void putSlicedoubleV   (uInt rownr, const Slicer&,
-                            const Array<double>* dataPtr);
-    void putSliceComplexV  (uInt rownr, const Slicer&,
-                            const Array<Complex>* dataPtr);
-    void putSliceDComplexV (uInt rownr, const Slicer&,
-                            const Array<DComplex>* dataPtr);
-    void putSliceStringV   (uInt rownr, const Slicer&,
-                            const Array<String>* dataPtr);
-    // </group>
+    virtual void putSliceV (rownr_t rownr, const Slicer&, const ArrayBase& dataPtr);
 
     // Remove the value in the given row.
     // This will result in lost file space.
-    void remove (uInt rownr);
+    virtual void remove (rownr_t rownr);
 
     // Let the column create its array file.
-    void doCreate (uInt nrrow);
+    virtual void doCreate (rownr_t nrrow);
 
     // Write the data into AipsIO.
     // This will call StManColumnAipsIO::putFile which will in its turn
     // call putData in this class for each of its chunks of data.
-    void putFile (uInt nrval, AipsIO&);
+    virtual void putFile (rownr_t nrval, AipsIO&);
 
     // Read the data from AipsIO.
     // This will call StManColumnAipsIO::getFile which will in its turn
     // call getData in this class for each of its chunks of data.
-    void getFile (uInt nrval, AipsIO&);
+    virtual void getFile (rownr_t nrval, AipsIO&);
 
     // Reopen the storage manager files for read/write.
     virtual void reopenRW();
@@ -242,6 +175,8 @@ public:
     Bool ok() const;
 
 private:
+    // The storage manager.
+    StManAipsIO* staioPtr_p;
     // The (unique) sequence number of the column.
     uInt seqnr_p;
     // The shape of all arrays in case it is fixed.
@@ -260,12 +195,12 @@ private:
     void openFile (ByteIO::OpenOption opt);
 
     // Delete the array in the given row.
-    void deleteArray (uInt rownr);
+    void deleteArray (rownr_t rownr);
 
     // Read the shape at the given row.
     // This will cache the information in the StIndArray
     // object for that row.
-    StIndArray* getShape (uInt rownr);
+    StIndArray* getShape (rownr_t rownr);
 
     // Put the data of a data block.
     // datap is an array of nrval pointers to StIndArray.
