@@ -30,6 +30,7 @@
 #include <casacore/tables/DataMan/TSMCube.h>
 #include <casacore/casa/Arrays/IPosition.h>
 #include <casacore/casa/BasicSL/String.h>
+#include <casacore/casa/BasicSL/STLIO.h>
 #include <casacore/casa/Utilities/BinarySearch.h>
 #include <casacore/casa/Containers/BlockIO.h>
 #include <casacore/casa/IO/AipsIO.h>
@@ -41,21 +42,18 @@ namespace casacore { //# NAMESPACE CASACORE - BEGIN
 
 TiledDataStMan::TiledDataStMan ()
 : TiledStMan     (),
-  nrUsedRowMap_p (0),
   nrrowLast_p    (0)
 {}
 
 TiledDataStMan::TiledDataStMan (const String& hypercolumnName,
 				uInt64 maximumCacheSize)
 : TiledStMan     (hypercolumnName, maximumCacheSize),
-  nrUsedRowMap_p (0),
   nrrowLast_p    (0)
 {}
 
 TiledDataStMan::TiledDataStMan (const String& hypercolumnName,
 				const Record& spec)
 : TiledStMan     (hypercolumnName, 0),
-  nrUsedRowMap_p (0),
   nrrowLast_p    (0)
 {
     if (spec.isDefined ("MAXIMUMCACHESIZE")) {
@@ -102,15 +100,12 @@ Bool TiledDataStMan::flush (AipsIO&, Bool fsync)
     }
     // Create the header file and write data in it.
     AipsIO* headerFile = headerFileCreate();
-    headerFile->putstart ("TiledDataStMan", 1);
+    headerFile->putstart ("TiledDataStMan", 2);
     // Let the base class write its data.
     headerFilePut (*headerFile, cubeSet_p.nelements());
     // Write the data from this object.
     *headerFile << nrrowLast_p;
-    *headerFile << nrUsedRowMap_p;
-    putBlock (*headerFile, rowMap_p,  Int(nrUsedRowMap_p));
-    putBlock (*headerFile, cubeMap_p, Int(nrUsedRowMap_p));
-    putBlock (*headerFile, posMap_p,  Int(nrUsedRowMap_p));
+    *headerFile << rowMap_p << cubeMap_p << posMap_p;
     headerFile->putend();
     headerFileClose (headerFile);
     return True;
@@ -120,15 +115,29 @@ void TiledDataStMan::readHeader (rownr_t tabNrrow, Bool firstTime)
 {
     // Open the header file and read data from it.
     AipsIO* headerFile = headerFileOpen();
-    headerFile->getstart ("TiledDataStMan");
+    uInt version = headerFile->getstart ("TiledDataStMan");
     // Let the base class read and initialize its data.
-    headerFileGet (*headerFile, tabNrrow, firstTime, -1);
+    uInt hdrVersion = headerFileGet (*headerFile, tabNrrow, firstTime, -1);
     // Read the data for this object.
-    *headerFile >> nrrowLast_p;
-    *headerFile >> nrUsedRowMap_p;
-    getBlock (*headerFile, rowMap_p);
-    getBlock (*headerFile, cubeMap_p);
-    getBlock (*headerFile, posMap_p);
+    // Version 1 was not incremented at the change to rownr_t, but the
+    // parent class TiledStMan was. So test that version as well.
+    if (version == 1  &&  hdrVersion < 3) {
+        uInt nrow;
+        *headerFile >> nrow;
+        nrrowLast_p = nrow;
+    } else {
+        *headerFile >> nrrowLast_p;
+    }
+    if (version == 1) {
+      uInt nused;
+      *headerFile >> nused;
+      std::vector<uInt> rowMap;
+      *headerFile >> rowMap;
+      rowMap_p.insert (rowMap_p.end(), rowMap.begin(), rowMap.end());
+      *headerFile >> cubeMap_p >> posMap_p;
+    } else {
+      *headerFile >> rowMap_p >> cubeMap_p >> posMap_p;
+    }
     headerFile->getend();
     headerFileClose (headerFile);
 }
@@ -195,18 +204,11 @@ void TiledDataStMan::updateRowMap (uInt cubeNr, uInt64 incrInLastDim)
     if (incrInLastDim == 0) {
 	return;
     }
-    // Extend the maps when needed.
-    if (nrUsedRowMap_p == rowMap_p.nelements()) {
-	rowMap_p.resize (nrUsedRowMap_p + 64);
-	cubeMap_p.resize (nrUsedRowMap_p + 64);
-	posMap_p.resize (nrUsedRowMap_p + 64);
-    }
     // Determine the numbers of rows added via the extension.
     const IPosition& shape = cubeSet_p[cubeNr]->cubeShape();
-    rowMap_p[nrUsedRowMap_p] = nrrowLast_p;
-    cubeMap_p[nrUsedRowMap_p] = cubeNr;
-    posMap_p[nrUsedRowMap_p] = shape(nrdim_p-1) - incrInLastDim;
-    nrUsedRowMap_p++;
+    rowMap_p.push_back (nrrowLast_p);
+    cubeMap_p.push_back (cubeNr);
+    posMap_p.push_back (shape(nrdim_p-1) - incrInLastDim);
     // Now update the last row number used with the
     // number of rows this extension represents.
     rownr_t nr = addedNrrow (cubeSet_p[cubeNr]->cubeShape(), incrInLastDim);
@@ -226,7 +228,7 @@ TSMCube* TiledDataStMan::getHypercube (rownr_t rownr, IPosition& position)
     }
     // Find the closest row number in the map (equal or less).
     Bool found;
-    uInt index = binarySearchBrackets (found, rowMap_p, rownr, nrUsedRowMap_p);
+    uInt index = binarySearchBrackets (found, rowMap_p, rownr, rowMap_p.size());
     if (!found) {
 	index--;
     }
