@@ -34,135 +34,96 @@
 #include <casacore/tables/DataMan/DataManError.h>
 #include <casacore/casa/Containers/Record.h>
 #include <casacore/casa/Arrays/ArrayMath.h>
+#include <casacore/casa/Utilities/Copy.h>
 #include <casacore/casa/Utilities/Assert.h>
 
 
 namespace casacore { //# NAMESPACE CASACORE - BEGIN
 
-VirtualTaQLColumn::VirtualTaQLColumn (const String& expr)
+  VirtualTaQLColumn::VirtualTaQLColumn (const String& expr, const String& style)
 : itsDataType     (TpOther),
   itsIsArray      (False),
-  itsExpr         (expr),
-  itsNode         (0),
+  itsIsConst      (False),
   itsTempWritable (False),
-  itsCurRow       (-1),
-  itsCurResult    (0)
+  itsExpr         (expr),
+  itsStyle        (style),
+  itsNode         (0),
+  itsCurArray     (0),
+  itsCurRow       (-1)
 {}
 
 VirtualTaQLColumn::VirtualTaQLColumn (const Record& spec)
 : itsDataType     (TpOther),
   itsIsArray      (False),
-  itsNode         (0),
+  itsIsConst      (False),
   itsTempWritable (False),
-  itsCurRow       (-1),
-  itsCurResult    (0)
+  itsNode         (0),
+  itsCurArray     (0),
+  itsCurRow       (-1)
 {
   if (spec.isDefined ("TAQLCALCEXPR")) {
     itsExpr = spec.asString ("TAQLCALCEXPR");
   }
+  if (spec.isDefined ("TAQLSTYLE")) {
+    itsStyle = spec.asString ("TAQLSTYLE");
+  }
 }
 
 VirtualTaQLColumn::~VirtualTaQLColumn()
 {
-  if (itsCurResult != 0) {
-    clearCurResult();
-  }
+  delete itsCurArray;
   delete itsNode;
 }
 
-void VirtualTaQLColumn::makeCurResult()
+void VirtualTaQLColumn::makeCurArray()
 {
+  delete itsCurArray;
+  itsCurArray = 0;
   switch (itsDataType) {
   case TpBool:
-    itsCurResult = new Array<Bool>();
+    itsCurArray = new Array<Bool>();
     break;
   case TpUChar:
-    itsCurResult = new Array<uChar>();
+    itsCurArray = new Array<uChar>();
     break;
   case TpShort:
-    itsCurResult = new Array<Short>();
+    itsCurArray = new Array<Short>();
     break;
   case TpUShort:
-    itsCurResult = new Array<uShort>();
+    itsCurArray = new Array<uShort>();
     break;
   case TpInt:
-    itsCurResult = new Array<Int>();
+    itsCurArray = new Array<Int>();
     break;
   case TpUInt:
-    itsCurResult = new Array<uInt>();
+    itsCurArray = new Array<uInt>();
     break;
   case TpInt64:
-    itsCurResult = new Array<Int64>();
+    itsCurArray = new Array<Int64>();
     break;
   case TpFloat:
-    itsCurResult = new Array<Float>();
+    itsCurArray = new Array<Float>();
     break;
   case TpDouble:
-    itsCurResult = new Array<Double>();
+    itsCurArray = new Array<Double>();
     break;
   case TpComplex:
-    itsCurResult = new Array<Complex>();
+    itsCurArray = new Array<Complex>();
     break;
   case TpDComplex:
-    itsCurResult = new Array<DComplex>();
+    itsCurArray = new Array<DComplex>();
     break;
   case TpString:
-    itsCurResult = new Array<String>();
+    itsCurArray = new Array<String>();
     break;
   default:
-    throw DataManError ("VirtualTaQLColumn::makeCurResult - unknown data type");
+    throw DataManError ("VirtualTaQLColumn::makeCurArray - unknown data type");
   }
 }
 
-void VirtualTaQLColumn::clearCurResult()
-{
-  switch (itsDataType) {
-  case TpBool:
-    delete static_cast<Array<Bool>*>(itsCurResult);
-    break;
-  case TpUChar:
-    delete static_cast<Array<uChar>*>(itsCurResult);
-    break;
-  case TpShort:
-    delete static_cast<Array<Short>*>(itsCurResult);
-    break;
-  case TpUShort:
-    delete static_cast<Array<uShort>*>(itsCurResult);
-    break;
-  case TpInt:
-    delete static_cast<Array<Int>*>(itsCurResult);
-    break;
-  case TpUInt:
-    delete static_cast<Array<uInt>*>(itsCurResult);
-    break;
-  case TpInt64:
-    delete static_cast<Array<Int64>*>(itsCurResult);
-    break;
-  case TpFloat:
-    delete static_cast<Array<Float>*>(itsCurResult);
-    break;
-  case TpDouble:
-    delete static_cast<Array<Double>*>(itsCurResult);
-    break;
-  case TpComplex:
-    delete static_cast<Array<Complex>*>(itsCurResult);
-    break;
-  case TpDComplex:
-    delete static_cast<Array<DComplex>*>(itsCurResult);
-    break;
-  case TpString:
-    delete static_cast<Array<String>*>(itsCurResult);
-    break;
-  default:
-    throw DataManError ("VirtualTaQLColumn::clearCurResult - unknown data type");
-  }
-  itsCurResult = 0;
-  itsCurRow    = -1;
-}
-
 DataManager* VirtualTaQLColumn::clone() const
 {
-  DataManager* dmPtr = new VirtualTaQLColumn (itsExpr);
+  DataManager* dmPtr = new VirtualTaQLColumn (itsExpr, itsStyle);
   return dmPtr;
 }
 
@@ -189,13 +150,15 @@ DataManagerColumn* VirtualTaQLColumn::makeIndArrColumn (const String& name,
 }
 
 
-void VirtualTaQLColumn::create (uInt)
+void VirtualTaQLColumn::create64 (rownr_t)
 {
   // Define a keyword in the column telling the expression.
+  // The table has to be writable for this operation only; otherwise it is not writable.
   itsTempWritable = True;
   TableColumn tabcol (table(), itsColumnName);
   itsTempWritable = False;
   tabcol.rwKeywordSet().define ("_VirtualTaQLEngine_CalcExpr", itsExpr);
+  tabcol.rwKeywordSet().define ("_VirtualTaQLEngine_Style", itsStyle);
 }
 
 void VirtualTaQLColumn::prepare()
@@ -203,8 +166,15 @@ void VirtualTaQLColumn::prepare()
   // Get the expression.
   TableColumn tabcol (table(), itsColumnName);
   itsExpr = tabcol.keywordSet().asString ("_VirtualTaQLEngine_CalcExpr");
+  if (tabcol.keywordSet().isDefined ("_VirtualTaQLEngine_Style")) {
+    itsStyle = tabcol.keywordSet().asString ("_VirtualTaQLEngine_Style");
+  }
   // Compile the expression.
-  TaQLResult res = tableCommand ("calc from $1 calc " + itsExpr, table());
+  String cmd;
+  if (! itsStyle.empty()) {
+    cmd = "using style " + itsStyle;
+  }
+  TaQLResult res = tableCommand (cmd + " calc from $1 calc " + itsExpr, table());
   itsNode = new TableExprNode(res.node());
   // Check if the expression type matches the column type.
   if (itsNode->isScalar() == itsIsArray) {
@@ -236,6 +206,17 @@ void VirtualTaQLColumn::prepare()
 			"expression and column " + itsColumnName +
                         " data type mismatch");
   }
+  // Create the correct array type.
+  makeCurArray();
+  // If a constant expression, get the constant value and set cache for scalars.
+  itsIsConst = itsNode->getRep()->isConstant();
+  if (itsIsConst) {
+    if (itsIsArray) {
+      getResult(0);
+    } else {
+      fillColumnCache();
+    }
+  }
 }
 
 DataManager* VirtualTaQLColumn::makeObject (const String&,
@@ -266,6 +247,16 @@ Record VirtualTaQLColumn::dataManagerSpec() const
   return spec;
 }
 
+void VirtualTaQLColumn::setShapeColumn (const IPosition& aShape)
+{
+  itsShape = aShape;
+}
+
+void VirtualTaQLColumn::setMaxLength (uInt maxLength)
+{
+  itsMaxLen = maxLength;
+}
+
 int VirtualTaQLColumn::dataType() const
 {
   return itsDataType;
@@ -273,265 +264,329 @@ int VirtualTaQLColumn::dataType() const
 
 Bool VirtualTaQLColumn::isWritable() const
 {
+  // This is always False except temporarily in function create64 to define a keyword.
   return itsTempWritable;
 }
 
 
-uInt VirtualTaQLColumn::ndim (uInt rownr)
+uInt VirtualTaQLColumn::ndim (rownr_t rownr)
 {
   return shape(rownr).nelements();
 }
 
-IPosition VirtualTaQLColumn::shape (uInt rownr)
+IPosition VirtualTaQLColumn::shape (rownr_t rownr)
 {
   if (!itsIsArray) {
     return IPosition();
   }
+  // See if the expression has a fixed shape.
   IPosition shp = itsNode->getNodeRep()->shape();
   if (shp.nelements() > 0) {
     return shp;
   }
-  if (Int(rownr) != itsCurRow) {
-    itsCurShape = getResult (rownr);
+  // Value is already available if constant or if current row.
+  if (!itsIsConst  &&  rownr != itsCurRow) {
+    getResult (rownr);
     itsCurRow = rownr;
   }
-  return itsCurShape;
+  return itsCurArray->shape();
 }
 
-Bool VirtualTaQLColumn::isShapeDefined (uInt)
+Bool VirtualTaQLColumn::isShapeDefined (rownr_t)
 {
   return True;
 }
 
 
-void VirtualTaQLColumn::getBoolV (uInt rownr, Bool* dataPtr)
+void VirtualTaQLColumn::getBool (rownr_t rownr, Bool* dataPtr)
 {
   *dataPtr = itsNode->getBool (rownr);
 }
-void VirtualTaQLColumn::getuCharV (uInt rownr, uChar* dataPtr)
+void VirtualTaQLColumn::getuChar (rownr_t rownr, uChar* dataPtr)
 {
   *dataPtr = uChar(itsNode->getInt (rownr));
 }
-void VirtualTaQLColumn::getShortV (uInt rownr, Short* dataPtr)
+void VirtualTaQLColumn::getShort (rownr_t rownr, Short* dataPtr)
 {
   *dataPtr = Short(itsNode->getInt (rownr));
 }
-void VirtualTaQLColumn::getuShortV (uInt rownr, uShort* dataPtr)
+void VirtualTaQLColumn::getuShort (rownr_t rownr, uShort* dataPtr)
 {
   *dataPtr = uShort(itsNode->getInt (rownr));
 }
-void VirtualTaQLColumn::getIntV (uInt rownr, Int* dataPtr)
+void VirtualTaQLColumn::getInt (rownr_t rownr, Int* dataPtr)
 {
   *dataPtr = Int(itsNode->getInt (rownr));
 }
-void VirtualTaQLColumn::getuIntV (uInt rownr, uInt* dataPtr)
+void VirtualTaQLColumn::getuInt (rownr_t rownr, uInt* dataPtr)
 {
   *dataPtr = uInt(itsNode->getInt (rownr));
 }
-void VirtualTaQLColumn::getInt64V (uInt rownr, Int64* dataPtr)
+void VirtualTaQLColumn::getInt64 (rownr_t rownr, Int64* dataPtr)
 {
-  *dataPtr = Int64(itsNode->getInt (rownr));
+  *dataPtr = itsNode->getInt (rownr);
 }
-void VirtualTaQLColumn::getfloatV (uInt rownr, float* dataPtr)
+void VirtualTaQLColumn::getfloat (rownr_t rownr, float* dataPtr)
 {
   *dataPtr = Float(itsNode->getDouble (rownr));
 }
-void VirtualTaQLColumn::getdoubleV (uInt rownr, double* dataPtr)
+void VirtualTaQLColumn::getdouble (rownr_t rownr, double* dataPtr)
 {
   *dataPtr = itsNode->getDouble (rownr);
 }
-void VirtualTaQLColumn::getComplexV (uInt rownr, Complex* dataPtr)
+void VirtualTaQLColumn::getComplex (rownr_t rownr, Complex* dataPtr)
 {
   *dataPtr = Complex(itsNode->getDComplex (rownr));
 }
-void VirtualTaQLColumn::getDComplexV (uInt rownr, DComplex* dataPtr)
+void VirtualTaQLColumn::getDComplex (rownr_t rownr, DComplex* dataPtr)
 {
   *dataPtr = itsNode->getDComplex (rownr);
 }
-void VirtualTaQLColumn::getStringV (uInt rownr, String* dataPtr)
+void VirtualTaQLColumn::getString (rownr_t rownr, String* dataPtr)
 {
   *dataPtr = itsNode->getString (rownr);
+  if (itsMaxLen > 0  &&  dataPtr->size() > itsMaxLen) {
+    *dataPtr = dataPtr->substr (0, itsMaxLen);
+  }
 }
 
-void VirtualTaQLColumn::getArrayV (uInt rownr, void* dataPtr)
+void VirtualTaQLColumn::getArrayV (rownr_t rownr, ArrayBase& arr)
 {
   // Usually getShape is called before getArray.
   // To avoid double calculation of the same value, the result is cached
-  // by getShape in itsCurResult (by getResult).
-  if (Int(rownr) != itsCurRow) {
+  // by getShape in itsCurArray (by getResult).
+  // Value is also available if constant.
+  if (!itsIsConst  &&  rownr != itsCurRow) {
     getResult (rownr);
+    itsCurRow = rownr;
   }
-  switch (itsDataType) {
-  case TpBool:
-    *static_cast<Array<Bool>*>(dataPtr) =
-      *static_cast<Array<Bool>*>(itsCurResult);
-    break;
-  case TpUChar:
-    *static_cast<Array<uChar>*>(dataPtr) =
-      *static_cast<Array<uChar>*>(itsCurResult);
-    break;
-  case TpShort:
-    *static_cast<Array<Short>*>(dataPtr) =
-      *static_cast<Array<Short>*>(itsCurResult);
-    break;
-  case TpUShort:
-    *static_cast<Array<uShort>*>(dataPtr) =
-      *static_cast<Array<uShort>*>(itsCurResult);
-    break;
-  case TpInt:
-    *static_cast<Array<Int>*>(dataPtr) =
-      *static_cast<Array<Int>*>(itsCurResult);
-    break;
-  case TpUInt:
-    *static_cast<Array<uInt>*>(dataPtr) =
-      *static_cast<Array<uInt>*>(itsCurResult);
-    break;
-  case TpInt64:
-    *static_cast<Array<Int64>*>(dataPtr) =
-      *static_cast<Array<Int64>*>(itsCurResult);
-    break;
-  case TpFloat:
-    *static_cast<Array<Float>*>(dataPtr) =
-      *static_cast<Array<Float>*>(itsCurResult);
-    break;
-  case TpDouble:
-    *static_cast<Array<Double>*>(dataPtr) =
-      *static_cast<Array<Double>*>(itsCurResult);
-    break;
-  case TpComplex:
-    *static_cast<Array<Complex>*>(dataPtr) =
-      *static_cast<Array<Complex>*>(itsCurResult);
-    break;
-  case TpDComplex:
-    *static_cast<Array<DComplex>*>(dataPtr) =
-      *static_cast<Array<DComplex>*>(itsCurResult);
-    break;
-  case TpString:
-    *static_cast<Array<String>*>(dataPtr) =
-      *static_cast<Array<String>*>(itsCurResult);
-    break;
-  default:
-    throw DataManError ("VirtualTaQLColumn::getArrayV - unknown data type");
-  }
-  clearCurResult();
+  arr.assignBase (*itsCurArray);
 }
 
-IPosition VirtualTaQLColumn::getResult (uInt rownr)
+void VirtualTaQLColumn::getResult (rownr_t rownr)
 {
-  if (! itsCurResult) {
-    makeCurResult();
-  }
-  IPosition shp;
   switch (itsDataType) {
   case TpBool:
     {
       Array<Bool> arr = itsNode->getArrayBool (rownr);
-      Array<Bool>& out = *static_cast<Array<Bool>*>(itsCurResult);
+      Array<Bool>& out = *static_cast<Array<Bool>*>(itsCurArray);
       out.reference (arr);
-      shp = out.shape();
       break;
     }
   case TpUChar:
     {
       Array<Int64> arr = itsNode->getArrayInt (rownr);
-      Array<uChar>& out = *static_cast<Array<uChar>*>(itsCurResult);
+      Array<uChar>& out = *static_cast<Array<uChar>*>(itsCurArray);
       out.resize (arr.shape());
       convertArray (out, arr);
-      shp = out.shape();
       break;
     }
   case TpShort:
     {
       Array<Int64> arr = itsNode->getArrayInt (rownr);
-      Array<Short>& out = *static_cast<Array<Short>*>(itsCurResult);
+      Array<Short>& out = *static_cast<Array<Short>*>(itsCurArray);
       out.resize (arr.shape());
       convertArray (out, arr);
-      shp = out.shape();
       break;
     }
   case TpUShort:
     {
       Array<Int64> arr = itsNode->getArrayInt (rownr);
-      Array<uShort>& out = *static_cast<Array<uShort>*>(itsCurResult);
+      Array<uShort>& out = *static_cast<Array<uShort>*>(itsCurArray);
       out.resize (arr.shape());
       convertArray (out, arr);
-      shp = out.shape();
       break;
     }
   case TpInt:
     {
       Array<Int64> arr = itsNode->getArrayInt (rownr);
-      Array<Int>& out = *static_cast<Array<Int>*>(itsCurResult);
+      Array<Int>& out = *static_cast<Array<Int>*>(itsCurArray);
       out.resize (arr.shape());
       convertArray (out, arr);
-      shp = out.shape();
       break;
     }
   case TpUInt:
     {
       Array<Int64> arr = itsNode->getArrayInt (rownr);
-      Array<uInt>& out = *static_cast<Array<uInt>*>(itsCurResult);
+      Array<uInt>& out = *static_cast<Array<uInt>*>(itsCurArray);
       out.resize (arr.shape());
       convertArray (out, arr);
-      shp = out.shape();
       break;
     }
   case TpInt64:
     {
       Array<Int64> arr  = itsNode->getArrayInt (rownr);
-      Array<Int64>& out = *static_cast<Array<Int64>*>(itsCurResult);
+      Array<Int64>& out = *static_cast<Array<Int64>*>(itsCurArray);
       out.reference (arr);
-      shp = out.shape();
       break;
     }
   case TpFloat:
     {
       Array<Double> arr = itsNode->getArrayDouble (rownr);
-      Array<Float>& out = *static_cast<Array<Float>*>(itsCurResult);
+      Array<Float>& out = *static_cast<Array<Float>*>(itsCurArray);
       out.resize (arr.shape());
       convertArray (out, arr);
-      shp = out.shape();
       break;
     }
   case TpDouble:
     {
       Array<Double> arr  = itsNode->getArrayDouble (rownr);
-      Array<Double>& out = *static_cast<Array<Double>*>(itsCurResult);
+      Array<Double>& out = *static_cast<Array<Double>*>(itsCurArray);
       out.reference (arr);
-      shp = out.shape();
       break;
     }
   case TpComplex:
     {
       Array<DComplex> arr = itsNode->getArrayDComplex (rownr);
-      Array<Complex>& out = *static_cast<Array<Complex>*>(itsCurResult);
+      Array<Complex>& out = *static_cast<Array<Complex>*>(itsCurArray);
       out.resize (arr.shape());
       convertArray (out, arr);
-      shp = out.shape();
       break;
     }
   case TpDComplex:
     {
       Array<DComplex> arr  = itsNode->getArrayDComplex (rownr);
-      Array<DComplex>& out = *static_cast<Array<DComplex>*>(itsCurResult);
+      Array<DComplex>& out = *static_cast<Array<DComplex>*>(itsCurArray);
       out.reference (arr);
-      shp = out.shape();
       break;
     }
   case TpString:
     {
       Array<String> arr  = itsNode->getArrayString (rownr);
-      Array<String>& out = *static_cast<Array<String>*>(itsCurResult);
+      Array<String>& out = *static_cast<Array<String>*>(itsCurArray);
       out.reference (arr);
-      shp = out.shape();
       break;
     }
   default:
     throw DataManError ("VirtualTaQLColumn::getResult - unknown data type");
   }
-  return shp;
+  if (! itsShape.empty()  &&  ! itsShape.isEqual(itsCurArray->shape())) {
+    throw DataManError ("VirtualTaQLColumn::getResult - shape of result mismatches fixed "
+                        "shape of column " + columnName());
+  }
 }
 
+void VirtualTaQLColumn::getScalarColumnV (ArrayBase& arr)
+{
+  if (itsIsConst) {
+    // Constant value, so fill the array with the same value.
+    fillArray (arr);
+  } else {
+    getScalarColumnBase (arr);
+  }
+}
+void VirtualTaQLColumn::getScalarColumnCellsV (const RefRows& rownrs,
+                                               ArrayBase& arr)
+{
+  if (itsIsConst) {
+    // Constant value, so fill the array with the same value.
+    fillArray (arr);
+  } else {
+    getScalarColumnCellsBase (rownrs, arr);
+  }
+}
+void VirtualTaQLColumn::fillColumnCache()
+{
+  columnCache().setIncrement (0);
+  switch (itsDataType) {
+  case TpBool:
+    getBool (0, &itsBool);
+    columnCache().set (0, table().nrow()-1, &itsBool);
+    break;
+  case TpUChar:
+    getuChar (0, &itsuChar);
+    columnCache().set (0, table().nrow()-1, &itsuChar);
+    break;
+  case TpShort:
+    getShort (0, &itsShort);
+    columnCache().set (0, table().nrow()-1, &itsShort);
+    break;
+  case TpUShort:
+    getuShort (0, &itsuShort);
+    columnCache().set (0, table().nrow()-1, &itsuShort);
+    break;
+  case TpInt:
+    getInt (0, &itsInt);
+    columnCache().set (0, table().nrow()-1, &itsInt);
+    break;
+  case TpUInt:
+    getuInt (0, &itsuInt);
+    columnCache().set (0, table().nrow()-1, &itsuInt);
+    break;
+  case TpInt64:
+    getInt64 (0, &itsInt64);
+    columnCache().set (0, table().nrow()-1, &itsInt64);
+    break;
+  case TpFloat:
+    getfloat (0, &itsFloat);
+    columnCache().set (0, table().nrow()-1, &itsFloat);
+    break;
+  case TpDouble:
+    getdouble (0, &itsDouble);
+    columnCache().set (0, table().nrow()-1, &itsDouble);
+    break;
+  case TpComplex:
+    getComplex (0, &itsComplex);
+    columnCache().set (0, table().nrow()-1, &itsComplex);
+    break;
+  case TpDComplex:
+    getDComplex (0, &itsDComplex);
+    columnCache().set (0, table().nrow()-1, &itsDComplex);
+    break;
+  case TpString:
+    getString (0, &itsString);
+    columnCache().set (0, table().nrow()-1, &itsString);
+    break;
+  default:
+    throw DataManInvDT(itsColumnName);
+  }
+}
+
+void VirtualTaQLColumn::fillArray (ArrayBase& arr)
+{
+  Bool deleteIt;
+  void* ptr = arr.getVStorage (deleteIt);
+  switch (itsDataType) {
+  case TpBool:
+    objset (static_cast<Bool*>(ptr), itsBool, arr.size());
+    break;
+  case TpUChar:
+    objset (static_cast<uChar*>(ptr), itsuChar, arr.size());
+    break;
+  case TpShort:
+    objset (static_cast<Short*>(ptr), itsShort, arr.size());
+    break;
+  case TpUShort:
+    objset (static_cast<uShort*>(ptr), itsuShort, arr.size());
+    break;
+  case TpInt:
+    objset (static_cast<Int*>(ptr), itsInt, arr.size());
+    break;
+  case TpUInt:
+    objset (static_cast<uInt*>(ptr), itsuInt, arr.size());
+    break;
+  case TpInt64:
+    objset (static_cast<Int64*>(ptr), itsInt64, arr.size());
+    break;
+  case TpFloat:
+    objset (static_cast<Float*>(ptr), itsFloat, arr.size());
+    break;
+  case TpDouble:
+    objset (static_cast<Double*>(ptr), itsDouble, arr.size());
+    break;
+  case TpComplex:
+    objset (static_cast<Complex*>(ptr), itsComplex, arr.size());
+    break;
+  case TpDComplex:
+    objset (static_cast<DComplex*>(ptr), itsDComplex, arr.size());
+    break;
+  case TpString:
+    objset (static_cast<String*>(ptr), itsString, arr.size());
+    break;
+  default:
+    throw DataManInvDT(itsColumnName);
+  }
+  arr.putVStorage (ptr, deleteIt);
+}
 
 } //# NAMESPACE CASACORE - END
-
