@@ -74,8 +74,8 @@ int main ()
 	check("tForwardCol_tmp.data1", 0, 10);
 	check("tForwardCol_tmp.data2", 10, 10);
 	check("tForwardCol_tmp.data3", 10, 10);
-    } catch (AipsError& x) {
-	cout << "Caught an exception: " << x.getMesg() << endl;
+    } catch (std::exception& x) {
+	cout << "Caught an exception: " << x.what() << endl;
 	return 1;
     } 
     return 0;                           // exit with success status
