@@ -38,7 +38,7 @@
 #include <casacore/casa/Arrays/Cube.h>
 #include <casacore/casa/Arrays/ArrayMath.h>
 #include <casacore/casa/Arrays/ArrayLogical.h>
-#include <casacore/casa/Arrays/ArrayIO.h>
+#include <casacore/casa/IO/ArrayIO.h>
 #include <casacore/casa/Arrays/Slicer.h>
 #include <casacore/casa/Arrays/Slice.h>
 #include <casacore/casa/Utilities/Assert.h>
@@ -66,6 +66,7 @@ void testWithLocking();
 
 int main (int argc, const char* argv[])
 {
+  ///  DataManager::MAXROWNR32 = 0;
     uInt nr = 1000;
     if (argc > 1) {
 	istringstream istr(argv[1]);
@@ -83,8 +84,8 @@ int main (int argc, const char* argv[])
 	a (nr, 0);
 	f();
         testWithLocking();
-    } catch (AipsError& x) {
-	cout << "Caught an exception: " << x.getMesg() << endl;
+    } catch (std::exception& x) {
+	cout << "Caught an exception: " << x.what() << endl;
 	return 1;
     } 
     return 0;                           // exit with success status
@@ -248,6 +249,9 @@ void a (uInt bucketSize, uInt mode)
     }
     // All rows from 0 on get this value.
     arr4.put (0, vstr);
+    ///cout << "arr4 = ";
+    ///    cout << arr4(0) << ' '<< arr4(9) << endl;
+    ///cout << "arr4 = " << arr4.getColumn () << endl;
     cout << "arr4 = " << arr4.getColumn (Slicer(Slice(0,1))) << endl;
     // All rows from 1 on get this value.
     arr4.put (1, vstr);
@@ -433,7 +437,7 @@ void c()
     removedRows(12) = True;                    // row 10 was old row 12
     b (removedRows);
     // Remove several rows.
-    Vector<uInt> rows(5);
+    Vector<rownr_t> rows(5);
     for (i=0; i<5; i++) {
 	rows(i)=i+2;
 	removedRows(i+3) = True;
@@ -461,7 +465,7 @@ void d()
     // Remove the last 10 rows.
     // Open the table as read/write for that purpose.
     Table rwtab ("tIncrementalStMan_tmp.data", Table::Update);
-    Vector<uInt> rows(10);
+    Vector<rownr_t> rows(10);
     for (i=0; i<10; i++) {
 	rows(i)=i+10;
     }
@@ -493,13 +497,13 @@ void f()
     //# Try to change some arrays (which cannot be done).
     try {
 	arr1.put (0, vecf);
-    } catch (AipsError& x) {
-	cout << x.getMesg() << endl;         // shape cannot change
+    } catch (std::exception& x) {
+	cout << x.what() << endl;         // shape cannot change
     } 
     try {
 	arr7.put (0, vecb);
-    } catch (AipsError& x) {
-	cout << x.getMesg() << endl;         // shape cannot change
+    } catch (std::exception& x) {
+	cout << x.what() << endl;         // shape cannot change
     } 
     Vector<Bool> removedRows(20);
     removedRows.set (False);
@@ -556,7 +560,7 @@ void testWithLocking()
                                                    IPosition(1,n)));
       // Check the contents.
       for (uInt i=0; i<n; ++i) {
-        AlwaysAssertExit (vec[i] == row/10000*10000);
+        AlwaysAssertExit (vec[i] == (Int)row/10000*10000);
         row++;
       }
       tab.unlock();
