@@ -61,8 +61,8 @@ int main() {
       readTable(TSMOption::Buffer, i==0);
       readTable(TSMOption::MMap, i==0);
     }
-  } catch (AipsError& x) {
-    cout << "Caught an exception: " << x.getMesg() << endl;
+  } catch (std::exception& x) {
+    cout << "Caught an exception: " << x.what() << endl;
     return 1;
   } 
   return 0;                           // exit with success status
