@@ -35,6 +35,7 @@
 #include <casacore/casa/Arrays/ArrayLogical.h>
 #include <casacore/casa/Arrays/ArrayUtil.h>
 #include <casacore/casa/Arrays/Slicer.h>
+#include <casacore/casa/IO/ArrayIO.h>
 #include <casacore/casa/OS/CanonicalConversion.h>
 #include <casacore/casa/OS/LECanonicalConversion.h>
 #include <casacore/casa/OS/Timer.h>
@@ -328,8 +329,8 @@ void writeVar (int acc, Bool chk, const IPosition& shape,
     }
     // Sync to measure true IO.
     table.flush(True);
-  } catch (AipsError& x) {
-    cout << "Caught an exception: " << x.getMesg() << endl;
+  } catch (std::exception& x) {
+    cout << "Caught an exception: " << x.what() << endl;
   }
   timer.show("Write     ");
 }
@@ -457,8 +458,8 @@ int main (int argc, const char* argv[])
 	ok = False;
       }
     }
-  } catch (AipsError& x) {
-    cout << "Caught an exception: " << x.getMesg() << endl;
+  } catch (std::exception& x) {
+    cout << "Caught an exception: " << x.what() << endl;
     return 1;
   } 
   cout << "<<<" << endl;
