@@ -27,7 +27,7 @@
 //# $Id$
 
 #include <casacore/tables/LogTables/LoggerHolder.h>
-#include <casacore/tables/Tables/Table.h>
+#include <casacore/tables/Tables/TableUtil.h>
 #include <casacore/casa/Exceptions/Error.h>
 #include <casacore/casa/Utilities/Assert.h>
 #include <casacore/casa/iostream.h>
@@ -45,7 +45,7 @@ void doIt (Bool tempClose)
 
   // Make sure we have a new table.
   if (Table::isReadable ("tLoggerHolder_tmp.log")) {
-    Table::deleteTable ("tLoggerHolder_tmp.log");
+    TableUtil::deleteTable ("tLoggerHolder_tmp.log");
   }
   // Create with a TableLogSink.
   // Test copy ctor and assignment.
