@@ -196,11 +196,6 @@ public:
     TableExprNodeArrayPlusString (const TableExprNodeRep&);
     ~TableExprNodeArrayPlusString();
     MArray<String> getArrayString (const TableExprId& id);
-private:
-    // Concatenate <src>nr</src> arrays of strings.
-    // The increment is 0 for a scalar value. Otherwise it is 1.
-    void concString (String* to, const String* left, Int incrLeft,
-                     const String* right, Int incrRight, uInt nr) const;
 };
 
 
