@@ -32,10 +32,11 @@
 #include <casacore/casa/aips.h>
 #include <casacore/tables/TaQL/TaQLNodeRep.h>
 #include <casacore/tables/TaQL/TaQLStyle.h>
-#include <casacore/casa/Utilities/CountedPtr.h>
-#include <casacore/casa/OS/Mutex.h>
-#include <vector>
+
 #include <iostream>
+#include <mutex>
+#include <vector>
+#include <memory>
 
 namespace casacore { //# NAMESPACE CASACORE - BEGIN
 
@@ -88,7 +89,7 @@ public:
 
   // Construct for given letter. It takes over the pointer.
   TaQLNode (TaQLNodeRep* rep)
-    { itsRep = rep; }
+    { itsRep.reset (rep); }
 
   // Copy constructor (reference semantics).
   TaQLNode (const TaQLNode& that)
@@ -112,11 +113,12 @@ public:
 
   // Parse a TaQL command and return the result.
   // An exception is thrown in case of parse errors.
+  // The parse tree is deleted by function clearNodeCreated.
   static TaQLNode parse (const String& command);
 
   // Does the envelope contain a letter?
   Bool isValid() const
-    { return itsRep; }
+    { return Bool(itsRep); }
 
   // Return the type of letter.
   char nodeType() const
@@ -135,14 +137,14 @@ public:
   void show (std::ostream& os) const
     { if (itsRep) itsRep->show (os); }
 
-  // Save and restore the entire tree.
+  // Save and restore the entire parse tree.
   // <group>
   void save (AipsIO& aio) const;
   static TaQLNode restore (AipsIO& aio);
   // </group>
 
 protected:
-  CountedPtr<TaQLNodeRep> itsRep;
+  std::shared_ptr<TaQLNodeRep> itsRep;
 
 private:
   // Delete all nodes that were created by the parser.
@@ -163,7 +165,7 @@ public:
   // Keep the TaQL style to use.
   static TaQLStyle theirStyle;
   // Use a mutex to guard the statics.
-  static Mutex theirMutex;
+  static std::mutex theirMutex;
 };
 
 
