@@ -113,6 +113,8 @@ public:
   virtual TaQLNodeResult visitAddRowNode   (const TaQLAddRowNodeRep& node) = 0;
   virtual TaQLNodeResult visitConcTabNode  (const TaQLConcTabNodeRep& node) = 0;
   virtual TaQLNodeResult visitShowNode     (const TaQLShowNodeRep& node) = 0;
+  virtual TaQLNodeResult visitCopyColNode  (const TaQLCopyColNodeRep& node) = 0;
+  virtual TaQLNodeResult visitDropTabNode  (const TaQLDropTabNodeRep& node) = 0;
   // </group>
 
 protected:
