@@ -113,25 +113,32 @@ public:
   // Default constructor for container class.
   TableParse();
 
-  // Copy constructor (copy semantics).
-  TableParse (const TableParse&);
-
-  // Assignment (copy semantics).
-  TableParse& operator= (const TableParse&);
-
   // Associate the table and the shorthand.
-  TableParse (const Table& table, const String& shorthand);
+  TableParse (const Table& table, Int tabnr, const String& name,
+              const String& shorthand);
 
-  // Test if shorthand matches.
+  // Test if shorthand matches. If also matches if the given shorthand is empty.
   Bool test (const String& shortHand) const;
 
+  // Get the given table number (of $i tables in TempTables)
+  Int tabnr() const;
+
+  // Get the given table name.
+  const String& name() const;
+
   // Get the shorthand.
   const String& shorthand() const;
 
   // Get table object.
   const Table& table() const;
+  Table& table();
+
+  // Replace the Table object.
+  void replaceTable (const Table&);
 
 private:
+  Int     tabnr_p;
+  String  name_p;
   String  shorthand_p;
   Table   table_p;
 };
@@ -390,6 +397,7 @@ public:
     PCALC,
     PCRETAB,
     PALTTAB,
+    PDROPTAB,
     PSHOW
   };
 
@@ -413,8 +421,8 @@ public:
   TableExprNode getNode() const
     { return node_p; }
 
-  // Create a temporary table in no tables are given in FROM.
-  void makeTableNoFrom (const vector<TableParseSelect*>& stack);
+  // Create a temporary table if no tables are given in FROM.
+  void makeTableNoFrom (const std::vector<TableParseSelect*>& stack);
 
   // Execute the select command (select/sort/projection/groupby/having/giving).
   // The setInGiving flag tells if a set in the GIVING part is allowed.
@@ -424,7 +432,9 @@ public:
   // It will be used as the default value for the LIMIT clause.
   // 0 = no maximum.
   void execute (Bool showTimings, Bool setInGiving,
-                Bool mustSelect, rownr_t maxRow, Bool doTracing=False);
+                Bool mustSelect, rownr_t maxRow, Bool doTracing=False,
+                const std::vector<const Table*>& tempTables = std::vector<const Table*>(),
+                const std::vector<TableParseSelect*>& stack = std::vector<TableParseSelect*>());
 
   // Execute a query in a from clause resulting in a Table.
   Table doFromQuery (Bool showTimings);
@@ -445,7 +455,7 @@ public:
 
   // Keep the groupby expressions.
   // It checks if they are all scalar expressions.
-  void handleGroupby (const vector<TableExprNode>&, Bool rollup);
+  void handleGroupby (const std::vector<TableExprNode>&, Bool rollup);
 
   // Keep the having expression.
   void handleHaving (const TableExprNode&);
@@ -453,11 +463,18 @@ public:
   // Keep the expression of a calculate command.
   void handleCalcComm (const TableExprNode&);
 
+  // Handle the DROP TABLE command.
+  void handleDropTab (const std::vector<const Table*>& tempTables,
+                      const std::vector<TableParseSelect*>& stack);
+  
   // Keep the create table command.
-  void handleCreTab (const Record& dmInfo);
+  void handleCreTab (const Record& dmInfo,
+                     const std::vector<const Table*>& tempTables,
+                     const std::vector<TableParseSelect*>& stack);
 
   // Keep the column specification in a create table command.
-  void handleColSpec (const String& columnName, const String& dataType,
+  void handleColSpec (const String& columnName, const String& likeColName,
+                      const String& dataType,
                       const Record& spec, Bool isCOrder=False);
 
   // Reopen the table (for update) used in the ALTER TABLE command.
@@ -467,6 +484,9 @@ public:
   // The column descriptions have already been added to tableDesc_p.
   void handleAddCol (const Record& dmInfo);
 
+  // Initialize the table and data manager descriptions.
+  void initDescriptions (const TableDesc&, const Record& dminfo);
+
   // Add a keyword or replace a keyword with the value of another keyword.
   // The keywords can be table or column keywords (col::key).
   ValueHolder getRecFld (const String& name);
@@ -481,6 +501,9 @@ public:
   // data type.
   static String getTypeString (const String& typeStr, DataType type);
 
+  // Handle copying of columns.
+  void handleCopyCol (Bool showTimings);
+  
   // Add a keyword or replace a keyword with a value.
   // The keyword can be a table or column keyword (col::key).
   // The data type string can be empty leaving the data type unchanged.
@@ -496,7 +519,9 @@ public:
   // Split the given name into optional shorthand, column and fields.
   // Find the keywordset for it and fill in the final keyword name.
   // It is a helper function for handleSetKey, etc.
-  TableRecord& findKeyword (const String& name, String& keyName);
+  // If update=True, rwKeywordSet() is used to ensure the table is updated.
+  TableRecord& findKeyword (const String& name, String& keyName,
+                            Bool update=True);
 
   // Add an update object.
   void addUpdate (const CountedPtr<TableParseUpdate>& upd);
@@ -537,23 +562,22 @@ public:
   void handleAddRow (const TableExprNode& expr);
 
   // Add a table nr, name, or object to the container.
-  void addTable (Int tabnr, const String& name,
-                 const Table& table,
-                 const String& shorthand,
-                 Bool addToFromList,
-                 const vector<const Table*> tempTables,
-                 const vector<TableParseSelect*>& stack);
+  Table addTable (Int tabnr, const String& name,
+                  const Table& table,
+                  const String& shorthand,
+                  Bool addToFromList,
+                  const std::vector<const Table*>& tempTables,
+                  const std::vector<TableParseSelect*>& stack);
 
   // Make a Table object for given name, seqnr or so.
   // If <src>alwaysOpen=False</src> the table will only be looked up,
   // but not opened if not found. This is meant for concatenated tables
   // in TaQLNodeHandler.
-  Table makeTable (Int tabnr, const String& name,
-                   const Table& ftab,
-                   const String& shorthand,
-                   const vector<const Table*> tempTables,
-                   const vector<TableParseSelect*>& stack,
-                   Bool alwaysOpen=True);
+  Table getTable (Int tabnr, const String& name,
+                  const Table& ftab,
+                  const std::vector<const Table*>& tempTables,
+                  const std::vector<TableParseSelect*>& stack,
+                  Bool alwaysOpen=True);
 
   // Replace the first table (used by CALC command).
   void replaceTable (const Table& table);
@@ -613,15 +637,16 @@ public:
   String getTableInfo (const Vector<String>& parts, const TaQLStyle& style);
 
   // Split a name into its parts (shorthand, column and field names).
-  // True is returned if the name contained a keyword part.
+  // If isKeyword is True, the first part of name is a keyword, even if no :: is given.
+  // True is returned if the name contains a keyword part.
   // In that case fieldNames contains the keyword name and the possible
   // subfields. The possible shorthand and the column name are
   // filled in if it is a column keyword.
   // If the name represents a column, fieldNames contains the subfields
   // of the column (for the case where the column contains records).
-  // If the name is invalid, an exception is thrown if checkError=True.
+  // If allowNoKey is True, a single :: is allowed, otherwise the name is invalid.
+  // If the name is invalid, exceptions are only thrown if checkError=True.
   // Otherwise the name is treated as a normal name without keyword.
-  // If allowEmtpy is True, :: is allowed, otherwise an error is thrown.
   static Bool splitName (String& shorthand, String& columnName,
                          Vector<String>& fieldNames, const String& name,
                          Bool checkError, Bool isKeyword, Bool allowNoKey);
@@ -634,7 +659,7 @@ private:
   Int testGroupAggr (std::vector<TableExprNodeRep*>& aggr) const;
 
   // Get the aggregate functions used in SELECT and HAVING.
-  vector<TableExprNodeRep*> getAggrNodes() const;
+  std::vector<TableExprNodeRep*> getAggrNodes() const;
 
   // Try to make a UDF function node for the given function name and arguments.
   static TableExprNode makeUDFNode (TableParseSelect*,
@@ -681,8 +706,21 @@ private:
   // Create a table using the given parameters.
   // The variables set by handleGiven are used for name and type.
   Table createTable (const TableDesc& td,
-                     Int64 nrow, const Record& dmInfo);
+                     Int64 nrow, const Record& dmInfo,
+                     const std::vector<const Table*>& tempTables,
+                     const std::vector<TableParseSelect*>& stack);
+  Table createSubTable (const String& subtableName,
+                        const TableDesc& td, Int64 nrow,
+                        const Record& dmInfo,
+                        const std::vector<const Table*>& tempTables,
+                        const std::vector<TableParseSelect*>& stack);
 
+  // Open the parent table of a subtable.
+  Table openParentTable (const String& fullName,
+                         const String& subTableName,
+                         const std::vector<const Table*>& tempTables,
+                         const std::vector<TableParseSelect*>& stack);
+  
   // Make the (empty) table for the epxression in the SELECT clause.
   void makeProjectExprTable();
 
@@ -728,7 +766,9 @@ private:
   Table doDistinct (Bool showTimings, const Table& table);
 
   // Finish the table (rename, copy, and/or flush).
-  Table doFinish (Bool showTimings, Table& table);
+  Table doFinish (Bool showTimings, Table& table,
+                  const std::vector<const Table*>& tempTables,
+                  const std::vector<TableParseSelect*>& stack);
 
   // Update the values in the columns (helpers of doUpdate).
   // <group>
@@ -790,6 +830,8 @@ private:
   // If no shorthand is given, the first table is returned (if there).
   // If not found, a null Table object is returned.
   Table findTable (const String& shorthand, Bool doWith) const;
+  Table findTable (const String& shorthand, Bool doWith,
+                   const std::vector<TableParseSelect*>& stack) const;
 
   // Handle the selection of a wildcarded column name.
   void handleWildColumn (Int stringType, const String& name);
@@ -805,23 +847,16 @@ private:
                       const Vector<String>& unitName,
                       const Record& attributes);
 
+  // Find the ColumnDesc and data manager info of another column (a LIKE column).
+  // The LIKE column name can be qualified to use another table.
+  // It sets the new column name in the data manager info.
+  // An exception is thrown if colName is invalid or unknown.
+  std::pair<ColumnDesc,Record> findColumnInfo (const String& colName,
+                                               const String& newColName) const;
+  
   // Find the names of all stored columns in a table.
   Block<String> getStoredColumns (const Table& tab) const;
 
-  // Try to find the keyword representing a table in one of the tables
-  // in any select block (from inner to outer).
-  // If not found, an exception is thrown.
-  static Table tableKey (const String& fullName,
-                         const String& shorthand, const String& columnName,
-                         const Vector<String>& fieldNames,
-                         const vector<TableParseSelect*>& stack);
-
-  // Try to find the keyword representing a table in the given table.
-  // If the columnName is empty, the keyword is a table keyword.
-  // If not found, a null Table object is returned.
-  static Table findTableKey (const Table& table, const String& columnName,
-                             const Vector<String>& keyNames);
-
   // Check if the tables used in selection columns have the same
   // size as the first table given in FROM.
   void checkTableProjSizes() const;
@@ -831,14 +866,14 @@ private:
   // This offers much faster map access then doGroupByAggrMultiple.
   template<typename T>
   std::vector<CountedPtr<TableExprGroupFuncSet> > doGroupByAggrSingleKey
-  (const vector<TableExprNodeRep*>& aggrNodes)
+  (const std::vector<TableExprNodeRep*>& aggrNodes)
   {
     // We have to group the data according to the (possibly empty) groupby.
     // We step through the table in the normal order which may not be the
     // groupby order.
     // A map<key,int> is used to keep track of the results where the int
     // is the index in a vector of a set of aggregate function objects.
-    vector<CountedPtr<TableExprGroupFuncSet> > funcSets;
+    std::vector<CountedPtr<TableExprGroupFuncSet> > funcSets;
     std::map<T, int> keyFuncMap;
     T lastKey = std::numeric_limits<T>::max();
     int groupnr = -1;
@@ -868,17 +903,19 @@ private:
   // Create the set of aggregate functions and groupby keys in case
   // multiple keys are given.
   std::vector<CountedPtr<TableExprGroupFuncSet> > doGroupByAggrMultipleKeys
-  (const vector<TableExprNodeRep*>& aggrNodes);
+  (const std::vector<TableExprNodeRep*>& aggrNodes);
 
   //# Command type.
   CommandType commandType_p;
-  //# Table description for a series of column descriptions.
-  TableDesc tableDesc_p;
+  //# Table and data manager description for a series of column descriptions.
+  //# TableDesc has no copy ctor, so use a shared_ptr.
+  std::shared_ptr<TableDesc> tableDesc_p;
+  Record dminfo_p;
   //# Vector of TableParse objects (from WITH and FROM clause).
   //# This is needed for the functions above, otherwise they have no
   //# way to communicate.
-  vector<TableParse> withTables_p;
-  vector<TableParse> fromTables_p;
+  std::vector<TableParse> withTables_p;
+  std::vector<TableParse> fromTables_p;
   //# Block of selected column names (new name in case of select).
   Block<String> columnNames_p;
   //# Block of selected mask column names (for masked arrays).
@@ -902,13 +939,12 @@ private:
   StorageOption storageOption_p;
   Table::EndianFormat endianFormat_p;
   Bool overwrite_p;
-  Record dminfo_p;
   //# Resulting set (from GIVING part).
   TableExprNodeSet* resultSet_p;
   //# The WHERE expression tree.
   TableExprNode node_p;
   //# The GROUPBY expressions.
-  vector<TableExprNode> groupbyNodes_p;
+  std::vector<TableExprNode> groupbyNodes_p;
   Bool groupbyRollup_p;   //# use ROLLUP in GROUPBY?
   //# The HAVING expression.
   TableExprNode havingNode_p;
@@ -936,7 +972,7 @@ private:
   //# All nodes that need to be adjusted for a selection of rownrs.
   //# It can consist of column nodes and the rowid function node.
   //# Some nodes (in aggregate functions) can later be disabled for adjustment.
-  vector<TableExprNode> applySelNodes_p;
+  std::vector<TableExprNode> applySelNodes_p;
   //# The resulting table.
   Table table_p;
   //# The first table used when creating a column object.
@@ -956,7 +992,13 @@ private:
 
 //# Implement the inline functions.
 inline Bool TableParse::test (const String& str) const
-  { return (shorthand_p == str  ?  True : False); }
+  { return (str.empty()  ||  shorthand_p == str); }
+
+inline Int TableParse::tabnr() const
+  { return tabnr_p; }
+
+inline const String& TableParse::name() const
+  { return name_p; }
 
 inline const String& TableParse::shorthand() const
   { return shorthand_p; }
@@ -964,6 +1006,12 @@ inline const String& TableParse::shorthand() const
 inline const Table& TableParse::table() const
   { return table_p; }
 
+inline Table& TableParse::table()
+  { return table_p; }
+
+inline void TableParse::replaceTable (const Table& table)
+  { table_p = table; }
+
 
 inline void TableParseUpdate::setColumnName (const String& name)
   { columnName_p = name; }
