@@ -43,13 +43,13 @@ BaseColumn::~BaseColumn()
 //# By default all functions throw an exception
 //# to ensure they are called correctly.
 
-void BaseColumn::setShape (uInt, const IPosition&)
+void BaseColumn::setShape (rownr_t, const IPosition&)
 {
   throw (TableInvOper ("invalid setShape() for column " + colDescPtr_p->name() +
                        "; only valid for an array"));
 }
 
-void BaseColumn::setShape (uInt, const IPosition&, const IPosition&)
+void BaseColumn::setShape (rownr_t, const IPosition&, const IPosition&)
 {
   throw (TableInvOper ("invalid setShape() for column " + colDescPtr_p->name() +
                        "; only valid for an array"));
@@ -69,21 +69,21 @@ IPosition BaseColumn::shapeColumn() const
   return IPosition(0);
 }
 
-uInt BaseColumn::ndim (uInt) const
+uInt BaseColumn::ndim (rownr_t) const
 {
   throw (TableInvOper ("invalid ndim() for column " + colDescPtr_p->name() +
                        "; only valid for an array"));
   return 0;
 }
 
-IPosition BaseColumn::shape (uInt) const
+IPosition BaseColumn::shape (rownr_t) const
 {
   throw (TableInvOper ("invalid shape() for column " + colDescPtr_p->name() +
                        "; only valid for an array"));
   return IPosition(0);
 }
 
-IPosition BaseColumn::tileShape (uInt) const
+IPosition BaseColumn::tileShape (rownr_t) const
 {
   throw (TableInvOper ("invalid tileShape() for column " + colDescPtr_p->name() +
                        "; only valid for an array"));
@@ -95,119 +95,111 @@ Bool BaseColumn::canChangeShape() const
     return False;                      // can not be changed
 }
 
-Bool BaseColumn::canAccessScalarColumn (Bool& reask) const
+void BaseColumn::get (rownr_t, void*) const
 {
-    reask = False;                     // By default an entire column
-    return False;                      // can never be accessed
-}
-Bool BaseColumn::canAccessArrayColumn (Bool& reask) const
-{
-    reask = False;                     // By default an entire column
-    return False;                      // can never be accessed
-}
-Bool BaseColumn::canAccessScalarColumnCells (Bool& reask) const
-{
-    reask = False;                     // By default cells in a column
-    return False;                      // can never be accessed
-}
-Bool BaseColumn::canAccessArrayColumnCells (Bool& reask) const
-{
-    reask = False;                     // By default cells in a column
-    return False;                      // can never be accessed
-}
-Bool BaseColumn::canAccessSlice (Bool& reask) const
-{
-    reask = False;                     // By default a cell slice
-    return False;                      // can never be accessed
-}
-Bool BaseColumn::canAccessColumnSlice (Bool& reask) const
-{
-    reask = False;                     // By default a column slice
-    return False;                      // can never be accessed
+  throw (TableInvOper ("get() not implemented for column " +
+                       colDesc_p.name() + "; only valid for a scalar"));
 }
 
+void BaseColumn::getArray (rownr_t, ArrayBase&) const
+{
+  throw (TableInvOper ("getArray() not implemented for column " +
+                       colDesc_p.name() + "; only valid for an array"));
+}
 
-void BaseColumn::getSlice (uInt, const Slicer&, void*) const
+void BaseColumn::getSlice (rownr_t, const Slicer&, ArrayBase&) const
 {
   throw (TableInvOper ("getSlice() not implemented for column " +
                        colDescPtr_p->name() + "; only valid for an array"));
 }
 
-void BaseColumn::getScalarColumn (void*) const
+void BaseColumn::getScalarColumn (ArrayBase&) const
 {
   throw (TableInvOper ("getScalarColumn() not implemented for column " +
                        colDescPtr_p->name() + "; only valid for a scalar"));
 }
 
-void BaseColumn::getArrayColumn (void*) const
+void BaseColumn::getArrayColumn (ArrayBase&) const
 {
   throw (TableInvOper ("getArrayColumn() not implemented for column " +
                        colDescPtr_p->name() + "; only valid for an array"));
 }
 
-void BaseColumn::getScalarColumnCells (const RefRows&, void*) const
+void BaseColumn::getScalarColumnCells (const RefRows&, ArrayBase&) const
 {
   throw (TableInvOper ("getScalarColumnCells() not implemented for column " +
                        colDescPtr_p->name() + "; only valid for a scalar"));
 }
 
-void BaseColumn::getArrayColumnCells (const RefRows&, void*) const
+void BaseColumn::getArrayColumnCells (const RefRows&, ArrayBase&) const
 {
   throw (TableInvOper ("getArrayColumnCells() not implemented for column " +
                        colDescPtr_p->name() + "; only valid for an array"));
 }
 
 void BaseColumn::getColumnSliceCells (const RefRows&,
-				      const Slicer&, void*) const
+				      const Slicer&, ArrayBase&) const
 {
   throw (TableInvOper ("getColumnCells(Slicer&) not implemented for column " +
                        colDescPtr_p->name() + "; only valid for an array"));
 }
 
-void BaseColumn::getColumnSlice (const Slicer&, void*) const
+void BaseColumn::getColumnSlice (const Slicer&, ArrayBase&) const
 {
   throw (TableInvOper ("getColumn(Slicer&) not implemented for column " +
                        colDescPtr_p->name() + "; only valid for an array"));
 }
 
-void BaseColumn::putSlice (uInt, const Slicer&, const void*)
+void BaseColumn::put (rownr_t, const void*)
+{
+  throw (TableInvOper ("put() not implemented for column " +
+                       colDesc_p.name() + "; only valid for a scalar"));
+}
+
+void BaseColumn::putArray (rownr_t, const ArrayBase&)
+{
+  throw (TableInvOper ("putArray() not implemented for column " +
+                       colDesc_p.name() + "; only valid for an array"));
+}
+
+void BaseColumn::putSlice (rownr_t, const Slicer&, const ArrayBase&)
 {
   throw (TableInvOper ("putSlice() not implemented for column " +
                        colDescPtr_p->name() + "; only valid for an array"));
 }
 
-void BaseColumn::putScalarColumn (const void*)
+void BaseColumn::putScalarColumn (const ArrayBase&)
 {
   throw (TableInvOper ("putScalarColumn() not implemented for column " +
                        colDescPtr_p->name() + "; only valid for a scalar"));
 }
 
-void BaseColumn::putArrayColumn (const void*)
+void BaseColumn::putArrayColumn (const ArrayBase&)
 {
   throw (TableInvOper ("putArrayColumn() not implemented for column " +
                        colDescPtr_p->name() + "; only valid for an array"));
 }
 
-void BaseColumn::putScalarColumnCells (const RefRows&, const void*)
+void BaseColumn::putScalarColumnCells (const RefRows&, const ArrayBase&)
 {
   throw (TableInvOper ("putScalarColumnCells() not implemented for column " +
                        colDescPtr_p->name() + "; only valid for a scalar"));
 }
 
-void BaseColumn::putArrayColumnCells (const RefRows&, const void*)
+void BaseColumn::putArrayColumnCells (const RefRows&, const ArrayBase&)
 {
   throw (TableInvOper ("putArrayColumnCells() not implemented for column " +
                        colDescPtr_p->name() + "; only valid for an array"));
 }
 
-void BaseColumn::putColumnSlice (const Slicer&, const void*)
+void BaseColumn::putColumnSlice (const Slicer&, const ArrayBase&)
 {
   throw (TableInvOper ("putColumn(Slicer&) not implemented for column " +
                        colDescPtr_p->name() + "; only valid for an array"));
 }
 
 void BaseColumn::putColumnSliceCells (const RefRows&,
-				      const Slicer&, const void*)
+				      const Slicer&, const ArrayBase&)
 {
   throw (TableInvOper ("putColumnCells(Slicer&) not implemented for column " +
                        colDescPtr_p->name() + "; only valid for an array"));
@@ -215,22 +207,17 @@ void BaseColumn::putColumnSliceCells (const RefRows&,
 
 
 void BaseColumn::makeSortKey (Sort&, CountedPtr<BaseCompare>&, Int,
-                              const void*&)
+                              CountedPtr<ArrayBase>&)
 {
   throw (TableInvOper ("makeSortKey() for column " + colDescPtr_p->name() +
                        " is only valid for a scalar"));
 }
 void BaseColumn::makeRefSortKey (Sort&, CountedPtr<BaseCompare>&, Int,
-				 const Vector<uInt>&, const void*&)
+				 const Vector<rownr_t>&, CountedPtr<ArrayBase>&)
 {
   throw (TableInvOper ("makeSortKey(rownrs) for column " + colDescPtr_p->name() +
                        " is only valid for a scalar"));
 }
-void BaseColumn::freeSortKey (const void*&)
-{
-  throw (TableInvOper ("freeSortKey() for column " + colDescPtr_p->name() +
-                       " is only valid for a scalar"));
-}
 void BaseColumn::allocIterBuf (void*&, void*&, CountedPtr<BaseCompare>&)
 {
   throw (TableInvOper ("allocIterBuf() for column " + colDescPtr_p->name() +
@@ -243,7 +230,7 @@ void BaseColumn::freeIterBuf (void*&, void*&)
 }
 
 
-void BaseColumn::getScalar (uInt rownr, Bool& value) const
+void BaseColumn::getScalar (rownr_t rownr, Bool& value) const
 {
     if (!colDescPtr_p->isScalar()) {
         throwGetScalar();
@@ -257,7 +244,7 @@ void BaseColumn::getScalar (uInt rownr, Bool& value) const
     }
 }
 
-void BaseColumn::getScalar (uInt rownr, uChar& value) const
+void BaseColumn::getScalar (rownr_t rownr, uChar& value) const
 {
     if (!colDescPtr_p->isScalar()) {
         throwGetScalar();
@@ -271,7 +258,7 @@ void BaseColumn::getScalar (uInt rownr, uChar& value) const
     }
 }
 
-void BaseColumn::getScalar (uInt rownr, Short& value) const
+void BaseColumn::getScalar (rownr_t rownr, Short& value) const
 {
     if (!colDescPtr_p->isScalar()) {
         throwGetScalar();
@@ -285,7 +272,7 @@ void BaseColumn::getScalar (uInt rownr, Short& value) const
     }
 }
 
-void BaseColumn::getScalar (uInt rownr, uShort& value) const
+void BaseColumn::getScalar (rownr_t rownr, uShort& value) const
 {
     if (!colDescPtr_p->isScalar()) {
         throwGetScalar();
@@ -304,7 +291,7 @@ void BaseColumn::getScalar (uInt rownr, uShort& value) const
     }
 }
 
-void BaseColumn::getScalar (uInt rownr, Int& value) const
+void BaseColumn::getScalar (rownr_t rownr, Int& value) const
 {
     if (!colDescPtr_p->isScalar()) {
         throwGetScalar();
@@ -333,7 +320,7 @@ void BaseColumn::getScalar (uInt rownr, Int& value) const
     }
 }
 
-void BaseColumn::getScalar (uInt rownr, uInt& value) const
+void BaseColumn::getScalar (rownr_t rownr, uInt& value) const
 {
     if (!colDescPtr_p->isScalar()) {
         throwGetScalar();
@@ -357,7 +344,7 @@ void BaseColumn::getScalar (uInt rownr, uInt& value) const
     }
 }
 
-void BaseColumn::getScalar (uInt rownr, Int64& value) const
+void BaseColumn::getScalar (rownr_t rownr, Int64& value) const
 {
     if (!colDescPtr_p->isScalar()) {
         throwGetScalar();
@@ -396,7 +383,7 @@ void BaseColumn::getScalar (uInt rownr, Int64& value) const
     }
 }
 
-void BaseColumn::getScalar (uInt rownr, float& value) const
+void BaseColumn::getScalar (rownr_t rownr, float& value) const
 {
     if (!colDescPtr_p->isScalar()) {
         throwGetScalar();
@@ -445,7 +432,7 @@ void BaseColumn::getScalar (uInt rownr, float& value) const
     }
 }
 
-void BaseColumn::getScalar (uInt rownr, double& value) const
+void BaseColumn::getScalar (rownr_t rownr, double& value) const
 {
     if (!colDescPtr_p->isScalar()) {
         throwGetScalar();
@@ -494,7 +481,7 @@ void BaseColumn::getScalar (uInt rownr, double& value) const
     }
 }
 
-void BaseColumn::getScalar (uInt rownr, Complex& value) const
+void BaseColumn::getScalar (rownr_t rownr, Complex& value) const
 {
     if (!colDescPtr_p->isScalar()) {
         throwGetScalar();
@@ -554,7 +541,7 @@ void BaseColumn::getScalar (uInt rownr, Complex& value) const
     }
 }
 
-void BaseColumn::getScalar (uInt rownr, DComplex& value) const
+void BaseColumn::getScalar (rownr_t rownr, DComplex& value) const
 {
     if (!colDescPtr_p->isScalar()) {
         throwGetScalar();
@@ -613,7 +600,7 @@ void BaseColumn::getScalar (uInt rownr, DComplex& value) const
     }
 }
 
-void BaseColumn::getScalar (uInt rownr, String& value) const
+void BaseColumn::getScalar (rownr_t rownr, String& value) const
 {
     if (!colDescPtr_p->isScalar()) {
         throwGetScalar();
@@ -627,7 +614,7 @@ void BaseColumn::getScalar (uInt rownr, String& value) const
     }
 }
 
-void BaseColumn::getScalar (uInt rownr, TableRecord& value) const
+void BaseColumn::getScalar (rownr_t rownr, TableRecord& value) const
 {
     if (!colDescPtr_p->isScalar()) {
         throwGetScalar();
@@ -641,7 +628,7 @@ void BaseColumn::getScalar (uInt rownr, TableRecord& value) const
     }
 }
 
-void BaseColumn::getScalar (uInt rownr, void* value,
+void BaseColumn::getScalar (rownr_t rownr, void* value,
 			    const String& dataTypeId) const
 {
     if (!colDescPtr_p->isScalar()) {
@@ -655,7 +642,7 @@ void BaseColumn::getScalar (uInt rownr, void* value,
 }
 
 
-void BaseColumn::putScalar (uInt rownr, const Bool& value)
+void BaseColumn::putScalar (rownr_t rownr, const Bool& value)
 {
     if (!colDescPtr_p->isScalar()) {
         throwPutScalar();
@@ -669,7 +656,7 @@ void BaseColumn::putScalar (uInt rownr, const Bool& value)
     }
 }
 
-void BaseColumn::putScalar (uInt rownr, const uChar& value)
+void BaseColumn::putScalar (rownr_t rownr, const uChar& value)
 {
     if (!colDescPtr_p->isScalar()) {
         throwPutScalar();
@@ -726,7 +713,7 @@ void BaseColumn::putScalar (uInt rownr, const uChar& value)
     }
 }
 
-void BaseColumn::putScalar (uInt rownr, const Short& value)
+void BaseColumn::putScalar (rownr_t rownr, const Short& value)
 {
     if (!colDescPtr_p->isScalar()) {
         throwPutScalar();
@@ -768,7 +755,7 @@ void BaseColumn::putScalar (uInt rownr, const Short& value)
     }
 }
 
-void BaseColumn::putScalar (uInt rownr, const uShort& value)
+void BaseColumn::putScalar (rownr_t rownr, const uShort& value)
 {
     if (!colDescPtr_p->isScalar()) {
         throwPutScalar();
@@ -815,7 +802,7 @@ void BaseColumn::putScalar (uInt rownr, const uShort& value)
     }
 }
 
-void BaseColumn::putScalar (uInt rownr, const Int& value)
+void BaseColumn::putScalar (rownr_t rownr, const Int& value)
 {
     if (!colDescPtr_p->isScalar()) {
         throwPutScalar();
@@ -852,7 +839,7 @@ void BaseColumn::putScalar (uInt rownr, const Int& value)
     }
 }
 
-void BaseColumn::putScalar (uInt rownr, const uInt& value)
+void BaseColumn::putScalar (rownr_t rownr, const uInt& value)
 {
     if (!colDescPtr_p->isScalar()) {
         throwPutScalar();
@@ -889,7 +876,7 @@ void BaseColumn::putScalar (uInt rownr, const uInt& value)
     }
 }
 
-void BaseColumn::putScalar (uInt rownr, const Int64& value)
+void BaseColumn::putScalar (rownr_t rownr, const Int64& value)
 {
     if (!colDescPtr_p->isScalar()) {
         throwPutScalar();
@@ -921,7 +908,7 @@ void BaseColumn::putScalar (uInt rownr, const Int64& value)
     }
 }
 
-void BaseColumn::putScalar (uInt rownr, const float& value)
+void BaseColumn::putScalar (rownr_t rownr, const float& value)
 {
     if (!colDescPtr_p->isScalar()) {
         throwPutScalar();
@@ -948,7 +935,7 @@ void BaseColumn::putScalar (uInt rownr, const float& value)
     }
 }
 
-void BaseColumn::putScalar (uInt rownr, const double& value)
+void BaseColumn::putScalar (rownr_t rownr, const double& value)
 {
     if (!colDescPtr_p->isScalar()) {
         throwPutScalar();
@@ -975,7 +962,7 @@ void BaseColumn::putScalar (uInt rownr, const double& value)
     }
 }
 
-void BaseColumn::putScalar (uInt rownr, const Complex& value)
+void BaseColumn::putScalar (rownr_t rownr, const Complex& value)
 {
     if (!colDescPtr_p->isScalar()) {
         throwPutScalar();
@@ -993,7 +980,7 @@ void BaseColumn::putScalar (uInt rownr, const Complex& value)
     }
 }
 
-void BaseColumn::putScalar (uInt rownr, const DComplex& value)
+void BaseColumn::putScalar (rownr_t rownr, const DComplex& value)
 {
     if (!colDescPtr_p->isScalar()) {
         throwPutScalar();
@@ -1011,7 +998,7 @@ void BaseColumn::putScalar (uInt rownr, const DComplex& value)
     }
 }
 
-void BaseColumn::putScalar (uInt rownr, const String& value)
+void BaseColumn::putScalar (rownr_t rownr, const String& value)
 {
     if (!colDescPtr_p->isScalar()) {
         throwPutScalar();
@@ -1025,7 +1012,7 @@ void BaseColumn::putScalar (uInt rownr, const String& value)
     }
 }
 
-void BaseColumn::putScalar (uInt rownr, const TableRecord& value)
+void BaseColumn::putScalar (rownr_t rownr, const TableRecord& value)
 {
     if (!colDescPtr_p->isScalar()) {
         throwPutScalar();
