@@ -390,13 +390,16 @@ public:
 
     // Sort a table on one or more columns of scalars.
     BaseTable* sort (const Block<String>& columnNames,
-		     const Block<CountedPtr<BaseCompare> >& compareObjects,
-		     const Block<Int>& sortOrder, int sortOption);
+                     const Block<CountedPtr<BaseCompare> >& compareObjects,
+                     const Block<Int>& sortOrder, int sortOption,
+                     std::shared_ptr<Vector<rownr_t>> sortIterBoundaries = nullptr,
+                     std::shared_ptr<Vector<size_t>> sortIterKeyIdxChange = nullptr);
 
     // Create an iterator.
     BaseTableIterator* makeIterator (const Block<String>& columnNames,
                                      const Block<CountedPtr<BaseCompare> >&,
-				     const Block<Int>& orders, int option);
+                                     const Block<Int>& orders, int option,
+                                     bool cacheIterationBoundaries = false);
 
     // Add one or more columns to the table.
     // The default implementation throws an "invalid operation" exception.
@@ -472,8 +475,10 @@ public:
     // Only in RefTable a smarter implementation is provided.
     virtual BaseTable* doSort (PtrBlock<BaseColumn*>&,
                                const Block<CountedPtr<BaseCompare> >&,
-			       const Block<Int>& sortOrder,
-			       int sortOption);
+                               const Block<Int>& sortOrder,
+                               int sortOption,
+                               std::shared_ptr<Vector<rownr_t>> sortIterBoundaries,
+                               std::shared_ptr<Vector<size_t>> sortIterKeyIdxChange);
 
     // Create a RefTable object.
     RefTable* makeRefTable (Bool rowOrder, rownr_t initialNrrow);
@@ -592,10 +597,11 @@ private:
     String makeAbsoluteName (const String& name) const;
 
 #ifdef HAVE_MPI
-    // MPI communicator for parallel I/O
-    // Set the default to MPI_COMM_WORLD to keep the compatibility for
-    // non-MPI apps to work with the MPI-enabled casacore build.
-    MPI_Comm itsMpiComm = MPI_COMM_WORLD;
+    // MPI communicator for parallel I/O.
+    // When using an MPI-disabled casacore, MPI applications have always been
+    // able to create Tables from each rank independently. Defaulting this
+    // communicator to MPI_COMM_SELF preserves that expectation.
+    MPI_Comm itsMpiComm = MPI_COMM_SELF;
 #endif
 };
 
