@@ -129,7 +129,7 @@ template<typename T> class RecordFieldPtr;
 //     // ANTENNA is a unique key, so only one row number matches.
 //     // Otherwise function getRowNumbers had to be used.
 //     *antFld = antenna;
-//     uInt antRownr = colInx.getRowNumber (found);
+//     rownr_t antRownr = colInx.getRowNumber (found);
 //     if (!found) {
 //         cout << "Antenna " << antenna << " is unknown" << endl;
 //     } else {
@@ -159,7 +159,7 @@ template<typename T> class RecordFieldPtr;
 //     *timeUpp = ...;
 //     *antUpp = ...;
 //     // Find the row numbers for keys between low and upp (inclusive).
-//     Vector<uInt> rows = colInx.getRowNumbers (True, True);
+//     RowNumbers rows = colInx.getRowNumbers (True, True);
 // }
 // </srcblock>
 //
@@ -176,7 +176,7 @@ template<typename T> class RecordFieldPtr;
 // Int myCompare (const Block<void*>& fieldPtrs,
 //                const Block<void*>& dataPtrs,
 //                const Block<Int>& dataTypes,
-//                Int index)
+//                rownr_t index)
 // {
 //   // Assert (for performance only in debug mode) that the correct
 //   // fields are used.
@@ -213,7 +213,7 @@ template<typename T> class RecordFieldPtr;
 //     // Fill the key field.
 //     *time = ...;
 //     // Find the row number for this time.
-//     uInt rownr = colInx.getRowNumber (found);
+//     rownr_t rownr = colInx.getRowNumber (found);
 // }
 // </srcblock>
 // </example>
@@ -239,7 +239,7 @@ public:
     typedef Int Compare (const Block<void*>& fieldPtrs,
 			 const Block<void*>& dataPtrs,
 			 const Block<Int>& dataTypes,
-			 Int index);
+			 rownr_t index);
 
     // Create an index on the given table for the given column.
     // The column has to be a scalar column.
@@ -307,8 +307,8 @@ public:
     // functions. Note that the given Record will be copied to the internal
     // record, thus overwrites it.
     // <group>
-    uInt getRowNumber (Bool& found);
-    uInt getRowNumber (Bool& found, const Record& key);
+    rownr_t getRowNumber (Bool& found);
+    rownr_t getRowNumber (Bool& found, const Record& key);
     // </group>
 
     // Find the row numbers matching the key. It should be used instead
@@ -318,8 +318,8 @@ public:
     // functions. Note that the given Record will be copied to the internal
     // record, thus overwrites it.
     // <group>
-    Vector<uInt> getRowNumbers();
-    Vector<uInt> getRowNumbers (const Record& key);
+    RowNumbers getRowNumbers();
+    RowNumbers getRowNumbers (const Record& key);
     // </group>
 
     // Find the row numbers matching the key range. The boolean arguments
@@ -330,9 +330,9 @@ public:
     // Note that the given Records will be copied to the internal
     // records, thus overwrite them.
     // <group>
-    Vector<uInt> getRowNumbers (Bool lowerInclusive, Bool upperInclusive);
-    Vector<uInt> getRowNumbers (const Record& lower, const Record& upper,
-				Bool lowerInclusive, Bool upperInclusive);
+    RowNumbers getRowNumbers (Bool lowerInclusive, Bool upperInclusive);
+    RowNumbers getRowNumbers (const Record& lower, const Record& upper,
+                              Bool lowerInclusive, Bool upperInclusive);
     // </group>
 
     // Fill the internal key field from the corresponding external key.
@@ -367,18 +367,18 @@ protected:
     // in <src>itsUniqueIndex</src> is returned.
     // If not found, <src>found</src> is set to False and the index
     // of the next higher key is returned.
-    uInt bsearch (Bool& found, const Block<void*>& fieldPtrs) const;
+    rownr_t bsearch (Bool& found, const Block<void*>& fieldPtrs) const;
 
     // Compare the key in <src>fieldPtrs</src> with the given index entry.
     // -1 is returned when less, 0 when equal, 1 when greater.
     static Int compare (const Block<void*>& fieldPtrs,
 			const Block<void*>& dataPtrs,
 			const Block<Int>& dataTypes,
-			Int index);
+			rownr_t index);
 
     // Fill the row numbers vector for the given start till end in the
     // <src>itsUniqueIndex</src> vector (end is not inclusive).
-    void fillRowNumbers (Vector<uInt>& rows, uInt start, uInt end) const;
+    void fillRowNumbers (Vector<rownr_t>& rows, rownr_t start, rownr_t end) const;
 
 private:
     // Fill the internal key fields from the corresponding external key.
@@ -392,26 +392,26 @@ private:
       key.get (field.name(), *field);
     }
 
-    Table  itsTable;
-    uInt   itsNrrow;
+    Table   itsTable;
+    rownr_t itsNrrow;
     Record* itsLowerKeyPtr;
     Record* itsUpperKeyPtr;
-    Block<Int>   itsDataTypes;
-    Block<void*> itsDataVectors;
-    Block<void*> itsData;              //# pointer to data in itsDataVectors
+    Block<Int>      itsDataTypes;
+    Block<void*>    itsDataVectors;
+    Block<void*>    itsData;              //# pointer to data in itsDataVectors
     //# The following 2 blocks are actually blocks of RecordFieldPtr<T>*.
     //# They are used for fast access to the records.
-    Block<void*> itsLowerFields;
-    Block<void*> itsUpperFields;
-    Block<Bool>  itsColumnChanged;
-    Bool         itsChanged;
-    Bool         itsNoSort;            //# True = sort is not needed
-    Compare*     itsCompare;           //# Compare function
-    Vector<uInt> itsDataIndex;         //# Row numbers of all keys
+    Block<void*>    itsLowerFields;
+    Block<void*>    itsUpperFields;
+    Block<Bool>     itsColumnChanged;
+    Bool            itsChanged;
+    Bool            itsNoSort;            //# True = sort is not needed
+    Compare*        itsCompare;           //# Compare function
+    Vector<rownr_t> itsDataIndex;         //# Row numbers of all keys
     //# Indices in itsDataIndex for each unique key
-    Vector<uInt> itsUniqueIndex;
-    uInt*        itsDataInx;           //# pointer to data in itsDataIndex
-    uInt*        itsUniqueInx;         //# pointer to data in itsUniqueIndex
+    Vector<rownr_t> itsUniqueIndex;
+    rownr_t*        itsDataInx;           //# pointer to data in itsDataIndex
+    rownr_t*        itsUniqueInx;         //# pointer to data in itsUniqueIndex
 };
 
 
