@@ -34,6 +34,7 @@
 #include <casacore/tables/Tables/BaseColumn.h>
 #include <casacore/tables/Tables/ColumnCache.h>
 #include <casacore/tables/Tables/TableRecord.h>
+#include <casacore/casa/Arrays/ArrayFwd.h>
 
 namespace casacore { //# NAMESPACE CASACORE - BEGIN
 
@@ -43,8 +44,6 @@ namespace casacore { //# NAMESPACE CASACORE - BEGIN
   class TableRecord;
   class Slicer;
   class IPosition;
-  template<class T> class Vector;
-
 
   // <summary>
   // A column in a concatenated table
@@ -113,16 +112,16 @@ namespace casacore { //# NAMESPACE CASACORE - BEGIN
     // </group>
 
     // Get nr of rows in the column.
-    virtual uInt nrow() const;
+    virtual rownr_t nrow() const;
 
     // Test if a value in a particular cell has been defined.
-    virtual Bool isDefined (uInt rownr) const;
+    virtual Bool isDefined (rownr_t rownr) const;
 
     // Set the shape of the array in the given row.
-    virtual void setShape (uInt rownr, const IPosition& shape);
+    virtual void setShape (rownr_t rownr, const IPosition& shape);
 
     // Set the shape and tile shape of the array in the given row.
-    virtual void setShape (uInt rownr, const IPosition& shape,
+    virtual void setShape (rownr_t rownr, const IPosition& shape,
 			   const IPosition& tileShape);
 
     // Get the global #dimensions of an array (i.e. for all rows).
@@ -132,101 +131,82 @@ namespace casacore { //# NAMESPACE CASACORE - BEGIN
     virtual IPosition shapeColumn() const;
 
     // Get the #dimensions of an array in a particular cell.
-    virtual uInt ndim (uInt rownr) const;
+    virtual uInt ndim (rownr_t rownr) const;
 
     // Get the shape of an array in a particular cell.
-    virtual IPosition shape (uInt rownr) const;
+    virtual IPosition shape (rownr_t rownr) const;
 
     // Get the tile shape of an array in a particular cell.
-    virtual IPosition tileShape (uInt rownr) const;
+    virtual IPosition tileShape (rownr_t rownr) const;
 
     // It can change shape if the underlying column can.
     virtual Bool canChangeShape() const;
 
-    // It can handle a scalar column if the underlying column
-    // can handle cells in a scalar column.
-    virtual Bool canAccessScalarColumn (Bool& reask) const;
-
-    // It can handle an array column if the underlying column
-    // can handle cells in an array column.
-    virtual Bool canAccessArrayColumn (Bool& reask) const;
-
-    // It can handle a cell slice if the underlying column can do it.
-    virtual Bool canAccessSlice (Bool& reask) const;
-
-    // It can handle a column slice if the underlying column
-    // can handle a collection of cells in a column and a column slice.
-    virtual Bool canAccessColumnSlice (Bool& reask) const;
-
-    // It can handle cells in a scalar column if the underlying column
-    // can do it.
-    virtual Bool canAccessScalarColumnCells (Bool& reask) const;
-
-    // It can handle cells in an array column if the underlying column
-    // can do it.
-    virtual Bool canAccessArrayColumnCells (Bool& reask) const;
-
     // Initialize the rows from startRownr till endRownr (inclusive)
     // with the default value defined in the column description (if defined).
-    void initialize (uInt startRownr, uInt endRownr);
+    virtual void initialize (rownr_t startRownr, rownr_t endRownr);
 
-    // Get the value from a particular cell.
-    // This can be a scalar or an array.
-    virtual void get (uInt rownr, void* dataPtr) const;
+    // Get a value from a particular cell.
+    virtual void get (rownr_t rownr, void* dataPtr) const;
 
     // Get a slice of an N-dimensional array in a particular cell.
-    virtual void getSlice (uInt rownr, const Slicer&, void* dataPtr) const;
-
-    // Put the value in a particular cell.
-    // This can be a scalar or an array.
-    virtual void put (uInt rownr, const void* dataPtr);
-
-    // Put a slice of an N-dimensional array in a particular cell.
-    virtual void putSlice (uInt rownr, const Slicer&, const void* dataPtr);
+    virtual void getSlice (rownr_t rownr, const Slicer&, ArrayBase& dataPtr) const;
 
     // Get the array of all array values in a column.
     // If the column contains n-dim arrays, the resulting array is (n+1)-dim.
     // The arrays in the column have to have the same shape in all cells.
-    virtual void getArrayColumn (void* dataPtr) const;
+    virtual void getArrayColumn (ArrayBase& dataPtr) const;
 
     // Get subsections from all arrays in the column.
     // If the column contains n-dim arrays, the resulting array is (n+1)-dim.
     // The arrays in the column have to have the same shape in all cells.
-    virtual void getColumnSlice (const Slicer&, void* dataPtr) const;
+    virtual void getColumnSlice (const Slicer&, ArrayBase& dataPtr) const;
+
+    // Get an array from a particular cell.
+    virtual void getArray (rownr_t rownr, ArrayBase& dataPtr) const;
 
     // Get the array of some array values in a column.
     // If the column contains n-dim arrays, the resulting array is (n+1)-dim.
     // The arrays in the column have to have the same shape in all cells.
     virtual void getArrayColumnCells (const RefRows& rownrs,
-				      void* dataPtr) const;
+				      ArrayBase& dataPtr) const;
 
     // Get subsections from some arrays in the column.
     // If the column contains n-dim arrays, the resulting array is (n+1)-dim.
     // The arrays in the column have to have the same shape in all cells.
     virtual void getColumnSliceCells (const RefRows& rownrs,
-				      const Slicer&, void* dataPtr) const;
+				      const Slicer&, ArrayBase& dataPtr) const;
+
+    // Put the scalar value in a particular cell.
+    virtual void put (rownr_t rownr, const void* dataPtr);
+
+    // Put the array value in a particular cell.
+    virtual void putArray (rownr_t rownr, const ArrayBase& dataPtr);
+
+    // Put a slice of an N-dimensional array in a particular cell.
+    virtual void putSlice (rownr_t rownr, const Slicer&, const ArrayBase& dataPtr);
 
     // Put the array of all array values in the column.
     // If the column contains n-dim arrays, the source array is (n+1)-dim.
     // The arrays in the column have to have the same shape in all cells.
-    virtual void putArrayColumn (const void* dataPtr);
+    virtual void putArrayColumn (const ArrayBase& dataPtr);
 
     // Put into subsections of all table arrays in the column.
     // If the column contains n-dim arrays, the source array is (n+1)-dim.
     // The arrays in the column have to have the same shape in all cells.
-    virtual void putColumnSlice (const Slicer&, const void* dataPtr);
+    virtual void putColumnSlice (const Slicer&, const ArrayBase& dataPtr);
 
     // Get the array of some array values in a column.
     // If the column contains n-dim arrays, the resulting array is (n+1)-dim.
     // The arrays in the column have to have the same shape in all cells.
     virtual void putArrayColumnCells (const RefRows& rownrs,
-				      const void* dataPtr);
+				      const ArrayBase& dataPtr);
 
     // Put subsections of some arrays in the column.
     // If the column contains n-dim arrays, the source array is (n+1)-dim.
     // The arrays in the column have to have the same shape in all cells.
     virtual void putColumnSliceCells (const RefRows& rownrs,
-				      const Slicer&, const void* dataPtr);
+				      const Slicer&, const ArrayBase& dataPtr);
 
     // Get the underlying column cache.
     virtual ColumnCache& columnCache();
@@ -246,40 +226,40 @@ namespace casacore { //# NAMESPACE CASACORE - BEGIN
   private:
     // Define the function to handle access to an entire column.
     typedef void AccessColumnFunc (BaseColumn* col,
-				   const Slicer*, ArrayBase* array);
+				   const Slicer*, ArrayBase& array);
 
     // Define the function to handle access to a number of rows.
     typedef void AccessRowsFunc (BaseColumn* col, const RefRows& rows,
-				  const Slicer*, ArrayBase* array);
+                                 const Slicer*, ArrayBase& array);
 
     // Access the data for an entire column.
     void accessColumn (const Slicer* ns,
-		       void* dataPtr,
+		       ArrayBase& dataPtr,
 		       AccessColumnFunc*) const;
 
     // Access the data with multiple rows combined.
     void accessRows (const RefRows& rownrs,
 		     const Slicer* ns,
-		     void* dataPtr,
+		     ArrayBase& dataPtr,
 		     AccessRowsFunc*) const;
 
     // Define the access functions.
     static void getColumnPart (BaseColumn* col,
-			       const Slicer*, ArrayBase* arr);
+			       const Slicer*, ArrayBase& arr);
     static void putColumnPart (BaseColumn* col,
-			       const Slicer*, ArrayBase* arr);
+			       const Slicer*, ArrayBase& arr);
     static void getColumnSlicePart (BaseColumn* col,
-				    const Slicer* ns, ArrayBase* arr);
+				    const Slicer* ns, ArrayBase& arr);
     static void putColumnSlicePart (BaseColumn* col,
-				    const Slicer* ns, ArrayBase* arr);
+				    const Slicer* ns, ArrayBase& arr);
     static void getRowsPart (BaseColumn* col, const RefRows& rows,
-			     const Slicer*, ArrayBase* array);
+			     const Slicer*, ArrayBase& array);
     static void putRowsPart (BaseColumn* col, const RefRows& rows,
-			     const Slicer*, ArrayBase* array);
+			     const Slicer*, ArrayBase& array);
     static void getRowsSlicePart (BaseColumn* col, const RefRows& rows,
-				  const Slicer*, ArrayBase* array);
+				  const Slicer*, ArrayBase& array);
     static void putRowsSlicePart (BaseColumn* col, const RefRows& rows,
-				  const Slicer*, ArrayBase* array);
+				  const Slicer*, ArrayBase& array);
     // </group>
 
   protected:
