@@ -74,68 +74,70 @@ public:
   virtual ~NullTable();
 
   // The table is a null table.
-  virtual Bool isNull() const;
+  virtual Bool isNull() const override;
 
   // All functions throw a "null table" exception.
   // <group>
-  virtual void reopenRW();
-  virtual Bool asBigEndian() const;
-  virtual const StorageOption& storageOption() const;
-  virtual Bool isMultiUsed (Bool checkSubTable) const;
-  virtual const TableLock& lockOptions() const;
-  virtual void mergeLock (const TableLock& lockOptions);
-  virtual Bool hasLock (FileLocker::LockType) const;
-  virtual Bool lock (FileLocker::LockType, uInt nattempts);
-  virtual void unlock();
-  virtual void flush (Bool fsync, Bool recursive);
-  virtual void resync();
-  virtual uInt getModifyCounter() const;
-  virtual Bool isWritable() const;
+  virtual void reopenRW() override;
+  virtual Bool asBigEndian() const override;
+  virtual const StorageOption& storageOption() const override;
+  virtual Bool isMultiUsed (Bool checkSubTable) const override;
+  virtual const TableLock& lockOptions() const override;
+  virtual void mergeLock (const TableLock& lockOptions) override;
+  virtual Bool hasLock (FileLocker::LockType) const override;
+  virtual Bool lock (FileLocker::LockType, uInt nattempts) override;
+  virtual void unlock() override;
+  virtual void flush (Bool fsync, Bool recursive) override;
+  virtual void resync() override;
+  virtual uInt getModifyCounter() const override;
+  virtual Bool isWritable() const override;
   virtual void deepCopy (const String& newName,
 			 const Record& dataManagerInfo,
                          const StorageOption&,
 			 int tableOption,
 			 Bool valueCopy,
 			 int endianFormat,
-			 Bool noRows) const;
-  virtual TableDesc actualTableDesc() const;
-  virtual Record dataManagerInfo() const;
-  virtual TableRecord& keywordSet();
-  virtual TableRecord& rwKeywordSet();
-  virtual BaseColumn* getColumn (uInt columnIndex) const;
-  virtual BaseColumn* getColumn (const String& columnName) const;
-  virtual Bool canAddRow() const;
-  virtual void addRow (rownr_t nrrow, Bool initialize);
-  virtual Bool canRemoveRow() const;
-  virtual void removeRow (rownr_t rownr);
+			 Bool noRows) const override;
+  virtual TableDesc actualTableDesc() const override;
+  virtual Record dataManagerInfo() const override;
+  virtual TableRecord& keywordSet() override;
+  virtual TableRecord& rwKeywordSet() override;
+  virtual BaseColumn* getColumn (uInt columnIndex) const override;
+  virtual BaseColumn* getColumn (const String& columnName) const override;
+  virtual Bool canAddRow() const override;
+  virtual void addRow (rownr_t nrrow, Bool initialize) override;
+  virtual Bool canRemoveRow() const override;
+  virtual void removeRow (rownr_t rownr) override;
   virtual DataManager* findDataManager (const String& name,
-                                        Bool byColumn) const;
-  virtual void addColumn (const ColumnDesc& columnDesc, Bool addToParent);
+                                        Bool byColumn) const override;
+  virtual void addColumn (const ColumnDesc& columnDesc, Bool addToParent) override;
   virtual void addColumn (const ColumnDesc& columnDesc,
 			  const String& dataManager, Bool byName,
-                          Bool addToParent);
+                          Bool addToParent) override;
   virtual void addColumn (const ColumnDesc& columnDesc,
-			  const DataManager& dataManager, Bool addToParent);
+			  const DataManager& dataManager, Bool addToParent) override;
   virtual void addColumn (const TableDesc& tableDesc,
-			  const DataManager& dataManager, Bool addToParent);
-  virtual Bool canRemoveColumn (const Vector<String>& columnNames) const;
-  virtual void removeColumn (const Vector<String>& columnNames);
-  virtual Bool canRenameColumn (const String& columnName) const;
-  virtual void renameColumn (const String& newName, const String& oldName);
+			  const DataManager& dataManager, Bool addToParent) override;
+  virtual Bool canRemoveColumn (const Vector<String>& columnNames) const override;
+  virtual void removeColumn (const Vector<String>& columnNames) override;
+  virtual Bool canRenameColumn (const String& columnName) const override;
+  virtual void renameColumn (const String& newName, const String& oldName) override;
   virtual void renameHypercolumn (const String& newName,
-				    const String& oldName);
-  virtual Vector<rownr_t> rowNumbers() const;
-  virtual BaseTable* root();
-  virtual Bool rowOrder() const;
-  virtual Vector<rownr_t>* rowStorage();
+				    const String& oldName) override;
+  virtual Vector<rownr_t> rowNumbers() const override;
+  virtual BaseTable* root() override;
+  virtual Bool rowOrder() const override;
+  virtual Vector<rownr_t>* rowStorage() override;
   virtual Bool adjustRownrs (rownr_t nrrow, Vector<rownr_t>& rownrs,
-			     Bool determineOrder) const;
+			     Bool determineOrder) const override;
   virtual BaseTable* doSort (PtrBlock<BaseColumn*>&,
-			     const Block<CountedPtr<BaseCompare> >&,
-			     const Block<Int>& sortOrder,
-			     int sortOption);
+                             const Block<CountedPtr<BaseCompare> >&,
+                             const Block<Int>& sortOrder,
+                             int sortOption,
+                             std::shared_ptr<Vector<rownr_t>> sortIterBoundaries,
+                             std::shared_ptr<Vector<size_t>> sortIterKeyIdxChange) override;
   virtual void renameSubTables (const String& newName,
-				const String& oldName);
+				const String& oldName) override;
   // </group>
 
 private:
