@@ -39,30 +39,6 @@ String removeDir (const String& msg)
   return s;
 }
 
-// Test modifying the dminfo record.
-void testDM()
-{
-    TableDesc td;
-    td.addColumn(ScalarColumnDesc<Int>("col1"));
-    td.addColumn(ScalarColumnDesc<Int>("col2"));
-    td.addColumn(ScalarColumnDesc<Int>("col3"));
-    td.addColumn(ArrayColumnDesc<Int>("col4"));
-    // Now create a new table from the description.
-    SetupNewTable aNewTab("tTableCopy_tmp.dm", td, Table::New);
-    Table tabl(aNewTab);
-    Record dminfo = tabl.dataManagerInfo();
-    cout << dminfo;
-    Vector<String> remCols1 =
-      TableCopy::removeDminfoColumns (dminfo, Vector<String>(1, "col1"), "Standard");
-    cout << dminfo << remCols1 << endl;
-    Vector<String> remCols2 =
-      TableCopy::removeDminfoColumns (dminfo, Vector<String>(1, "col1"));
-    cout << dminfo << remCols2 << endl;
-    TableCopy::setTiledStMan (dminfo, Vector<String>(1, "col3"),
-                              "TiledShapeStMan", "TSMData", IPosition(3,3,4,5));
-    cout << dminfo << endl;
-}
-
 void testCloneColumn (const DataManager& tsm, Bool fixed)
 {
   cout << "testCloneColumn ..." << endl;
@@ -190,7 +166,6 @@ int main (int argc, const char* argv[])
 	 << endl;
 
     if (argc <= 1) {
-      testDM();
       testCloneColumns();
     }
   } catch (const exception& x) {
