@@ -45,6 +45,7 @@
 #include <casacore/casa/Arrays/ArrayUtil.h>
 #include <casacore/casa/Utilities/Assert.h>
 #include <casacore/casa/Exceptions/Error.h>
+#include <casacore/casa/IO/ArrayIO.h>
 #include <casacore/casa/iostream.h>
 
 #include <casacore/casa/namespace.h>
@@ -109,7 +110,7 @@ void b (Bool noReadLocking, Bool permLocking)
     Table tab("tTableLockSync_tmp.tab", lt, Table::Update);
     try {
 	TableLocker lock1 (tab, FileLocker::Write, 1);
-    } catch (AipsError& x) {
+    } catch (std::exception& x) {
 	cout << "table is write-locked" << endl;
     } 
     ScalarColumn<Int> col1 (tab, "col1");
@@ -171,8 +172,8 @@ void b (Bool noReadLocking, Bool permLocking)
 		if (opt == 9) {
 		    col1.put (0, val);
 		}
-	    } catch (AipsError& x) {
-	        cout << x.getMesg() << endl;
+	    } catch (std::exception& x) {
+	        cout << x.what() << endl;
 		err = True;
 	    } 
 	    if (!err) {
@@ -226,8 +227,8 @@ void b (Bool noReadLocking, Bool permLocking)
 		if (opt == 11) {
 		    tab.rwKeywordSet().define ("k0", val);
 		}
-	    } catch (AipsError& x) {
-	        cout << x.getMesg() << endl;
+	    } catch (std::exception& x) {
+	        cout << x.what() << endl;
 		err = True;
 	    } 
 	    if (!err) {
@@ -279,8 +280,8 @@ int main (int argc, const char* argv[])
 		a();
 	    }
 	    b (noReadLocking, permLocking);
-	} catch (AipsError& x) {
-	    cout << "Caught an exception: " << x.getMesg() << endl;
+	} catch (std::exception& x) {
+	    cout << "Caught an exception: " << x.what() << endl;
 	    return 1;
 	} 
     }
