@@ -37,7 +37,7 @@
 #include <casacore/casa/Utilities/Assert.h>
 #include <casacore/casa/Arrays/Array.h>
 #include <casacore/casa/Arrays/Vector.h>
-#include <casacore/casa/Arrays/ArrayIO.h>
+#include <casacore/casa/IO/ArrayIO.h>
 #include <casacore/casa/Arrays/ArrayMath.h>
 #include <casacore/casa/Arrays/ArrayLogical.h>
 #include <casacore/casa/Arrays/ArrayUtil.h>
@@ -103,13 +103,13 @@ void doDefineAssign (const TableRecord& inrecord)
 			     stringToVector ("abc,dghij,klmn")));
     try {
 	*rfstr2 = stringToVector ("abc");
-    } catch (AipsError& x) {
-	cout << x.getMesg() << endl;           // incorrect shape
+    } catch (std::exception& x) {
+	cout << x.what() << endl;           // incorrect shape
     } 
     try {
 	*rfstr3 = stringToVector ("abc");
-    } catch (AipsError& x) {
-	cout << x.getMesg() << endl;           // incorrect shape
+    } catch (std::exception& x) {
+	cout << x.what() << endl;           // incorrect shape
     } 
     record.get (record.fieldNumber ("TpArrayString2"), vec);
     AlwaysAssertExit (allEQ (vec,
@@ -120,13 +120,13 @@ void doDefineAssign (const TableRecord& inrecord)
 
     try {
 	*rfstr2 = stringToVector ("abc");
-    } catch (AipsError& x) {
-	cout << x.getMesg() << endl;           // incorrect shape
+    } catch (std::exception& x) {
+	cout << x.what() << endl;           // incorrect shape
     } 
     try {
 	*rfstr3 = stringToVector ("abc");
-    } catch (AipsError& x) {
-	cout << x.getMesg() << endl;           // incorrect shape
+    } catch (std::exception& x) {
+	cout << x.what() << endl;           // incorrect shape
     } 
     record.get (record.fieldNumber ("TpArrayString2"), vec);
     AlwaysAssertExit (allEQ (vec,
@@ -137,8 +137,8 @@ void doDefineAssign (const TableRecord& inrecord)
 
     try {
 	rfstr2.define (stringToVector ("abc"));
-    } catch (AipsError& x) {
-	cout << x.getMesg() << endl;           // incorrect shape
+    } catch (std::exception& x) {
+	cout << x.what() << endl;           // incorrect shape
     } 
     rfstr3.define (stringToVector ("a"));
     record.get (record.fieldNumber ("TpArrayString2"), vec);
@@ -171,8 +171,8 @@ void doDefineAssign (const TableRecord& inrecord)
 
     try {
         record.define ("TpBool", Vector<Bool>(2, False));
-    } catch (AipsError& x) {
-        cout << x.getMesg() << endl;
+    } catch (std::exception& x) {
+        cout << x.what() << endl;
     } 
 }
 
@@ -217,9 +217,9 @@ void doSubRecord (Bool doExcp, const RecordDesc& desc)
     if (doExcp) {
 	try {
 	    record1 = record;
-	} catch (AipsError& x) {
+	} catch (std::exception& x) {
 	    cout << ">>> Instance-specific assertion error message:" << endl;
-	    cout << x.getMesg() << endl;           // not conforming
+	    cout << x.what() << endl;           // not conforming
 	    cout << "<<<" << endl;
 	} 
     }
@@ -290,25 +290,25 @@ void doIt (Bool doExcp)
     if (doExcp) {
 	try {
 	    record.define ("", (Int)0);
-	} catch (AipsError& x) {
-	    cout << x.getMesg() << endl;           // empty name
+	} catch (std::exception& x) {
+	    cout << x.what() << endl;           // empty name
 	} 
 	try {
 	    record.define ("aB", (Int)0);
-	} catch (AipsError& x) {
-	    cout << x.getMesg() << endl;           // first no uppercase
+	} catch (std::exception& x) {
+	    cout << x.what() << endl;           // first no uppercase
 	} 
 	extraArgument = 10;
 	try {
 	    record.define ("A", (Int)0);
-	} catch (AipsError& x) {
-	    cout << x.getMesg() << endl;           // extra argument = 10
+	} catch (std::exception& x) {
+	    cout << x.what() << endl;           // extra argument = 10
 	} 
 	extraArgument = 0;
 	try {
 	    record.define ("TpShort", (Int)0);
-	} catch (AipsError& x) {
-	    cout << x.getMesg() << endl;           // invalid type
+	} catch (std::exception& x) {
+	    cout << x.what() << endl;           // invalid type
 	} 
     }
     AlwaysAssertExit(record.nfields() == rd.nfields() &&
@@ -379,8 +379,8 @@ void doIt (Bool doExcp)
     if (doExcp) {
 	try {
 	    record2a.restructure(subDesc);
-	} catch (AipsError& x) {
-	    cout << x.getMesg() << endl;  // fixed, not empty ->impossible
+	} catch (std::exception& x) {
+	    cout << x.what() << endl;  // fixed, not empty ->impossible
 	} 
     }
     record2 = record;                     // non-fixed -> possible
@@ -389,9 +389,9 @@ void doIt (Bool doExcp)
     if (doExcp) {
 	try {
 	    record2a = record2b;
-	} catch (AipsError& x) {
+	} catch (std::exception& x) {
 	    cout << ">>> Instance-specific assertion error message:" << endl;
-	    cout << x.getMesg() << endl;  // fixed; non-conforming
+	    cout << x.what() << endl;  // fixed; non-conforming
 	    cout << "<<<" << endl;
 	} 
     }
@@ -463,8 +463,8 @@ void doIt (Bool doExcp)
     if (doExcp) {
 	try {
 	    RecordFieldPtr<Record> fld(record, "SubRecord");
-	} catch (AipsError& x) {
-	    cout << x.getMesg() << endl;           // invalid type
+	} catch (std::exception& x) {
+	    cout << x.what() << endl;           // invalid type
 	} 
     }
     RecordFieldPtr<TableRecord> recordField(record, "SubRecord");
@@ -774,13 +774,13 @@ void testTable (Bool doExcp)
     if (doExcp) {
 	try {
 	    rec1.defineTable (rec1.fieldNumber("tab1"), tab2);
-	} catch (AipsError& x) {
-	    cout << x.getMesg() << endl;           // non-conforming
+	} catch (std::exception& x) {
+	    cout << x.what() << endl;           // non-conforming
 	} 
 	try {
 	    RecordFieldPtr<Table> fld1 (rec1, "tab1");
-	} catch (AipsError& x) {
-	    cout << x.getMesg() << endl;           // invalid type
+	} catch (std::exception& x) {
+	    cout << x.what() << endl;           // invalid type
 	} 
     }    
     rec1.defineTable (rec1.fieldNumber("tab2"), tab2);
@@ -916,8 +916,8 @@ int main (int argc, const char*[])
 	doIt ( (argc<2));
 	testTable ( (argc<2));
 	testTable2 ( (argc<2));
-    } catch (AipsError& x) {
-	cout << "Caught an exception: " << x.getMesg() << endl;
+    } catch (std::exception& x) {
+	cout << "Caught an exception: " << x.what() << endl;
 	return 1;
     } 
     cout << "OK" << endl;
